(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    858644,      17550]
NotebookOptionsPosition[    812533,      16744]
NotebookOutlinePosition[    813092,      16765]
CellTagsIndexPosition[    813049,      16762]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Analysis of the sweet spot for the coil- T1000164-v4", "Title",
 CellChangeTimes->{{3.662846845378744*^9, 3.662846854708425*^9}, {
  3.799225299045371*^9, 
  3.799225299730547*^9}},ExpressionUUID->"3dfe1237-ce63-495a-9b65-\
ebf5ff37ac1c"],

Cell[CellGroupData[{

Cell["Instructions", "Section",ExpressionUUID->"bb0d3673-5957-440e-805b-8cf3d0ee019a"],

Cell["\<\
1. Make sure that the notebook of utility functions for magnetic dipoles, \
MagDipole.nb, and the associated autosave file, MagDipole.m, are in the same \
directory as this notebook.
2. Do likewise for NewCoilTheory.nb and NewCoilTheory.m.
3. Edit the path setting statement in the Preliminaries section below to make \
it add this directory to the path. The directory name has to be specified in \
the correct format and the correct branch of the Switch[] statement for your \
system. Check the value of $System and add new branches if necessary.
4. Evaluate the Preliminaries section.
5. Evaluate the rest of the notebook and/or hack around to your heart's \
content.\
\>", "Text",
 CellChangeTimes->{{3.662606486924474*^9, 
  3.6626064944261007`*^9}},ExpressionUUID->"639e0d4b-79f4-4554-935e-\
ec18c521377a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"useprecomputed", " ", "=", " ", "True"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "whether", " ", "to", " ", "use", " ", "archived", " ", "values", " ", 
     "for", " ", "certain", " ", "time"}], "-", 
    RowBox[{"consuming", " ", "calculations"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.480244231326439*^9, 3.48024423792516*^9}, {
  3.480703939177309*^9, 3.48070394080156*^9}, {3.481941928523884*^9, 
  3.481941957601687*^9}, {3.662606252913006*^9, 3.66260627414581*^9}, {
  3.662606542247143*^9, 3.662606543728855*^9}, {3.6628468634118023`*^9, 
  3.662846863916623*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"880f8f56-0e29-4ae5-b330-3294a7b28cc9"],

Cell[CellGroupData[{

Cell["Preliminaries", "Section",
 Evaluatable->False,
 AspectRatioFixed->
  True,ExpressionUUID->"ae6c7bba-54b3-4d61-9f0a-2d04a3ee297b"],

Cell[CellGroupData[{

Cell["Dependencies", "Subsection",ExpressionUUID->"c8619771-36ca-45a5-aa35-9b680d81934d"],

Cell[CellGroupData[{

Cell[TextData[{
 "The path in which the MagDipole.m and NewCoilTheory.m files are installed. \
\n",
 StyleBox["**** EDIT THE PATHS AND/OR ADD CLAUSES FOR NEW SYSTEMS AS \
APPROPRIATE ****",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsubsection",
 CellChangeTimes->{{3.799225271705007*^9, 
  3.799225288807975*^9}},ExpressionUUID->"a0d974f5-90d7-4db0-ad7e-\
fd24e90e28de"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Switch", "[", "\[IndentingNewLine]", "\t", 
   RowBox[{
   "$System", ",", "\[IndentingNewLine]", "\t", 
    "\"\<Mac OS X x86 (64-bit)\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{
      "$Path", ",", 
       "\"\</Users/mbarton/Work/LIGO/writeups/Sweet Spot Measurement \
(T1000164)/T1000164-v4\>\""}], "]"}]}], ",", "\[IndentingNewLine]", "\t", 
    "\"\<Microsoft Windows\>\"", ",", 
    RowBox[{"$Path", " ", "=", " ", 
     RowBox[{"Append", "[", 
      RowBox[{"$Path", ",", "\"\<c:\\\\EDIT ME\>\""}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.453747804876116*^9, 3.4537478086805983`*^9}, {
   3.662606320813328*^9, 3.662606344907859*^9}, {3.662606620105997*^9, 
   3.662606660892832*^9}, 3.662606796394608*^9, 3.799212631891096*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"cdb3efd8-18de-4355-af3a-39095dd99e02"]
}, Open  ]]
}, Open  ]],

Cell["<<\"MagDipole.m\"", "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"5372f101-ca2f-49e6-9a12-063152ae5f8d"],

Cell["<<\"NewCoilTheory.m\"", "Input",
 CellChangeTimes->{3.631828660846888*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"c342b927-7087-4eee-8bf4-9e186f897796"],

Cell[CellGroupData[{

Cell["Disable spell-checking", "Subsection",ExpressionUUID->"9780a3d9-9540-4886-9697-f741c422a5fb"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{
   RowBox[{"General", "::", "spell"}], ",", 
   RowBox[{"General", "::", "spell1"}]}], "]"}]], "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"cf85e739-cd86-4302-aacd-ac44fc545330"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions for manipulating lists of substitutions", "Subsection",ExpressionUUID->"9adcfee4-a22e-4c6d-bdb2-90b11cf7b5de"],

Cell[CellGroupData[{

Cell["Replace a single substitution", "Subsubsection",ExpressionUUID->"ffc09f59-ca70-4cb8-affb-eabdf7057e11"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Override", "[", 
   RowBox[{"oldsubs_", ",", "newsubs_"}], "]"}], " ", ":=", " ", 
  RowBox[{"oldsubs", "/.", 
   RowBox[{"(", 
    RowBox[{"newsubs", "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"param_", "\[Rule]", "newval_"}], ")"}], "\[RuleDelayed]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "oldval_"}], ")"}], "\[RuleDelayed]", 
        RowBox[{"(", 
         RowBox[{"param", "\[Rule]", "newval"}], ")"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"a8c3bb97-4087-4d53-8662-a22df462b79d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
A function to reduce a substitution list to fully numerical form by applying \
it repeatedly to itself:\
\>", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"506e45ed-ac8b-4ade-b72f-98885d921fd4"],

Cell["\<\
Recurse[sublist_List] := 
\tsublist//.(x_->y_):>(x->(y/.sublist))\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"6e6dff58-ddc2-4d85-a678-de8a16047112"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to scale a substitution list:", "Subsubsection",
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"6638e03a-c5f4-4afd-9d19-0630b8b3b919"],

Cell["\<\
scale[sublist_List, factor_] := 
\tsublist/.(x_->y_):>(x->factor*y)\
\>", "Input",
 CellChangeTimes->{3.453749631833597*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"c7541543-1c68-47d5-98c0-53e6f0bec293"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derive the axial and radial components of B", "Subsection",ExpressionUUID->"678e8115-2bb6-4ba0-aeb9-afed12599c78"],

Cell[CellGroupData[{

Cell["\<\
Baxial = Simplify[
\tTogether[
\t\tdipoleB[[3]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]
\
\>", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"d534ff9f-4118-48a0-8862-c08ac405a88b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "m1z"}], " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1x", " ", "r", " ", "z"}], "+", 
     RowBox[{"2", " ", "m1z", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965547722*^9, 3.453749599994955*^9, 3.4638444535242777`*^9, {
   3.478894405842181*^9, 3.478894421027747*^9}, 3.478960340825461*^9, 
   3.479485741071822*^9, 3.479486052836144*^9, 3.4796583821237583`*^9, 
   3.480082564582583*^9, 3.4802436759582167`*^9, 3.4806922469034033`*^9, 
   3.481566005895687*^9, {3.4819409141959743`*^9, 3.48194093732237*^9}, 
   3.48194192328915*^9, 3.662606573885989*^9, {3.662606989900323*^9, 
   3.662607015810851*^9}, 3.662607108876596*^9, 3.6626240600072823`*^9, 
   3.799212563574514*^9, 3.799212646045431*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"a546e7a1-354c-4c1d-8dff-5a3a4173ee4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Baxial", "/.", 
  RowBox[{"r", "\[Rule]", "0"}]}]], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"2456c139-a623-4985-af3d-765900d42720"],

Cell[BoxData[
 FractionBox[
  RowBox[{"m1z", " ", "mu0"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SuperscriptBox["z", "2"], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.4537479655831127`*^9, 3.453749600034116*^9, 3.4638444538148317`*^9, {
   3.478894405888887*^9, 3.478894421080052*^9}, 3.47896034086206*^9, 
   3.4794857411376143`*^9, 3.4794860528885927`*^9, 3.479658382192664*^9, 
   3.480082564654179*^9, 3.480243676115644*^9, 3.480692246945731*^9, 
   3.4815660059479713`*^9, {3.4819409142460823`*^9, 3.4819409373890877`*^9}, 
   3.4819419233788652`*^9, 3.6626065739127083`*^9, {3.662606990014765*^9, 
   3.662607015954369*^9}, 3.662607108934417*^9, 3.662624060038443*^9, 
   3.799212563624206*^9, 3.799212646050994*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"e0643c83-0574-4326-a41e-fe004fa5f899"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Btransverse = Simplify[
\tTogether[
\t\tdipoleB[[1]]
\t\t/.dx->0
\t\t/.dy->0
\t\t/.dz->0
\t\t/.Xx->r
\t\t/.Yy->0
\t\t/.Zz->z
\t]
]\
\>", "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"fa895aba-bd45-47e1-b999-8f3ea924fac8"],

Cell[BoxData[
 FractionBox[
  RowBox[{"mu0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "m1x", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"3", " ", "m1z", " ", "r", " ", "z"}], "-", 
     RowBox[{"m1x", " ", 
      SuperscriptBox["z", "2"]}]}], ")"}]}], 
  RowBox[{"4", " ", "\[Pi]", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.453747965615678*^9, 3.453749600077715*^9, 3.463844455487849*^9, {
   3.478894405942997*^9, 3.4788944211302834`*^9}, 3.478960340942863*^9, 
   3.479485741189885*^9, 3.4794860529295588`*^9, 3.4796583822416077`*^9, 
   3.480082564700638*^9, 3.48024367617673*^9, 3.480692246987156*^9, 
   3.481566005979335*^9, {3.481940914277701*^9, 3.481940937448995*^9}, 
   3.481941923414253*^9, 3.662606573961648*^9, {3.662606990066422*^9, 
   3.662607015998637*^9}, 3.662607108999185*^9, 3.662624060105956*^9, 
   3.799212563635304*^9, 3.7992126460936937`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"6575c2e5-eac8-43ab-a708-9ca05252588b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
force[Zz_] = Simplify[-mz \
D[dipoleBz,Zz]/.dx->0/.dy->0/.dz->0/.Xx->0/.Yy->0]/.powerfix\
\>", "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"657f57ee-cbd8-4b4b-ad07-337e3f815d14"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", "m1z", " ", "mu0", " ", "mz"}], 
  RowBox[{"2", " ", "\[Pi]", " ", 
   SuperscriptBox["Zz", "4"]}]]], "Output",
 CellChangeTimes->{
  3.453747965823358*^9, 3.4537496001121492`*^9, 3.46384446080796*^9, {
   3.4788944059930553`*^9, 3.478894421180645*^9}, 3.47896034097888*^9, 
   3.4794857412398157`*^9, 3.479486052963105*^9, 3.479658382309431*^9, 
   3.4800825649222116`*^9, 3.480243676306188*^9, 3.48069224701851*^9, 
   3.4815660060302887`*^9, {3.481940914334242*^9, 3.481940937496923*^9}, 
   3.481941923466711*^9, 3.662606574022719*^9, {3.6626069901552343`*^9, 
   3.662607016065351*^9}, 3.662607109064283*^9, 3.662624060172635*^9, 
   3.7992125636946898`*^9, 3.7992126461435432`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"aa833aa4-f5cd-4b6a-8244-7a8bc24bcf84"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"force", "[", "1", "]"}], "/.", 
     RowBox[{"mz", "\[Rule]", "1."}]}], "/.", 
    RowBox[{"m1z", "\[Rule]", "1."}]}], "/.", 
   RowBox[{"Zz", "\[Rule]", "1."}]}], "/.", 
  RowBox[{"mu0", "\[Rule]", "1", " ", 
   RowBox[{"(*", 
    RowBox[{"4", " ", "Pi", " ", 
     RowBox[{"10", "^", 
      RowBox[{"-", "7"}]}]}], "*)"}]}]}]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"b11f8f4d-4fab-4c28-89c0-ba9ed0b4562c"],

Cell[BoxData["0.477464829275686`"], "Output",
 CellChangeTimes->{
  3.4537479659442177`*^9, 3.4537496001816998`*^9, 3.463844461260048*^9, {
   3.478894406093301*^9, 3.4788944212800493`*^9}, 3.478960341011427*^9, 
   3.4794857412898493`*^9, 3.47948605300837*^9, 3.4796583823753366`*^9, 
   3.4800825649736032`*^9, 3.480243676359799*^9, 3.480692247054192*^9, 
   3.4815660060631313`*^9, {3.481940914365226*^9, 3.481940937547433*^9}, 
   3.4819419235105124`*^9, 3.6626065740757732`*^9, {3.662606990213984*^9, 
   3.662607016116412*^9}, 3.6626071091101513`*^9, 3.662624060236904*^9, 
   3.799212563699902*^9, 3.7992126461500683`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"3fd1c375-a2f8-40fe-8422-1c2abd48981d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic constants", "Subsection",
 Evaluatable->False,
 AspectRatioFixed->
  True,ExpressionUUID->"edcb98b6-a535-42a2-abc3-024a620de9bf"],

Cell["\<\
basicvals = Recurse[{
\tkB->1.38 10^-23,
\tT->295,
\tg->9.8,
\tmu0->4 N[Pi] 10^-7,
\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\tmassM->rhomM l N[Pi] a^2,
\tBresid->1.25,\t\t\t\t(* Residual field *)
\tPi->N[Pi],
\tl->0.003175,\t\t\t\t(* Length of magnets *)
\ta->0.0009525,\t\t\t\t(* Radius of magnets *)
\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\tmasspullapart->0.060\t\t(* Force (in kgf) to separate magnets *)
}];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[15]:=",ExpressionUUID->"19e1338f-4a6c-44a8-827f-3217503d699e"],

Cell["\<\
SOSvals = Recurse[{
\tdpend->0.248,\t(* SOS final design *)
\troptic->0.0762/2,\t(* SOS final design *)
\tdyaw->0.0157,\t(* SOS final design *)
\tmassoptic->0.25,
\tw0->2 N[Pi] 1.0
}];\
\>", "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"fdca09ed-d11f-4dbe-b709-0ac511c38634"],

Cell["\<\
LOSvals = Recurse[{
\tw0->2 N[Pi] 0.743,
\trwire->0.0031/2,
\tawire->N[Pi] rwire^2,
\tdpend->0.450,\t(* LOS final design *)
\tdyaw->0.0333,\t(* LOS final design *)
\tmassoptic->10.7,
\tloptic->0.1,
\troptic->0.125,
\tIoptic->0.25 massoptic*roptic^2 + (1/12) massoptic loptic^2,
\twpitch->2 N[Pi] 0.6,
\twpend->2 N[Pi] 0.744,
\twyaw->2 N[Pi] 0.5,
\tkpitch->wpitch^2 Ioptic, (* Angular restoring force *)
\tkyaw->wyaw^2 Ioptic, (* Angular restoring force *)\t
\tpitchlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tyawlever->0.0808,\t(* lever arm, pitch direction, per magnet *)
\tkxpitch->kpitch/pitchlever
}];\
\>", "Input",
 CellChangeTimes->{3.478894781983313*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"84d4f767-3885-464a-9226-6977164a18a0"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for bigmagnetvals 10x10 magnet, old 400 turn coil\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.799216647040254*^9, 
  3.7992166586940813`*^9}},ExpressionUUID->"2ae1367f-56e4-4279-9cb4-\
f02578c0d682"],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"1a638f07-39e3-4615-8baa-7d495e3444de"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.005811946409141117`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.007999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844663941598*^9, 3.479667628840351*^9, 
  3.480245057580022*^9, 3.48069224815385*^9, 3.4815660167539787`*^9, 
  3.481941596985648*^9, 3.481941924708386*^9, 3.662623278532525*^9, 
  3.66262406040844*^9, 3.7992125637743483`*^9, 3.7992126469013*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"5386e0a7-1ebd-4793-a0c7-7236984b3e99"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM", "]"}], " ", ":=", " ", "bigmagnetvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"902df673-dd1f-4fb6-888a-fc33cf3e4da3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.084332204665714`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006361536563952735`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BM", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.479667207329587*^9, 3.479667207950783*^9}, {3.4802442654999228`*^9, 
   3.480244302808629*^9}, 3.6626232869812593`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"445ff0c9-759b-41bc-bd85-1effc873d84c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.084332204665714`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006361536563952735`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626243337155247`*^9, 3.799212563827639*^9, 
  3.799212646948718*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"6d1925a7-604a-45c8-800f-4aa685dd4f1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8VW8cB3A/DaIQmSmlKFERFcKHiiT8yMgooSFCGZd7z71klboaGsqI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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.0843321794484708`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.479667208457279*^9, 3.479667208895832*^9}, {
   3.48024520498495*^9, 3.4802452202413063`*^9}, 3.662623284294729*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"449b716a-aa12-4cf6-bd1e-313b91961256"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8VW8cB3A/DaIQmSmlKFERFcKHiiT8yMgooSFCGZd7z71klboaGsqI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 1.0843321794484708`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662624366216887*^9, 3.79921256389085*^9, 
  3.799212646998053*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"6504973f-740a-497e-939a-33d9fe3414ce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.4796672094171343`*^9, 3.4796672098856077`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"95d58a8b-5990-4a03-a515-fea0840c57ce"],

Cell[BoxData["0.006361536563952735`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.4796682577475853`*^9, 3.4802452914839983`*^9, 3.480692248270643*^9, 
  3.481566016936092*^9, 3.481941597128859*^9, 3.481941924843739*^9, 
  3.662624366497341*^9, 3.7992125639351587`*^9, 3.79921264700364*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"d408aa6e-a1d7-490e-a50f-f77a6ca70692"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.479667219043417*^9, 3.4796672194929113`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"58b82fc2-4281-4e19-9c58-3ceab85f654e"],

Cell[BoxData["1.084332204665714`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.479668257772698*^9, 3.48024529160467*^9, 3.480692248321662*^9, 
  3.481566016972385*^9, 3.481941597184218*^9, 3.481941924879663*^9, 
  3.662624366528409*^9, 3.7992125639402847`*^9, 3.799212647046083*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"9cfc5246-ad41-4075-b5ad-739920d17fca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"34545ddd-03f8-4d06-b2de-379474b8d110"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXswGwYAB+As0rlqlvNKp5FOqzrMUI/akOxXrVS9WjWUG2UEN1JSW4YK
DSKIMreirLWt19NVTTs9j9I0m96ij6guVlGvqyIaEnlUyu0Ot+2P7769qbnR
6UQCgcD4z/+brvQ7FB/TMQkES6sAc+5nM+3hEtOQG0a8lncGszvRfS2TuO0N
A9/n2q7ca5TCMv+fkHoBC1nTDQphxxAiNIxABTsCiUVt7KIXT1HoEp8eqT8J
O78wwyXZKA4GsDPjOLGglVH2M6OUuB5c1bfPNwFnqeeYbdRJ/OCnaQ1bToRj
ZsDmZvcMJEeiXoYdSMHfbr5dBYJZiNS9TaOWqVBlJduRmHOQSY5mcxRpGF/b
ITs9Mg8Zac3CpzodxX018t5QFfaEdim+yMgESh8lUZ4vQi9p7Gna9xUWFx7Z
lXursctd9IfPu9mgvHLcUrcsgWTV1LT5kgOTpMPt9sIy2E7PqidacpCcIb6b
RtLCkmYxWsPg4rcL73hLnFZww39wxYd+Fh5SrUFO0yHn1Ba9lpKH8YHmDtEO
PWw95V38jTykku+x7Gf04P34cSxv8muQGGfqvIINMCPbkh3k3yA0hsoZvGhA
hFW9QtHBg3/fSbNLCgN4f13eoFV9C9eK0+xfiEYM17oHUvPzoR1JmHN1M2Jm
7vMqu7gC1N2cSopmGWHvR1gaDilElMogTo81IuAI4/b7B8/hCe1PFSvBCBs1
WZhtXQRhu3D9YbQRtJo0DpfIh8XGzu0JQUZMyY6nlczxcc21X210NqJ44PHv
jtJi1DvnBNqbGxHR+cSz4NcStJ7Sv3diygDlJym3lOLzWNo6NJ3fYcDRWeae
VaYA5N0spYxrwHlDI/f8LQE87/bcP+RrwI2ZnlUlvRT0rOMNHLUe6sfNhMqG
UvC3V8viY/TYRhxqCCSVYbFsMOXpAx0+9e+9c6y4DKMPgr7M+ECHxMgcs72m
Mrxasl4pyl9BUid3ajO1HGlvdJUL41rwyH5Mn6lyxEXRKtqctcjqY314JlwI
A5mqXRNocAK7D+f1C9F5s1ITNr2M8KG+188OVKCRwJW+dVmGU8sVW++fK0Bv
pXq0li7BNjtYrrUTYWOydmxiWA3Tru7uvO9E4GbrrC/S1eiyzdm/uSlCyHMP
r/bC16igaBxmeZUgk2yuE+WL8Iu5c/WhqhJjE3SLgI8WsdXM6DRPrkI3xYYg
K1Ghd6BOY62sQjwjyJI/sYBwF7cuR1Y1Yt+OXfY9vID1BjGh5n41+ENzq3VX
5yGI9B1fdxfDbmxd+oIyD2ODX670JzFMEUZxT/Ec/gUgJMys
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$7916#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980085`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXswGwYAB+As0rlqlvNKp5FOqzrMUI/akOxXrVS9WjWUG2UEN1JSW4YK
DSKIMreirLWt19NVTTs9j9I0m96ij6guVlGvqyIaEnlUyu0Ot+2P7769qbnR
6UQCgcD4z/+brvQ7FB/TMQkES6sAc+5nM+3hEtOQG0a8lncGszvRfS2TuO0N
A9/n2q7ca5TCMv+fkHoBC1nTDQphxxAiNIxABTsCiUVt7KIXT1HoEp8eqT8J
O78wwyXZKA4GsDPjOLGglVH2M6OUuB5c1bfPNwFnqeeYbdRJ/OCnaQ1bToRj
ZsDmZvcMJEeiXoYdSMHfbr5dBYJZiNS9TaOWqVBlJduRmHOQSY5mcxRpGF/b
ITs9Mg8Zac3CpzodxX018t5QFfaEdim+yMgESh8lUZ4vQi9p7Gna9xUWFx7Z
lXursctd9IfPu9mgvHLcUrcsgWTV1LT5kgOTpMPt9sIy2E7PqidacpCcIb6b
RtLCkmYxWsPg4rcL73hLnFZww39wxYd+Fh5SrUFO0yHn1Ba9lpKH8YHmDtEO
PWw95V38jTykku+x7Gf04P34cSxv8muQGGfqvIINMCPbkh3k3yA0hsoZvGhA
hFW9QtHBg3/fSbNLCgN4f13eoFV9C9eK0+xfiEYM17oHUvPzoR1JmHN1M2Jm
7vMqu7gC1N2cSopmGWHvR1gaDilElMogTo81IuAI4/b7B8/hCe1PFSvBCBs1
WZhtXQRhu3D9YbQRtJo0DpfIh8XGzu0JQUZMyY6nlczxcc21X210NqJ44PHv
jtJi1DvnBNqbGxHR+cSz4NcStJ7Sv3diygDlJym3lOLzWNo6NJ3fYcDRWeae
VaYA5N0spYxrwHlDI/f8LQE87/bcP+RrwI2ZnlUlvRT0rOMNHLUe6sfNhMqG
UvC3V8viY/TYRhxqCCSVYbFsMOXpAx0+9e+9c6y4DKMPgr7M+ECHxMgcs72m
Mrxasl4pyl9BUid3ajO1HGlvdJUL41rwyH5Mn6lyxEXRKtqctcjqY314JlwI
A5mqXRNocAK7D+f1C9F5s1ITNr2M8KG+188OVKCRwJW+dVmGU8sVW++fK0Bv
pXq0li7BNjtYrrUTYWOydmxiWA3Tru7uvO9E4GbrrC/S1eiyzdm/uSlCyHMP
r/bC16igaBxmeZUgk2yuE+WL8Iu5c/WhqhJjE3SLgI8WsdXM6DRPrkI3xYYg
K1Ghd6BOY62sQjwjyJI/sYBwF7cuR1Y1Yt+OXfY9vID1BjGh5n41+ENzq3VX
5yGI9B1fdxfDbmxd+oIyD2ODX670JzFMEUZxT/Ec/gUgJMys
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$7916#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980085`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAAD7AMncqMayP4cqdsrG
vMI/9IH4t2ECzD8sYYLNBZXSP/hmMh69FNc/Fe0rnhZ72z+65jqMuMLfP6G0
2iAb8+E/GdspKg7w4z8VVl4kgdXlP92kYo3QoOc/rmGR7HZP6T+HfsxfG9/q
P6g+53KgTew/l7+vizKZ7T+5tGjNVMDuP4ItCw/swe8/2KrwlaNO8D/DuIcl
EqnwPyfGYt5Z8PA/1aLrIcsk8T8pRpbA7EbxP56nllB4V/E/S69jDFVX8T83
Z2tzkUfxP+Y4G8NbKfE/ptBCq/n98D/xeyxXwMbwPy/VRd0KhfA/fW/EgzM6
8D+j4sO7GM/vP3X9LveyHO8/uvEy+5hf7j9HDRCUAprtP/45jVT4zew/T13h
RFH96z/0pSwQsynrP3UsZeqSVOo/ugjN1zd/6T+C67BavaroPzoXB8cW2Oc/
HU9itBII5z9/lclNXjvmP5QE3OOIcuU/GALQHweu5D93fSoYNu7jP9L1cRVe
M+M/pSZmgbV94j8pjsms
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624375842202*^9, 3.799212564060957*^9, 
  3.799212655130692*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"aa11c5d6-ed7e-4c3f-a1cd-e1e98b418733"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, 3.799212531109395*^9},
 CellLabel->"In[25]:=",ExpressionUUID->"64ff4a14-8871-4129-af87-06c0713c3594"],

Cell[BoxData["53808.60407813385`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626243761012707`*^9, 3.799212564110034*^9, 3.799212655225871*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"729fa1cb-4dc7-412b-9d1a-9f8033cc360c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"BM", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"f8cf4648-752b-474a-bc39-f37770b6d3f7"],

Cell[BoxData[
 RowBox[{"-", "1.084292460250462`"}]], "Output",
 CellChangeTimes->{3.453749602972189*^9, 3.453749666574046*^9, 
  3.453750876352957*^9, 3.453752731604185*^9, 3.453823764931923*^9, 
  3.453823801509736*^9, 3.4538385837598877`*^9, 3.453838637735564*^9, 
  3.46384467782513*^9, 3.4796682584643373`*^9, 3.4802452924391212`*^9, 
  3.480692249102811*^9, 3.481566017649225*^9, 3.4819415980291986`*^9, 
  3.4819419259636927`*^9, 3.662624376253016*^9, 3.7992125641161833`*^9, 
  3.7992126553405027`*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"7afe43e2-5771-4469-8039-4ea07690504f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"53a96b9e-449f-4ee8-9791-f3779fc8cb23"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.453823764961364*^9, 
   3.463844678344269*^9, 3.479668258488261*^9, 3.480245292474451*^9, 
   3.480692249189704*^9, 3.481566017673868*^9, 3.48194159812962*^9, 
   3.481941926000042*^9, 3.6626243762992783`*^9, 3.799212564182468*^9, 
   3.7992126553465853`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"39a19b81-a568-4701-b287-897ead9cf996"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"BM", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
  3.453823813188589*^9, 3.4538238137302923`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"401ce758-5327-4811-82da-38866b3dedee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.127078`", ",", 
   RowBox[{"-", "1.0436583953898708`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823765066656*^9, 
  3.45382381697288*^9, 3.4638446806023808`*^9, 3.479668258688435*^9, 
  3.480245292720821*^9, 3.480692249415637*^9, 3.481566017911345*^9, 
  3.481941598383407*^9, 3.481941926247629*^9, 3.662624376460092*^9, 
  3.799212564277938*^9, 3.799212655477284*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"8d6f0369-14f4-4ace-b01d-7b2ffebd0420"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Sweet spot of hybrid OSEM with dipole correction (two 10 mm long by 10 mm \
diameter magnets, 5 mm between faces) relative to centre of coil\
\>", "Text",ExpressionUUID->"36002a4d-5c80-4599-85a4-f80a15a9331b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-0.01, 0.5},
    PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", "p"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BM", ",", 
          RowBox[{"p", "-", "0.015"}]}], "]"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", 
       RowBox[{"-", "0.010"}], ",", 
       RowBox[{"-", "0.003"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.453823411637844*^9, 3.453823415837685*^9}, {
  3.480245301978496*^9, 3.4802453263238277`*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"a754fc22-647b-40ae-bb7f-9655f6a4fb9d"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VG8UB3DZk6SxlSxRRJhCtHsLbUhaaEMimpEsKTH3zpA9ayGkItoo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.01, 0.5},
  PlotRange->{{-0.01, -0.003}, {0.4602013907859698, 0.9124418225431208}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.453823529739856*^9, 3.463844847582552*^9, 
  3.480245328076311*^9, 3.480692249849388*^9, 3.481566018664538*^9, 
  3.481941598416605*^9, 3.481941926329867*^9, 3.662624416436451*^9, 
  3.799212564286899*^9, 3.799212655484116*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"1c19801b-367e-4ef6-af2c-4d69b24807e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
If[
useprecomputed,
{-0.912442, {p \[Rule] -0.00680076}},
FindMinimum[fz[BM,p]-fz[BM,p-0.015],{p,-0.007,-0.006}]
]\
\>", "Input",
 CellChangeTimes->{{3.45382342881886*^9, 3.4538234334668007`*^9}, {
  3.4538235413508263`*^9, 3.453823587089514*^9}, {3.480245341853726*^9, 
  3.480245360684174*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"beec4926-b1cd-4634-9cc5-b505164c56d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.912442`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", "0.00680076`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.453823532157748*^9, 3.4538235906330833`*^9}, 
   3.463844850994608*^9, {3.480245357148303*^9, 3.480245361221218*^9}, 
   3.480692249882522*^9, 3.481566018727625*^9, 3.48194159846943*^9, 
   3.4819419263446903`*^9, 3.662624418589693*^9, 3.7992125643326483`*^9, 
   3.799212655516746*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"01a104a6-a657-4083-9772-f6541425b5ad"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 
  3.4538236144707003`*^9}},ExpressionUUID->"c37bd691-811c-4570-8675-\
b60bafa8e5bf"],

Cell[CellGroupData[{

Cell["\<\
OOvals = Recurse[
\tbasicvals~Join~LOSvals~Join~{
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* preferred value of magnet dipole moment per volume *)
\t\tmz->mzpref/(l*N[Pi]*a^2),
\t\t(* nominal distance between PAM and optic magnet centres *)
\t\tz0->0.013,
\t\t(* thread spacing (40 tpi, cf. 32 in original design) *)
\t\tthreadpitch->0.0254/40, \t\t
\t\t(* standard perturbation to (normalised) magnet strength *)
\t\tspert->0.1, 
\t\t(* standard perturbation to magnet position *)
\t\tzpert->threadpitch, 
\t\t(* elasticity of pendulum mode *)
\t\tkpend->massoptic g/dpend,
\t\t(* distance that the magnet sticks out of the OSEM *)
\t\tstandofftoosem->0.00114681,
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254,
\t\t(* the ends of the coil relative to the end of the OSEM *)
\t\tcoilz1OSEM->0.12*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.302*0.0254,
\t\tcoilrad2->0.498*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.4538264235745993`*^9, 3.45382644840556*^9}, {
   3.453837031795086*^9, 3.453837041528119*^9}, {3.453837099708474*^9, 
   3.453837132901514*^9}, 3.453837267777411*^9, {3.453840139813717*^9, 
   3.453840149255684*^9}, {3.4538402007979527`*^9, 3.453840204355585*^9}, {
   3.4538636089891777`*^9, 3.453863609530529*^9}, {3.453863819107182*^9, 
   3.453863840974169*^9}, {3.45386389080914*^9, 3.4538638933349*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"b4827e9a-2581-400c-b635-ff1b6db624ad"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535085`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"z0", "\[Rule]", "0.013`"}], ",", 
   RowBox[{"threadpitch", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"spert", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"zpert", "\[Rule]", "0.000635`"}], ",", 
   RowBox[{"kpend", "\[Rule]", "233.0222222222222`"}], ",", 
   RowBox[{"standofftoosem", "\[Rule]", "0.00114681`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.003048`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.008305799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.007670799999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5281505471815046`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538636242380333`*^9, 3.4538639022226553`*^9, 
  3.463844851197278*^9, 3.4806922499105587`*^9, 3.481941926405641*^9, 
  3.662624418650628*^9, 3.799212564338482*^9, 3.799212655522147*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"cb6a9749-82fc-4f74-ab06-d655d575921e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "OO", "]"}], " ", ":=", " ", "OOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"75fa72e5-f61a-4b00-87b8-d570a6556952"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"OO", ",", 
   RowBox[{"-", "0.0064"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"20077e92-d012-4e5b-862a-5fbaddf3cbfd"],

Cell[BoxData[
 RowBox[{"-", "0.015387096244059595`"}]], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.4538401571878767`*^9, 
   3.453840174075727*^9}, 3.453840210377989*^9, 3.4538636411134653`*^9, 
   3.453863909646071*^9, 3.463844851305705*^9, 3.480692249973194*^9, 
   3.4819419265374804`*^9, 3.662624418743021*^9, 3.799212564389861*^9, 
   3.799212655582581*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"bf6d7f1b-1252-4b2f-801f-6cde150ce3a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"bc336c19-1cb1-43a6-baa9-f8f5c9d85fcc"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453840157247375*^9, 
   3.4538402104113083`*^9, 3.453863641155484*^9, 3.453863909695507*^9, 
   3.4638448513697023`*^9, 3.4806922500076113`*^9, 3.481941926588934*^9, 
   3.662624418792185*^9, 3.7992125644349127`*^9, 3.799212655587611*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"0e842272-5dc1-420d-bd05-272be06af2a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"27952e17-6cd1-4d1f-ac44-4d2f63fd648a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.028892`", ",", 
   RowBox[{"-", "0.015851396334673768`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453840157347342*^9, 3.453840210506116*^9, 3.453863641201985*^9, 
  3.4538639097501583`*^9, 3.463844851469378*^9, 3.480692250041*^9, 
  3.4819419266883163`*^9, 3.662624418850252*^9, 3.799212564443059*^9, 
  3.799212655620996*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"4c854889-9107-441a-9f71-9121aefb489f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"3a518087-6cae-40e0-983d-81d102009411"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.022107`", ",", 
   RowBox[{"-", "0.010507386986391542`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.4538401576313677`*^9, 3.453840210546205*^9, 
  3.453863641238579*^9, 3.453863909799973*^9, 3.4638448515362864`*^9, 
  3.4806922500657587`*^9, 3.481941926915098*^9, 3.662624418897685*^9, 
  3.79921256448658*^9, 3.799212655656489*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"6d37aa67-702e-4613-93dc-9853b906c8c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"OO", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"11708426-b2bc-4205-9106-debb6efe02c5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.043935`", ",", 
   RowBox[{"-", "0.012824745749794319`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538401579824533`*^9, 3.453840210608426*^9, 
  3.4538636412980003`*^9, 3.453863909861566*^9, 3.463844851657218*^9, 
  3.480692250121179*^9, 3.481941926976323*^9, 3.662624418971629*^9, 
  3.799212564493863*^9, 3.799212655703897*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"ae69c8ec-c2af-460d-9441-5c86e45adc5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"18b6656e-f25d-4227-9736-\
711dee46383f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"7f8d5b99-3877-44ef-993a-cb12d9cd2d89"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk0VP//B3CEikhaRFJUKklZEqFX1iRZ2iRCi0pkmZk7M9aSmaHB3CtK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       "]]},
     Annotation[#, "Charting`Private`Tag$8436#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.015861531207785717`, 0.015861531161368958`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.453840159929102*^9, 
   3.453840225991082*^9, 3.4538636558574543`*^9, 3.453863924479361*^9, 
   3.4638448686389313`*^9, 3.4806922643363953`*^9, 3.481941942064209*^9, 
   3.662624432690221*^9, 3.7992125646333*^9, 3.799212667535213*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"7626922c-2496-4172-b8d6-f659257e0b6c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"OO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"25973c72-5333-4fd9-80f7-7ac37d6298d6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13c41V8cB3CjpMjeiVJRyUhKQ95NqyUVUkRKyLjre+8l270y772USihp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       "]]},
     Annotation[#, "Charting`Private`Tag$34677#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.015861531364868304`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453840161864758*^9, 
  3.4538402352085543`*^9, 3.4538636649073067`*^9, 3.453863933391049*^9, 
  3.46384487886052*^9, 3.480692273326301*^9, 3.481941951327619*^9, 
  3.662624441306498*^9, 3.79921256464925*^9, 3.799212675206346*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"7abb0e15-e7ba-49d9-b514-18c04ab1480e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"OO", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"f0fefd8d-0148-4c32-af44-6cb5456687f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01586153159690472`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.00532527619389735`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.4538636654918613`*^9, 3.463844880212677*^9, 3.480692273883992*^9, 
   3.4819419518975058`*^9, 3.662624441878827*^9, 3.799212564668103*^9, 
   3.799212675733951*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"157a085a-46d3-48b4-ade7-1bc852e6338f"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"313eb942-123a-45f1-b00f-bd8283f90fa0"],

Cell[BoxData["0.00532527619389735`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453863665522478*^9, 3.4638448803345337`*^9, 
   3.480692273901267*^9, 3.48194195198164*^9, 3.662624441920925*^9, 
   3.799212564688949*^9, 3.7992126757388983`*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"dc67efc3-9b3a-4105-963b-c42af8a2b2ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "OO", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "OO", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"2f158e54-941f-4e8f-ab4b-59c160c12ea7"],

Cell[BoxData["0.01586153159690472`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538636655554333`*^9, 
  3.463844880438141*^9, 3.480692273921216*^9, 3.4819419520177402`*^9, 
  3.662624441968322*^9, 3.799212564746285*^9, 3.799212675784647*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"427d4820-a750-423c-9260-e3e4bc4e6467"]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}},ExpressionUUID->"ec1821fe-d639-4dd4-9f6a-\
4568230a7630"],

Cell[CellGroupData[{

Cell["\<\
VEvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.347*0.0254, (* increased from 0.16\" for LIGO-I *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\tcoilz1OSEM->0.05*0.0254,
\t\tcoilz2OSEM->coilz1OSEM+coillen,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilrad2->0.498*0.0254, (* same *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, {3.453862135114468*^9, 3.4538622312380953`*^9}, {
   3.4538622812810287`*^9, 3.453862282014607*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"56560bf5-235e-4f9a-a92f-cf475feab4d5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.008813799999999998`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.004406899999999999`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.004406899999999999`"}], ",", 
   RowBox[{"coilz1OSEM", "\[Rule]", "0.00127`"}], ",", 
   RowBox[{"coilz2OSEM", "\[Rule]", "0.010083799999999999`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.0894799325270267`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453862217965355*^9, {3.453862264142426*^9, 3.453862285813403*^9}, 
   3.463844880536422*^9, 3.4802620957847557`*^9, 3.48069227394248*^9, 
   3.481941952073387*^9, 3.6626244420201607`*^9, 3.799212564753502*^9, 
   3.799212675794528*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"304ae8a5-8e5a-481c-847e-25accad7d06e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE", "]"}], " ", ":=", " ", "VEvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
  3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
  3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"7e81a715-9ca1-4856-9954-33ef64603726"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.013119230572857864`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.006315461295902202`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"VE", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.48026206168556*^9, 
   3.480262062286573*^9}, 3.480262239842697*^9, 3.662623959952838*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"4f67205c-9f43-4fbf-838f-c912f0c00cca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572857864`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.006315461295902202`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662624488662723*^9, 3.799212564807518*^9, 
  3.799212675846784*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"0c891c29-a662-4c57-ad4e-487ba55304d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"VE", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.48026206307683*^9, 3.4802620637527103`*^9}, 
   3.480262264694813*^9, 3.662623963897244*^9},
 CellLabel->"In[46]:=",ExpressionUUID->"9fb2e2ba-9280-42e7-a100-e0021c15e7da"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662624495590671*^9, 3.799212564857132*^9, 
  3.799212675886161*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"ee657b72-238b-4d6a-a980-ca20c754deaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.48026206489049*^9, 3.480262065861014*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"32643f23-3336-44ca-99ec-f76e90a3f4e3"],

Cell[BoxData["0.006315461295902202`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480262195337325*^9, 
  3.48069227397675*^9, 3.4819419522162*^9, 3.662624495638719*^9, 
  3.79921256486833*^9, 3.799212675895667*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"63f94bab-0141-4637-8a06-3921c4510957"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "VE", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "VE", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.4802620669164543`*^9, 3.480262067600336*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"1b78dee0-4370-4b8b-84b3-39acbd94d674"],

Cell[BoxData["0.013119230572857864`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480262195361561*^9, 
  3.480692273996217*^9, 3.481941952298916*^9, 3.662624495703776*^9, 
  3.799212564916767*^9, 3.799212675930348*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"f437289e-8009-445f-847d-3157db9da92f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"VE", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623545865924*^9, 3.662623547424322*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"91096579-c078-45df-9be3-2862295967db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVknsw1AkAx/eWujln8mjvkrSeZxCjs16x+t6Vt/XIK4o5s14XbmndsoR9
v36bx53NSKSOMS7pbllMHUkzONFoc7nKOUZcjpDH5TLRuT8+85n5/P2xZGZH
ppJJJBJ9l/+9UXvbvDhw2YdESrpIsdc7PvljSPfGwBGwt9PEfVsB0DSkk/es
0XHqbbdDyus4GOa/Dajg+0GkK3Iu5DLBWKR7a1MYUEb+mzca/DUK7OJSQ1dO
gRZTNftexIKbV0p6bFYMzke6UWoPsdHkK++ydo1HyIjas9SCgxr3xbrghQQ4
0Afjz5G56D4ZMRV8NAl2aTZl1XWFkM53Vj02ZMIUVzquni5Gf7d/ZpY2GWPp
4ZXLv/LQr/tGj6ZIhafg4cyzjwSwCFJrz6al44OlypooTyFWui91VFmfgwv9
WsLaCREOOknv0fZmosgySmAdKYauUVXV9lQWaPXXY3ODJEixGVU8u8xCw1hz
6F9UKQxN9R4r6TlYuFCnXlyTovlY3xLN7DwMTBN5zCYZWKd3zEr3scF6L7sv
ipaD4jysLnrHBiNgc1m9IAfnqmMM53kuPLyU7SUpCujoU/TNh7+FI/Xl0/zf
FGAYVWi1LRws/pzY2ORAgPPoyjtTeR6mIr6MobEIjJQ6eX+Sn4/pzezy1UYC
kzNRcpNYLtyUTxuiBwkccif9PRJQgLJG17HJ5wS8TtJ/OuBWiNA3ogXqJIH9
8/riTOMLuNFnUDLwiICpMjkrh1yEf0imHlwNgYn+sOSSmSJU1jRu7S0lUHxn
qNfqbjFmWjyMds4QYLQ+cObeLIFKbfndnAmBcY+kW+MED+SV7+ONtQr4T/tY
rPvwYb5ltPFpgQK815dyeLf4sAlcW/KlKtA82bE+bibAq17jkaUeOeaHqkky
lQAuhyP2O4XJsYc8oPLWFcKRVpscPi2D57HOtsBiIXojwz6fS5YhIZSlY7kh
RIaqVvPHrBSJrTkT20wRniS12nZmSMHRd/ehTYigqPA4Y/BCgowuP9tvQsQI
4Wry+pgShOPwCfZtMcqrH/5S8WK3D3S9HD0qgb2+W5V/nBg2l2spLtckuG9O
5VU+EYGS6Tv8ykQKq9UunZsBImwc1GjY5VLEDnhWxvcIoaawPtveliL53pIH
1UcIyb5F82mODIygph8+bhfAPbrt+uCcDCaD6sJ0mgA71fTWD7+So35W2zJ0
g4/OO2WLxuNyHGizT2235SPE7ojayk8BsXEiXM7ysKkiSMqe3S/G2gzn40vA
D3X9fdOJwOCD4+tfZBdjVeWefbeeQEWutcufsiL8B16utuY=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$53948#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.013117066890568152`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVknsw1AkAx/eWujln8mjvkrSeZxCjs16x+t6Vt/XIK4o5s14XbmndsoR9
v36bx53NSKSOMS7pbllMHUkzONFoc7nKOUZcjpDH5TLRuT8+85n5/P2xZGZH
ppJJJBJ9l/+9UXvbvDhw2YdESrpIsdc7PvljSPfGwBGwt9PEfVsB0DSkk/es
0XHqbbdDyus4GOa/Dajg+0GkK3Iu5DLBWKR7a1MYUEb+mzca/DUK7OJSQ1dO
gRZTNftexIKbV0p6bFYMzke6UWoPsdHkK++ydo1HyIjas9SCgxr3xbrghQQ4
0Afjz5G56D4ZMRV8NAl2aTZl1XWFkM53Vj02ZMIUVzquni5Gf7d/ZpY2GWPp
4ZXLv/LQr/tGj6ZIhafg4cyzjwSwCFJrz6al44OlypooTyFWui91VFmfgwv9
WsLaCREOOknv0fZmosgySmAdKYauUVXV9lQWaPXXY3ODJEixGVU8u8xCw1hz
6F9UKQxN9R4r6TlYuFCnXlyTovlY3xLN7DwMTBN5zCYZWKd3zEr3scF6L7sv
ipaD4jysLnrHBiNgc1m9IAfnqmMM53kuPLyU7SUpCujoU/TNh7+FI/Xl0/zf
FGAYVWi1LRws/pzY2ORAgPPoyjtTeR6mIr6MobEIjJQ6eX+Sn4/pzezy1UYC
kzNRcpNYLtyUTxuiBwkccif9PRJQgLJG17HJ5wS8TtJ/OuBWiNA3ogXqJIH9
8/riTOMLuNFnUDLwiICpMjkrh1yEf0imHlwNgYn+sOSSmSJU1jRu7S0lUHxn
qNfqbjFmWjyMds4QYLQ+cObeLIFKbfndnAmBcY+kW+MED+SV7+ONtQr4T/tY
rPvwYb5ltPFpgQK815dyeLf4sAlcW/KlKtA82bE+bibAq17jkaUeOeaHqkky
lQAuhyP2O4XJsYc8oPLWFcKRVpscPi2D57HOtsBiIXojwz6fS5YhIZSlY7kh
RIaqVvPHrBSJrTkT20wRniS12nZmSMHRd/ehTYigqPA4Y/BCgowuP9tvQsQI
4Wry+pgShOPwCfZtMcqrH/5S8WK3D3S9HD0qgb2+W5V/nBg2l2spLtckuG9O
5VU+EYGS6Tv8ykQKq9UunZsBImwc1GjY5VLEDnhWxvcIoaawPtveliL53pIH
1UcIyb5F82mODIygph8+bhfAPbrt+uCcDCaD6sJ0mgA71fTWD7+So35W2zJ0
g4/OO2WLxuNyHGizT2235SPE7ojayk8BsXEiXM7ysKkiSMqe3S/G2gzn40vA
D3X9fdOJwOCD4+tfZBdjVeWefbeeQEWutcufsiL8B16utuY=
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$53948#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.013117066890568152`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {19}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0075833333333333326`,
    0.008666666666666666, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.0018644318321832706`}, {
   0.0036876886214778624`}, {0.005429815153356174}, {0.007053357764066122}, {
   0.008524729334094025}, {0.009815593418634016}, {0.010904253703901247`}, {
   0.011776620504141631`}, {0.012426913422448983`}, {0.012857731971128833`}, {
   0.013079419057084953`}, {0.013109039052227827`}, {0.012683846630763284`}, {
   0.011787555304705316`}, {0.01062464586507396}, {0.009362830205797328}, {
   0.008119625649188394}, {0.0069655110558750925`}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662624496599176*^9, 3.799212565011959*^9, 
  3.7992126767249527`*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"67ca01b3-485d-4dfc-b14f-7aacc732ea1a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "VE", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "VE", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626235494568357`*^9, 
   3.6626235537922993`*^9}, 3.799212531123786*^9},
 CellLabel->"In[50]:=",ExpressionUUID->"bc47da5d-ca01-4d8c-8301-7c1274c233c7"],

Cell[BoxData["603.0651370531962`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624496679113*^9, 3.7992125650365887`*^9, 3.799212676779603*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"9fbb59bc-89b2-452c-8040-a9df27012f00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "VE", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}, 3.480262070375884*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"f177b1a4-497f-4cd3-a2b6-4e2abe2cce05"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4lOsbB3CHQrYsWVORVhGFUuGLpA3hIJVUKrQgzDDvLPZt3lQqKkRE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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.013119230033113495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.480262195466113*^9, 3.480692274101901*^9, 
  3.481941952516597*^9, 3.662624496743587*^9, 3.7992125650886*^9, 
  3.7992126767896137`*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"c07c4d54-6518-48ed-ab6d-e551f6bb39f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fz", "[", 
  RowBox[{"VE", ",", "0.0064"}], "]"}]], "Input",
 CellChangeTimes->{{3.45375087506522*^9, 3.453750875607725*^9}, 
   3.453823640650034*^9, 3.453837393601057*^9, 3.45383890126833*^9, 
   3.4538394359743757`*^9},
 CellLabel->"In[52]:=",ExpressionUUID->"d9a8c6be-6da5-4103-bcc6-df8f9e62e8bc"],

Cell[BoxData["0.013117074132794832`"], "Output",
 CellChangeTimes->{
  3.453749602972189*^9, 3.453749666574046*^9, 3.453750876352957*^9, 
   3.453752731604185*^9, 3.4538236694422503`*^9, 3.4538259483409157`*^9, 
   3.453826469350016*^9, {3.4538373992114477`*^9, 3.4538374256931763`*^9}, 
   3.453837477368595*^9, 3.453838646018355*^9, {3.453838905538686*^9, 
   3.453838910306279*^9}, 3.453839436745421*^9, 3.463844880639366*^9, 
   3.4802621955329037`*^9, 3.4806922741384277`*^9, 3.481941952544153*^9, 
   3.662624496811386*^9, 3.799212565098648*^9, 3.799212676829167*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"e2d42dd6-b9ab-4a74-a4be-ac5c9e8e7968"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oldsweetspot", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.0254"}], "*", 
    RowBox[{"0.205", "/", "2"}]}], "-", 
   RowBox[{"0.0254", "*", "0.12"}], "-", "0.001115", "+", 
   RowBox[{"0.003175", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.4537508826011543`*^9, 3.453750883775889*^9}, {
  3.4537527418735323`*^9, 3.453752742503742*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"c841c6ca-eda9-4bed-9488-ff5a80345e79"],

Cell[BoxData[
 RowBox[{"-", "0.0051790000000000004`"}]], "Output",
 CellChangeTimes->{
  3.4537496030114202`*^9, 3.453749666610465*^9, {3.453750887396463*^9, 
   3.453750909722947*^9}, 3.4537527433073397`*^9, 3.4538236694697313`*^9, 
   3.453825948369759*^9, 3.453837425726906*^9, 3.453838918528926*^9, 
   3.4638448806922894`*^9, 3.480262195562632*^9, 3.4806922741597643`*^9, 
   3.481941952586825*^9, 3.662624496879122*^9, 3.7992125651519547`*^9, 
   3.799212676836163*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"62eaa40d-b5f0-41ff-9961-4d83aecc2430"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", "oldsweetspot"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4537509122631893`*^9, 3.45375094919713*^9}, {
   3.453823640684885*^9, 3.453823640735626*^9}, {3.453826474859961*^9, 
   3.45382647576938*^9}, 3.4538373936510477`*^9, 3.453838901300256*^9},
 CellLabel->"In[54]:=",ExpressionUUID->"852f2c59-3560-4124-807e-a41c924f82e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.026008`", ",", 
   RowBox[{"-", "0.012695220225685581`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453750950353718*^9, 3.453823671960964*^9, 
  3.453825948604528*^9, 3.453826476451028*^9, 3.453837425763947*^9, 
  3.453838918661368*^9, 3.4638448807548018`*^9, 3.4802621956072607`*^9, 
  3.480692274189659*^9, 3.4819419526252537`*^9, 3.662624496930757*^9, 
  3.799212565160301*^9, 3.799212676876684*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"289ca90e-9214-4b3f-be45-d98c5cee5403"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.010"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751088575416*^9, 3.453751089087048*^9}, 
   3.453823640769184*^9, 3.453837393699996*^9, 3.453838901333053*^9},
 CellLabel->"In[55]:=",ExpressionUUID->"ee93f305-a43a-4d89-be9d-92f02104aeb3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.025353`", ",", 
   RowBox[{"-", "0.01033713033781032`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.453749683527301*^9, 3.45375109040812*^9, 
  3.4538236722686167`*^9, 3.453825948821306*^9, 3.45382648659874*^9, 
  3.453837425793631*^9, 3.453838918742206*^9, 3.463844880837522*^9, 
  3.4802621956487217`*^9, 3.480692274215329*^9, 3.481941952668998*^9, 
  3.662624496982448*^9, 3.799212565207038*^9, 3.799212676929386*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"4e769f50-e69c-41bd-a90b-5a5dd23ea91c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"fz", "[", 
   RowBox[{"VE", ",", 
    RowBox[{"-", "0.003"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.453751094726705*^9, 3.453751095317946*^9}, 
   3.453823640822011*^9, 3.453837393750527*^9, 3.453838901368658*^9},
 CellLabel->"In[56]:=",ExpressionUUID->"f54f6b89-9c65-45e5-b085-01740ff4004d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.02436`", ",", 
   RowBox[{"-", "0.009243782811928641`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537496838232193`*^9, 3.4537510967086277`*^9, 
  3.453823672557324*^9, 3.4538259490222588`*^9, 3.4538264890979757`*^9, 
  3.453837425851626*^9, 3.4538389187839413`*^9, 3.46384488093897*^9, 
  3.480262195696735*^9, 3.480692274248917*^9, 3.48194195271663*^9, 
  3.662624497032889*^9, 3.799212565296081*^9, 3.799212676971652*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"28386815-fcb1-46ed-9f32-4a8c90c71d82"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"548ecba9-2816-4f3d-b1ee-\
a36844dfb2ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9},
 CellLabel->"In[57]:=",ExpressionUUID->"854f4323-71fb-46f6-9e95-f9c32d166838"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk4VN8fB3BRlFSIQgilQkklSvgIWQpZCkm2kkK2McydYWwzmJvIN+1Z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       "]]},
     Annotation[#, "Charting`Private`Tag$54308#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.01311922838888413, 0.013119230426461693`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.46384489286368*^9, 3.4802622059949303`*^9, 3.480692283838723*^9, 
   3.481941962908568*^9, 3.662624508597904*^9, 3.79921256536007*^9, 
   3.799212686463931*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"a79b417b-4ae9-48a0-9378-df332c79371e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"a531a3ec-79d9-4e67-a8a0-42db602ff2ca"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV13k8lFsYB3AqbguhEBFu5BLXliLJryRJKkuR0mKrKEthzPvOyDaDeSVL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       "]]},
     Annotation[#, "Charting`Private`Tag$80728#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.013119229771598732`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.463844900055211*^9, 3.480262212578673*^9, 3.48069228997019*^9, 
  3.48194196963024*^9, 3.66262451582117*^9, 3.79921256539148*^9, 
  3.7992126922677517`*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"53d17c3d-53b9-4d57-a258-b67cbb51f84a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSdata", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"FindMinimum", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"fz", "[", 
      RowBox[{"VE", ",", "p"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, {3.453862450307226*^9, 3.45386248039209*^9}, {
   3.453862568949154*^9, 3.453862570115514*^9}, {3.45386264847299*^9, 
   3.453862649636854*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"da98ea8e-ec18-4fb9-bbee-2bc2c2834481"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.013119230572841655`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.006315454195954644`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453840162093855*^9, 3.4538402359560423`*^9, {
   3.4538624679971113`*^9, 3.4538624812382927`*^9}, 3.453862586264966*^9, 
   3.453862659344542*^9, 3.453862832601221*^9, 3.463844900650577*^9, 
   3.480692290440241*^9, 3.481941970310296*^9, 3.662624516428594*^9, 
   3.7992125654098177`*^9, 3.799212692813489*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"f4372525-8fc8-4149-8868-8efcf9a14d8e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpos", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"p", "/.", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862483701729*^9, 3.4538625105182133`*^9}, {
  3.453862576749049*^9, 3.453862581411574*^9}, {3.453862650555091*^9, 
  3.45386265144018*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"d60bd202-0290-480e-b2e6-e79e6533ec6f"],

Cell[BoxData["0.006315454195954644`"], "Output",
 CellChangeTimes->{{3.4538625068641663`*^9, 3.4538625109082727`*^9}, 
   3.4538625864136257`*^9, 3.453862659454235*^9, 3.4538628327231894`*^9, 
   3.463844900679907*^9, 3.480692290473279*^9, 3.481941970349381*^9, 
   3.6626245164738493`*^9, 3.799212565472928*^9, 3.799212692820784*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"e1794821-e2e5-462f-882c-7b467238ae0c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], " ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"SSdata", "[", "VE", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.453862473476694*^9, 3.453862474190342*^9}, {
  3.453862598812314*^9, 3.453862615921789*^9}, {3.453862652024186*^9, 
  3.4538626531996193`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"4c9c9ec2-9442-4edb-8b9c-33797d9b231d"],

Cell[BoxData["0.013119230572841655`"], "Output",
 CellChangeTimes->{3.453862616387323*^9, 3.4538626595105743`*^9, 
  3.453862832777169*^9, 3.4638449007258987`*^9, 3.4806922905067368`*^9, 
  3.481941970402519*^9, 3.6626245165282593`*^9, 3.799212565485951*^9, 
  3.799212692855546*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"b098591c-d6ec-4590-b479-d57786fcf1a4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for alternate value-engineered LIGO-I", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 
  3.4538410760356073`*^9}},ExpressionUUID->"82586c70-4af1-4da1-b79a-\
96177a9bd8e0"],

Cell[CellGroupData[{

Cell["\<\
VE2vals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.334*0.0254, (* 0.334=0.498-0.164, increased from 0.302 *)
\t\tcoilarea->0.347*0.164*0.0254^2, (* desired area, same as VEvals *)
\t\tcoildr->coilarea/(0.207*0.0254), (* desired difference in radius for \
desired area and length from OOvals *)
\t\tcoilrad2->coilrad1+coildr, (*  *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"dfd7ef58-4e21-45e6-92c1-45dafe32170f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0084836`"}], ",", 
   RowBox[{"coilarea", "\[Rule]", "0.00003671476528`"}], ",", 
   RowBox[{"coildr", "\[Rule]", "0.006982914009661837`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.015466514009661838`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.089479932527026`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.481941970502873*^9, 3.662624516578066*^9, 
  3.799212565535537*^9, 3.7992126928651*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"67c648db-67fd-412e-a1eb-285cf30b1d35"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "VE2", "]"}], " ", ":=", " ", "VE2vals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"2d189b41-9222-4a58-8e19-ccb2814792be"],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"90754ed9-7f5e-430b-bf5c-\
44472a83d5ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"b4d67e0f-c1af-4f6b-88d6-e95aa3eb5c9f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk4VN8bAHDZKiVEWdJCEhKSZO2VpYREklAiKtnXmTv2ZsbcW0kLSiW0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       "]]},
     Annotation[#, "Charting`Private`Tag$98466#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.011911333952159105`, 0.0119113346320878}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.4819419881990843`*^9, 3.662624531874794*^9, 3.799212565596328*^9, 
   3.7992127058594303`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"2721820f-bf87-46cf-9728-8e451bf2bb88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"VE2", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9},
 CellLabel->"In[65]:=",ExpressionUUID->"e7191882-4686-421a-b6f1-453a24ea51af"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3DpSwhFElJEqfQ18hOSvKRhlFVWVkYqe91x7r0K917u0UCK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       "]]},
     Annotation[#, "Charting`Private`Tag$125740#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.011911334644876743`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942001190299*^9, 3.6626245411818647`*^9, 3.799212565612917*^9, 
  3.7992127140092773`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"de8e7551-18c5-4eff-80af-5fc0878727ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"VE2", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9},
 CellLabel->"In[66]:=",ExpressionUUID->"8c873269-2f83-46ca-9455-031edfe1f7e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.011911334644952153`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005962869118876708`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942002157364*^9, 3.6626245418391943`*^9, 3.799212565624192*^9, 
   3.7992127145622997`*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"9ba2ec87-6e41-4d53-a52a-f69734fbd372"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SSpeak", "[", "VE", "]"}], "/", 
  RowBox[{"SSpeak", "[", "OO", "]"}]}]], "Input",
 CellChangeTimes->{{3.453865307265691*^9, 3.453865311272402*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"ba4ea7a9-e82a-4e5e-9d30-94aeec41edf7"],

Cell[BoxData["0.8271099479070351`"], "Output",
 CellChangeTimes->{3.4538653118630533`*^9, 3.463844933516652*^9, 
  3.48069231654394*^9, 3.481942002211248*^9, 3.662624541891303*^9, 
  3.799212565670024*^9, 3.799212714568256*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"70cbdc9d-3c6a-46f8-943f-62cee9a734f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for AOSEM (D0901048-v4) and LIGO-I magnet", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 
  3.4806947920213118`*^9}},ExpressionUUID->"46df04c7-2007-4642-9b1f-\
9ec7b09d28cd"],

Cell[CellGroupData[{

Cell["\<\
AOvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->lold,\t\t\t\t(* length *)
\t\ta->aold,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"1409a6fd-6943-472f-9135-d85b2b6bf26a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.00006696614374535086`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.014824999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.481942002252563*^9, 
  3.662624541953936*^9, 3.799212565684411*^9, 3.7992127146122417`*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"98686405-bdf8-4d40-ae2a-2b8e8743857c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AO", "]"}], " ", ":=", " ", "AOvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"487e2fda-2a80-4287-b27d-746da4ecf6fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AO", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, 3.6626239713916283`*^9},
 CellLabel->"In[70]:=",ExpressionUUID->"8f7817b5-563b-4f5f-af31-f465c6488b7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278972314`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6626245970991707`*^9, 3.7992125657357073`*^9, 
  3.7992127146635113`*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"cd705f4c-34f1-422c-b2e2-ffd84cbafa14"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR
qKhLm1TSSl3CzxKlRNmuJHFV3OT39Nd5vV/nPNt5Pc/3c46Wz9FtB8RERERm
iYqI/L5WynUJnNeOWuWdzHgSpa9s7XssodKzotHaM/dM9Yx149YX9vXarqno
sr5tnTu/xWYWnjSnSy2tGLEunb8yqNxGEc3JQ58XVojgXcysiQybJdjtp7JX
tUIWj4evlq22WYFzHteUlSs0YVa7Y6jNehMeOU2MKVaYwDxzuYL3Gjfc2dW1
Z1HgOlSk5GacnnkQ8+rFL379aA8nkWjLQatgPAmrH9JQcYH5FZeAVGsK15vC
4xxPu+HpZq1t4jwOzkvXyGTW7oTiRtMRpm4kHslQSv07vCBVOMfj62Q0wv81
+JN7eB9O9aRfTzWKw0mXYLH5Eb4IjL2X06mYgCdy+ycuPzyADO30VmriOMaf
XPqn8e0h1HsOK7cLE2HcLZHhMeyHqasDngXjfMT4qEZ2GwQABZ+Ze+ySsXmg
sHPdigCouc0bG3JIhnSQuXW+VQCKkpzKOC7JyAzfOuXjFIAvnnuGBbuSUSKM
5/YcDUDrbZ2AtIBktD34yu6/HgDnEsUENWEyDBb8Hfx5dSB8jF4+Um1NRmsz
x2diYxA2JF499sFdAL0FMxrmOgWBqXNYXHm3AFE+SWsXeQRh1aFqL7u9Ahh8
PaOwxS8IWenu7LxDAsTIVFbnCIJQeWGzu2GYACb203o2r4IQcue8aMlpAfgP
YscSDh2F76rSbts2Ac672q6X3BSML3+MMmdsScHiv0RWR9oH4/aqFxc8nVJQ
OOee4b+OwWg6cKPxpksKSh4Yq3a6ByPMw0xn144UlC9THSk7HIyZs8pfRB1I
Qf3PT7k7k4ORfe+HnXVkCqYKTk5cag6GluvpTl5pCqKmt3xZ2B6MHzMtBOwb
KRDbNbs39W0wVD7G2B69nQKJedxGXm8w3upWvXG7nwKF8P1Fzt+DIfVtJGO6
JgUGjqvcfqiFoMlke8WzzhTsGn9butknBHoPszs1JGlUfk18fPRgCJJ3dz6m
pWloDq9syfQPwboQRa0pGRp9fcLv/aEhKPMbdWiUpxHSvtH6RGwIEosTA3cs
pHHiXknt8wLi5aEGI8Y0yqN5ffb9IRDuR5zNdhpqEbo/Qj6FoEF9S4i3Gw0e
59Wc7C8hUIxM6z3mQWM9w8Rw8HsI5pjkHCjbTaN+fw+DLxGKNOWGhklfMv5m
B9Fa3VBY++uXKjNpKMioqzsEhCJ9bk8dL5UGjtia1weHomSN/d9UOg3/58EO
zlQo+stjRo6covEw5hnPNSIUMx+8r9iaTSPwe9C7PcJQ3JJwdRnPo1Hd9ehs
4M1QBExNq1eU0gi7cUiL/hmKQckp/tI6GhdkU9fMF2VgqMe0rfolmV/gfZe0
WQz0fd/n7dtAQ3vZ/JhMGQZuvXAxSG+i8b+cux/OaTIwx+zV/ZZ2GnoJcwtK
NzKQ5Fzp2tRDo2PHDZ2mZAbUezcqPp0k6/No3CV+koH3LV6x3/6jMer+OcUy
g4GXDIccnSkaEm5LvxfmMkDl9TVGTtMwdzlTw73GgJxotJ6UmBDJ9rGHlzQy
8JZxSNt/thCZdudzdrUwIFn7Z8sIcf7myka6nQFbb0MvlrgQdzZ9Xz3ZxYBF
gapohIQQveuOzGn4yoBNfXlSpKQQ1hbbr4TJMyGrmjO+RUYI+zXBnVeVmTgv
dfzwQ2LX1QK5jwuY0Gctvms2Twj/lTUcR20mbMXyJpVkyfjL125ZtIKJZV9n
TzTMF2JEb/FQrTsTTXsyjKQVhfhP10ZTdDcTcXHs0iDi2bqeriv3MrF7x5Bi
I7H60sz75w8x8VTFO5lWIuMvlhJQYUz478o0EVUh61kwZqiRzURs9sXsv9SE
oLiCw9fOMnGwTmAkvkAIu46lF6wuMCEus5zjSfwle4/KnhImpgQbLWarC2Gp
Vi2W9YCJtZzkw3YLhZDleFste8LEseErzzKIP76eZJfXMJH1l++7bmJ+lvHn
1kYmJr5IgPWHEG0qWW1yH5mYk3bnFa0hxJUwM7n8fiaOqLQrNhNHtL90MB1i
wjpVUV5RUwjt02KPt44zkaHma59BHKocUJIsTkFfcK00QUuITezZ/QukKazd
V/Wpilil7bxWsSyF2vGFA9+Jq061nnqhSsHa00dn/yIhpJUQPduAQndjwFPD
xUK8p17fyzChYFe0XtGT+Hor45v2Cgp1wwV6ScQ7My4d2UBywUG9tOAjscH4
+sKm9RTEB3QlZbSFEHF717VvM4WVSa9WrCIuVJBzj3KmkLnCtTueOJxZIpzn
RsGpWcynmNihxbb27E4KkUeCLzYQj6VxbSp9SH/NMbTCEiFs5Hv1JpkUKrgZ
zTSxPCPyQGI4hZZ3zmeLifuaVM+rRFC4r6VrXk0sSHVSXHWcQtzinsffib1H
B7ZWJ1H444rjfRkdIcy3xfLdhBT6c+/HaBO/mX9nmpFF4VFIGtuB+FrINosZ
Zym8elJX6EUc/b8hZmo+hZ61VMFRYlfT439pFZH56X4LjiRedlJrsLSYgoLO
XekU4v9G7mnblFLw+WgYdoa43tl9b8NNCqNL7twoIs4vHcnyqqCw+fmzquvE
lGxSy+dKCqUVj3LuE2sWnak/9JjCt4OuS54R11mVPO+upqAWeJJfR8xuuf94
dy2FN6s765qIFx15eb+1gcJV+/NDbb/HE+28vbWF5Lap1WAHcfjp4dIX7RSO
ZKhVdxJrG09f2fCO3Nc/G9VF3Phs3sXKbgqMSkO1bmLeHs1zq/ooCJYYp/2+
v3TMJKtskAJP59en3+2bEtel6X+hoKKmuOQtcYTmNsHFMbJf3jdYtxPrlvsc
1/hBYUtm+ppm4hZHRnTWTwqcgaeKL4mjemK58qIsxG5qbP69Pn1uOiWYxUL/
XhVmJfGr+RePikuyMJAz4/sN4phLt/yiZVigQn/suUxsiGrf/+RYqDroWZhL
3N76ypNSZmGfbFazkDguoN/jywIWNJTkemOIjWf8cPHTZKHMyLiDQZxgomrr
qcvC+scjrG3Ey2t0bdoMWbAa915oQ/zO08LCZTkLtbflrhj83i9Ju402rWVh
TEaFJ0b8XitgWRVYqLP+UvmJ7C/+Hd6iNRtZaDuQ399M3N2bq2ToyEJI0Zp/
zxMn867JFrmwoBM41BZPvFq+SlLLnYV/IlUu+hGn2HT9UtjLQkIEZ8qQ2KJt
5EeKLwtP4iMTZYh7A0XHJA6zUCObIzJMzoflmUX9P4NZ+MS5WXaZeMDUrJtF
saD+Lz30+3ylPd/QMRLOguJFWYV9xIPj+xt6YliwWLpAX4E407movC6dBZaI
aWwgOb/r+8vLbLNYyC3oMlpHPHzsefHDXBbsXCv/lifeWPzPuZuF5Pkc0ZZb
pF6MzjI4kXOHBdkB0dWfST1xvFe6I+AtC6c/lebrknrUPnYjKKuLBVzl5Y2Q
+rXfoDyuuoeFhw+3Vtwm5uRWlmp+ZmHDy3tmNsSXIv+WaJ1iQfSb4X47Ug/F
NvbcsdJgQyFqxTdDUl9TeP31/ovZaFATFveR+qt6a7AncykbSkO6kWeJTXS+
yo4asxHDD4mRIvaU+HW40IYNaYdrYh2qJJ/qlFXn+bAhpf3O3FmZrGfWAmPL
g6S9kuu3SZIHDVZ/bPLzZ4PffaCjgLjvmnbIk1A27iaWzf9G8kP+pOkLdiwb
3llOq1MUhAhy2xLeVcBGqVT7nQySR9qdEa/L+tnISMjpniElRBh7enz1EBtm
qqLr+ST/amWj5B6OsCHRN108jzh0Q/SW+gk2btGxZ5XnCPHwUmzloFQY/OcW
zVEneerJOJG32CQMqTtid3wneXxKItUvIywM7d8kb4yP0RjMk0tQPxaGV0uU
4qpHaVitTcu/EB0Gz6ba2IyvNHoC0zvK+GEoLy6QM/pCY3nzKcf6nDB8dZqb
YD9IoyH3jKn4ozAUKF2I1esi3wNmFyfC5oRjgOpoy/6bhmWQyvIbc8PRMdQg
u+UFjaOXk/w/zw9HY9RI7UQNjVcaoR371MKxtONg7bZnNAqkUfmnfjiSNFRn
jFXRWNfXHqXuGA6LyGUjQzdpcLKkJR4Kw2HjcTezNpfG0DRDSVyFg8qY2lu7
jtD4EeIpY6DOQU2apX2FH40ZPbazXTQ5GDaazlQ6TL73nqt+y17GgeUTCf+X
+2nYC6tajdZwkDGoP6rvRaNQUyrDfRcHi+octa460/Bely9fmMOBaah/8FNz
Gi0xjbKbtLiYcdDCzH8iBS9WxV+ZuY6HD4viL9z3S8GD/R9skhyPwcln4B27
WYCqJ5mstOAI3AnuXvtcS4Bn7W8St6RE4m3+qMyMQ8noXf7R4YBDFLZdlVMV
LU1CkFx8Qe/bKGjMauEv/sDHd0Mu54VvNOL6d052qJP/F+3VmDUQjciMvcZr
dyRC3jyvOZodg2tTaQYvo06gINKrb99UDP588+DUkvLjsOypeR6TEgtlv0QP
lXcJaImL1xVXioPdBk3zmfIJCBKRDP+YHYfwL2EOOlvjIZNhcVpEPx5jiqep
/47F4dqBqhXRZfH4XGOiSj2IhevWkfz1GxIw+1ybcsRYDH7KD/za3ZSAbQr9
XBfTGBQomL9u9ziOwRenfkpHR2O7kUHsqYHjmPfaLeJYTRTE4sKKy4+ewLcP
Jf8UakThxs2kxyb/noCorq3ESZFI+P/68/JgbCJ+VnB47OvHoBXnJSMhyUfN
iQ96VfE82Nzu6PeS5mNy60Ta6SgevAd2PLolw8e6Hon/hXJ5OOuwnekrz0dW
289q3RAe1BXt3jwg782p9kxe3h4elApNCyljPvQe/5KrMONB8vlM64+ufIjW
zU1N+MCF7mS0soUHH3UGhkGcd1zYGUyPCHfyUXng6MKj7VwcF05csPbiI0Xf
cnxXPRczdw7PyT7Eh+zK+YmWd7n49U9bqzOH9HdojcXSVC4Wqrv9VcTj43rX
qY3LBFxYOjWd+BXBR/Y+gZbeCS641+vWlsTysSFyzXaTCC5+cB7liQv4mHdx
OM3Wnwvlq9ZcL5qPt5ellzsd4GLl+3uut07y8TKOne/uzQW14ba47yk+PllJ
T/q5c5FOmXVXnObDyHBRN9OFi5tFpXdlz/ARpeiZHeXARfNrw/RDuXx82CPQ
EGzmYlSqOPDBOT42Wo3xstdz8X/PzGwq
        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AO", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, 3.662623973998605*^9},
 CellLabel->"In[71]:=",ExpressionUUID->"e162c8e4-f5a2-40d6-858a-8d9f8094479b"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662624605422865*^9, 3.799212565785183*^9, 
  3.799212714676622*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"eac8dd1d-44e8-4e88-97ff-565b65903386"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"429d9939-6034-4001-9360-c57125af8fcc"],

Cell[BoxData["0.005342368876734437`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.4819420024634247`*^9, 3.6626246054880657`*^9, 
  3.7992125657946*^9, 3.799212714711656*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"f4eac74b-5b00-45ea-a77a-67e44fd95c1c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AO", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AO", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"5b4d0698-1f1e-4aaa-ad24-9ac9c6332d15"],

Cell[BoxData["0.01577331278972314`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.4819420025016727`*^9, 3.662624605533827*^9, 
  3.799212565841427*^9, 3.799212714721059*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"ceade777-9a82-4e20-8936-ede7ca420b75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235658776608`*^9, 3.662623567527854*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"7f5887ee-98f1-42d5-b63c-2b9651d20454"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQ0wUAB/AfLy1bCjgKGA/lIcZTGVDC5leRh/KIhyhJCDQYCEzk4WA8
Nrax9/tq7gCJKDxECwiDIUaYBXQGHI7zMOEQIrsoKhJIjguw+uNzn/2MS8lM
c4IgaP/5/7WmflfuyT/pBJGVSArfe3T2RuzA2ogPmtMTNlZbk9DTmmdutUKD
Yj7t2o5kBqwrNqJ1/EhcUKsWVXaFiFuihZly4jAU4PfGj9+WoPLgO8z45SS0
zcitfOnlCA7NyTvLOoMLHp9U8U5VoS1C1ucedA7Jd+1+ooh4aAxZ+jDmt3S8
mtSU1EUXYOBE4lzMoSxQ/Q0U0wshJItGw6Q1AyuMqcuMMRGGB6IKWaZs9J8z
t6ZmSDBs+XwXVc5EWYJX/p5xKfad6ja9m5sHu9yyJoswOZYHrvQa3PPBCXTi
T5Yo4OAn+Zq6oxDn7cnEfIsSljYGw9YcC4fX9c/eu65CjseE/HFDEUIZimMt
XDWsHXdNKmnF0Hfa37wYoUH7kXt/UJ1KEHs7M485p0FR6raTencpHBp8WfO5
WpADRrtrNkvxuVcUQYxpwW72PcOeLsM9W0NC104dLEhkkuvoZZyezPe3cdEh
zkZnMn3KBuubfqbsgA7sB1c3HWXlSBQmvfzUXYcxtV+YXUUFnGmznvV2Oswu
nJbZn+XA1dnz2uCmFpQQ4tex6Er4ex998YVRi9ATtK7Xg6sQHZ/V+DBTi72L
JFGhbTUmtoZWkggtHJXZrGLzGqiCydvtCg1mht/O5i3UwLM0ffs1Gw24d+7f
dRvkYiaq8DFHp0Zcx/cBnM940DYZqPX/qDD1ZlbnlKIWKcwYCSNfhah5+r5V
Oh+66S73iCElav+6UlzbyUf4QmDxcw8l2md7V6ecBGi+vioOEiuweL+ekOoF
oLiQhvoeymFlPqIPsxTCWb3HmuQvx1tHjLdOcoXIeCUtx5sjQ3p8kcX+NSGW
eTeMlGEpzncUz2wx6nBz2MeyzEUKNimETp2pw7g647i8QIKCvsgDF2NFyFpo
8w4YEiMBzuGl/SKkCKbDn7qJETvS98vEITE4kzwjpVwEj4YmcmCLGA2GL/8+
9qgO5MKI0d/tJRj3jFne9qvDmkNPT6lWAi+zarM+pRDd5CLPrS0JeL2pG1fX
BRDvXnKdZ0txWFNgJk4TICTl1sff/SzFS1xadeooH9v1tI6dmTKY/7B+2zmI
D+MdzZLtlAyV9loWL7oWsQd9ut0i5XiSoKL0HedhXa8glF/J8UGTvLXanwt+
fNCjdT8FWPn0Jw+Ca/BMH3Jp8CMFSijvVzaGV+NfXg+nqw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$145751#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.015771990975226677`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXtQ0wUAB/AfLy1bCjgKGA/lIcZTGVDC5leRh/KIhyhJCDQYCEzk4WA8
Nrax9/tq7gCJKDxECwiDIUaYBXQGHI7zMOEQIrsoKhJIjguw+uNzn/2MS8lM
c4IgaP/5/7WmflfuyT/pBJGVSArfe3T2RuzA2ogPmtMTNlZbk9DTmmdutUKD
Yj7t2o5kBqwrNqJ1/EhcUKsWVXaFiFuihZly4jAU4PfGj9+WoPLgO8z45SS0
zcitfOnlCA7NyTvLOoMLHp9U8U5VoS1C1ucedA7Jd+1+ooh4aAxZ+jDmt3S8
mtSU1EUXYOBE4lzMoSxQ/Q0U0wshJItGw6Q1AyuMqcuMMRGGB6IKWaZs9J8z
t6ZmSDBs+XwXVc5EWYJX/p5xKfad6ja9m5sHu9yyJoswOZYHrvQa3PPBCXTi
T5Yo4OAn+Zq6oxDn7cnEfIsSljYGw9YcC4fX9c/eu65CjseE/HFDEUIZimMt
XDWsHXdNKmnF0Hfa37wYoUH7kXt/UJ1KEHs7M485p0FR6raTencpHBp8WfO5
WpADRrtrNkvxuVcUQYxpwW72PcOeLsM9W0NC104dLEhkkuvoZZyezPe3cdEh
zkZnMn3KBuubfqbsgA7sB1c3HWXlSBQmvfzUXYcxtV+YXUUFnGmznvV2Oswu
nJbZn+XA1dnz2uCmFpQQ4tex6Er4ex998YVRi9ATtK7Xg6sQHZ/V+DBTi72L
JFGhbTUmtoZWkggtHJXZrGLzGqiCydvtCg1mht/O5i3UwLM0ffs1Gw24d+7f
dRvkYiaq8DFHp0Zcx/cBnM940DYZqPX/qDD1ZlbnlKIWKcwYCSNfhah5+r5V
Oh+66S73iCElav+6UlzbyUf4QmDxcw8l2md7V6ecBGi+vioOEiuweL+ekOoF
oLiQhvoeymFlPqIPsxTCWb3HmuQvx1tHjLdOcoXIeCUtx5sjQ3p8kcX+NSGW
eTeMlGEpzncUz2wx6nBz2MeyzEUKNimETp2pw7g647i8QIKCvsgDF2NFyFpo
8w4YEiMBzuGl/SKkCKbDn7qJETvS98vEITE4kzwjpVwEj4YmcmCLGA2GL/8+
9qgO5MKI0d/tJRj3jFne9qvDmkNPT6lWAi+zarM+pRDd5CLPrS0JeL2pG1fX
BRDvXnKdZ0txWFNgJk4TICTl1sff/SzFS1xadeooH9v1tI6dmTKY/7B+2zmI
D+MdzZLtlAyV9loWL7oWsQd9ut0i5XiSoKL0HedhXa8glF/J8UGTvLXanwt+
fNCjdT8FWPn0Jw+Ca/BMH3Jp8CMFSijvVzaGV+NfXg+nqw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$145751#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.015771990975226677`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {22}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.002736965202036054}, {
   0.005376030254553376}, {0.007826552614291075}, {0.01001159606434724}, {
   0.011872863945006773`}, {0.013373609984324762`}, {0.01449929993257453}, {
   0.015256117250269213`}, {0.01566770933309047}, {0.015770789908488913`}, {
   0.015610306666795384`}, {0.015234823589392852`}, {0.014692617726235247`}, {
   0.0140287505643306}, {0.013283178230669233`}, {0.012489794780202257`}, {
   0.01167621494091271}, {0.010864077036726108`}, {0.009304649284073284}, {
   0.007891430464800061}, {0.006655314612367335}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246067933207`*^9, 3.799212565930393*^9, 
  3.799212715805522*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"4369f629-eb1c-4744-9010-91b39cc1c9f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AO", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AO", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AO", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623569112307*^9, 
   3.662623572807571*^9}, 3.799212531131391*^9},
 CellLabel->"In[75]:=",ExpressionUUID->"4bf6b1ea-d75e-4ae1-b0e8-b869c889ad9f"],

Cell[BoxData["919.3132929763831`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624606848462*^9, 3.799212565984627*^9, 3.799212715855835*^9},
 CellLabel->"Out[75]=",ExpressionUUID->"469a9b71-257c-4a87-a055-6d5c839ca70f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"plot", "[", "AO", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fmax", "[", "AO", "]"}], "-", 
      RowBox[{"0.5", "*", 
       RowBox[{"coupling", "[", "AO", "]"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", 
          RowBox[{"zmax", "[", "AO", "]"}]}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "0.", ",", "0.013"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Red"}], "}"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.66284663709056*^9, 3.662846643001965*^9}, 
   3.7992125311324997`*^9},
 CellLabel->"In[76]:=",ExpressionUUID->"f61de3d9-71a3-4818-af8b-1595bc09f16a"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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      "]]}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV1nk4lN0bB3BJtmQtSyhKhUil3fIl7aGUUtJGKrLPPDMGEcPEYJ6pCKVI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        "]]},
      Annotation[#, "Charting`Private`Tag$145803#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.6628466519886923`*^9, 3.799212566044846*^9, 
  3.799212715906108*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"743adc85-6d92-4f38-b227-9c4f226a5351"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"0049aa13-92b2-432b-b51a-\
22a4c957b0b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9},
 CellLabel->"In[77]:=",ExpressionUUID->"d87e340b-f959-45cb-b783-62f31ee81cd3"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk0VO8fB3BRhJA9UqESKm2SpD5FCklaJES0SckyM3fGmm0GWeaOrVRa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       "]]},
     Annotation[#, "Charting`Private`Tag$145906#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.015773312770077808`, 0.015773310655553992`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.481942019293109*^9, 3.662624620495331*^9, 3.799212566076847*^9, 
   3.7992127281406612`*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"f985c3c3-44b9-4602-8dae-f5db98d03a18"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AO", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9},
 CellLabel->"In[78]:=",ExpressionUUID->"bf29ff74-3fde-4839-941c-f36d95b618c9"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk01VsUB3DyEiFDKCIyNXlIXiO+SgmVKWUoSoZCct17fz+XZOpeme8l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       "]]},
     Annotation[#, "Charting`Private`Tag$172326#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.015773312580828865`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.481942029259119*^9, 3.6626246289498587`*^9, 3.799212566105277*^9, 
  3.799212736159642*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"f3b7b127-c6d3-4a9c-baeb-77dc63200808"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AO", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"bc34bb23-ffa4-4c43-9f52-1efa7479be62"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278970189`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005342364901626687`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.481942029872281*^9, 3.662624629579126*^9, 3.799212566119658*^9, 
   3.799212736690179*^9},
 CellLabel->"Out[79]=",ExpressionUUID->"590f40bb-dbc9-4ed7-8038-cf209a141dfa"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and extra small, \[OSlash]2 mm x 0.5 mm \
magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
   3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
   3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
   3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
   3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, 
   3.480699179006065*^9},ExpressionUUID->"b7ab0cf5-cedb-47b9-b53a-\
ccf94e68fe80"],

Cell[CellGroupData[{

Cell["\<\
AOESvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.0005,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.480699187974929*^9, 3.480699197276938*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"b19586bb-2c7d-4055-af11-8df359e66e66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.000011623892818282234`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.017499999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.0005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699218382852*^9, 3.481566729144149*^9, 3.481942029907995*^9, 
  3.6626246296430073`*^9, 3.799212566169499*^9, 3.799212736698094*^9},
 CellLabel->"Out[80]=",ExpressionUUID->"caa8ba38-6532-4073-bbf8-1874a816c133"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AOES", "]"}], " ", ":=", " ", "AOESvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"c52d5242-bbcc-40db-a078-c25af1a1a30f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.002807824198073727`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AOES", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, 3.480699359418405*^9},
 CellLabel->"In[82]:=",ExpressionUUID->"9d4f343d-a4ba-47fb-921e-e99e5a4ea1c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.002807824198073727`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005198473408953153`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.4806993237886267`*^9, 
  3.4806993994484053`*^9, 3.48156682235257*^9, 3.481942029984186*^9, 
  3.662624679655575*^9, 3.79921256622328*^9, 3.799212736738921*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"1e3f206c-0c5c-47b9-ac24-4ec01a6f309e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AOES", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, 3.480699363708275*^9},
 CellLabel->"In[83]:=",ExpressionUUID->"a06c1d25-0451-4c24-b8a2-00e990c77f60"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3Bxi0qSypBuKIXiRikUvgglQ5mHUqazKeI45+zjGDJHjkhF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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.002807824129332503}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699332309153*^9, 
  3.480699399566325*^9, 3.481566829952278*^9, 3.481942030040433*^9, 
  3.662624688188848*^9, 3.7992125662863483`*^9, 3.799212736777196*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"b634b4f9-2370-485b-a3d9-7e54bf4fa965"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"ef704f4c-43be-4ad3-afed-5069b47c3194"],

Cell[BoxData["0.005198473408953153`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.480699332401712*^9, 
  3.481566830010151*^9, 3.48194203006644*^9, 3.6626246882658*^9, 
  3.799212566296227*^9, 3.799212736786602*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"ff937244-c362-4dfc-8d47-a3e9b178c008"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AOES", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AOES", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"d9119b47-bb99-4d17-b0c5-4e3ac9c41aa2"],

Cell[BoxData["0.002807824198073727`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699332444682*^9, 
  3.481566830040126*^9, 3.481942030118945*^9, 3.662624688341494*^9, 
  3.799212566344317*^9, 3.799212736823483*^9},
 CellLabel->"Out[85]=",ExpressionUUID->"64b9a2fc-9d8f-4001-8180-a1c6db65feff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.6626235829632797`*^9, 3.662623584946313*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"17ec380f-903d-48ad-840f-942a66457bc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkWlM0wcARxuk4EhRinUIY+Xw4J5oETna/ogFhAKCUK5xWGj7By1yOS6l
3JQWwmGsRNSpG4boNsQyhMk4dA4GYmB1SREKg2nIcMgpDgiHYx9e3pf37VnE
pwSLtEgkEnOb/71887GZxGeORSI9+SvN4x1r/L5fx3KvHeZCjvd5TdqgpT5B
i7zExPBPkd1Gf7rBIGvtZE2BF9bpdeQroxz4zzDdVUJ/+Ht6GI/v5CLHOkIU
MH8aouZJTpBvEI65CRPCkkLh7lil1GeFoMFT1rbfKRLfefhsNQeF4brzzNfc
f6LBo9sYGR2JRAcnaILryEeYnG01/HMUpNOttS8N4jFtYf6GHBKLng5vcZJK
gPSRGSuhLx892v/qMeQi+OYqgiZOxcHcV6mKIhIQbeUztHA6HvMdVx/V7j8L
LqXPJcZeAGMH6ROGjhiLrqt8yUcBtKm1tZsTSTCw7Uyr/lEI4YEh+UhdMv5Y
i7Nt8hTBwETvZQUzFbOWdwSj/SLcc306yzBNQ4puJoPkSCA5fMu0clc6vqWm
qgqkBGiHB5S5G+nI6S5k058RyLhlH5oxegHdxZqpqGkCOyg0itnAV7ANrV6f
2iDgT61Rqb7PAG9CXnB5a7v//caGiSwTmSkfn99dIPCi0sF9b1YWspYHJWwV
gfHXIbJ9YdkoY0c8tG8g8Jkz6e2LkzloWKDUj50l4MZhNhkduwjq6NI5tiWB
PdOUErHhJXxKFbeT1SKYVAiSUrVy0Rf8odrnogianlOCvNe5WDIJpP1iKoKk
vb/bskuCoSm6pKFdCP/G54ezf8iDTXFeM40rhPo4/4G6PB/SL1YHdMcF8J5k
mb9nFaDTo/K2q0CA/IWrqfkPCpAY4KbmzMXj3vij92rTQszfX9E5kbP9sf8a
qUxRiDevCp0urcaBrNWrcNcuQl9L2fRafhxcXFubfSRFGPxE/iFqk4/ogOQd
FstFkK0qhVQJHzGNqZrN+GIs6cv1e8h8ZFCcWQxNMQLuPgu/oncG59q8Dp33
K0EbXaR/gR6LQHx+Iv1xCdhVY7vZbjHw6237e8ixFNaF1qsc72gcqLtJO3qn
FHYjcsNEIgo0sefAu31StGkSH8Zmf4ll45aW9Gop1p/WL3QoIqGkJR/c3JRi
8GBmkbgnAqW7ZswmM8rAPb/YN/s2HM685m9+myqDxuuQnotlOLauMRt1z8iw
t+7ynluBYWhtr5oxVMtwI6mraUwaCj9rO6Wllxy/6uweoKl4WFGUkyo65Sip
YnjYGfJQEOA0vOJQjqNTvCOvRCFYVDindN0uR/f1GpW4Mxj/AfSor1Q=
                   
                   "]]}, Annotation[#, 
                  "Charting`Private`Tag$191528#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.0028069345319713754`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkWlM0wcARxuk4EhRinUIY+Xw4J5oETna/ogFhAKCUK5xWGj7By1yOS6l
3JQWwmGsRNSpG4boNsQyhMk4dA4GYmB1SREKg2nIcMgpDgiHYx9e3pf37VnE
pwSLtEgkEnOb/71887GZxGeORSI9+SvN4x1r/L5fx3KvHeZCjvd5TdqgpT5B
i7zExPBPkd1Gf7rBIGvtZE2BF9bpdeQroxz4zzDdVUJ/+Ht6GI/v5CLHOkIU
MH8aouZJTpBvEI65CRPCkkLh7lil1GeFoMFT1rbfKRLfefhsNQeF4brzzNfc
f6LBo9sYGR2JRAcnaILryEeYnG01/HMUpNOttS8N4jFtYf6GHBKLng5vcZJK
gPSRGSuhLx892v/qMeQi+OYqgiZOxcHcV6mKIhIQbeUztHA6HvMdVx/V7j8L
LqXPJcZeAGMH6ROGjhiLrqt8yUcBtKm1tZsTSTCw7Uyr/lEI4YEh+UhdMv5Y
i7Nt8hTBwETvZQUzFbOWdwSj/SLcc306yzBNQ4puJoPkSCA5fMu0clc6vqWm
qgqkBGiHB5S5G+nI6S5k058RyLhlH5oxegHdxZqpqGkCOyg0itnAV7ANrV6f
2iDgT61Rqb7PAG9CXnB5a7v//caGiSwTmSkfn99dIPCi0sF9b1YWspYHJWwV
gfHXIbJ9YdkoY0c8tG8g8Jkz6e2LkzloWKDUj50l4MZhNhkduwjq6NI5tiWB
PdOUErHhJXxKFbeT1SKYVAiSUrVy0Rf8odrnogianlOCvNe5WDIJpP1iKoKk
vb/bskuCoSm6pKFdCP/G54ezf8iDTXFeM40rhPo4/4G6PB/SL1YHdMcF8J5k
mb9nFaDTo/K2q0CA/IWrqfkPCpAY4KbmzMXj3vij92rTQszfX9E5kbP9sf8a
qUxRiDevCp0urcaBrNWrcNcuQl9L2fRafhxcXFubfSRFGPxE/iFqk4/ogOQd
FstFkK0qhVQJHzGNqZrN+GIs6cv1e8h8ZFCcWQxNMQLuPgu/oncG59q8Dp33
K0EbXaR/gR6LQHx+Iv1xCdhVY7vZbjHw6237e8ixFNaF1qsc72gcqLtJO3qn
FHYjcsNEIgo0sefAu31StGkSH8Zmf4ll45aW9Gop1p/WL3QoIqGkJR/c3JRi
8GBmkbgnAqW7ZswmM8rAPb/YN/s2HM685m9+myqDxuuQnotlOLauMRt1z8iw
t+7ynluBYWhtr5oxVMtwI6mraUwaCj9rO6Wllxy/6uweoKl4WFGUkyo65Sip
YnjYGfJQEOA0vOJQjqNTvCOvRCFYVDindN0uR/f1GpW4Mxj/AfSor1Q=
                   
                   "]]}, Annotation[#, 
                  "Charting`Private`Tag$191528#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.0028069345319713754`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {16}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.004333333333333333, 0.005416666666666667, 0.0065, 0.0075833333333333326`,
    0.008666666666666666, 0.00975, 0.010833333333333334`, 
   0.011916666666666666`, 0.013}}, {{0.}, {0.0005016661137573716}, {
   0.0009842959308477655}, {0.0014303302051011844`}, {
   0.0018250102805042352`}, {0.002157399470547845}, {
   0.0024209766904133407`}, {0.0027377720363055197`}, {
   0.002803854187632368}, {0.002684795884917627}, {0.0024536167769683764`}, {
   0.0021713112937943005`}, {0.0018801200172207425`}, {
   0.0016050036191860876`}, {0.001358194750877934}, {
   0.0011437942978251277`}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626246894085207`*^9, 3.799212566435601*^9, 
  3.799212737703001*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"667c9523-fc6d-4825-b4d5-b50f99a7d67d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AOES", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AOES", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AOES", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623586641572*^9, 
   3.662623589762891*^9}, 3.7992125311352167`*^9},
 CellLabel->"In[87]:=",ExpressionUUID->"71f8cc29-6a67-4f1f-8629-2e048d5742fa"],

Cell[BoxData["169.0060726375998`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624689486725*^9, 3.799212566446608*^9, 3.799212737753663*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"33d7ba88-3285-4728-a753-27da43f4b72e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"671e63b2-895c-417b-b8b0-\
1aa4e7ad2546"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9},
 CellLabel->"In[88]:=",ExpressionUUID->"f3feb58d-577f-4328-83e7-9422619e6a79"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk0VP//B3DZKhXSoiRJK5WQVKhXoQUlZStlrHNlyTIzd2YYSxhLKFlK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       "]]},
     Annotation[#, "Charting`Private`Tag$191641#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.002807823986434553, 0.0028078241960445755`}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699347175211*^9, 3.481566843006109*^9, 
   3.481942047830917*^9, 3.662624703720014*^9, 3.7992125665071373`*^9, 
   3.799212750152135*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"8c48605e-afc9-497f-9703-68c0ae989b87"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AOES", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9},
 CellLabel->"In[89]:=",ExpressionUUID->"52d51435-012e-48ca-8a75-f644918ad052"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk8lNsfB3AqIpSyFL+KXEmbpG5KzKeQ0CZLpIxlzJOsY2aeMShb0yKS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       "]]},
     Annotation[#, "Charting`Private`Tag$217939#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.0028078240720868976`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699356475226*^9, 3.481566851563313*^9, 
  3.481942060181831*^9, 3.662624712512875*^9, 3.7992125665384007`*^9, 
  3.7992127578078413`*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"c56c0d50-a54c-4ad2-beea-248d07a556cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AOES", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"58668235-e7ab-469b-a144-2d91f6ec5bda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0028078241980691245`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.0051984702551490704`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.4806993585664883`*^9, 3.481566852005377*^9, 
   3.481942060656612*^9, 3.662624712959793*^9, 3.799212566553184*^9, 
   3.799212758196513*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"966b3c14-7399-4ff4-bc7e-86b6ece71158"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for AOSEM (D0901048-v4) and (approximately) double length, \
\[OSlash]2 mm x 6 mm magnet\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, {
  3.45382361286519*^9, 3.4538236144707003`*^9}, {3.453838874626217*^9, 
  3.4538388807274017`*^9}, {3.453841072413919*^9, 3.4538410760356073`*^9}, {
  3.48069476991868*^9, 3.4806947920213118`*^9}, {3.480695820456702*^9, 
  3.4806958224791937`*^9}, {3.480699030573723*^9, 3.480699039227467*^9}, {
  3.480699105085774*^9, 3.480699140273758*^9}, {3.480699240398816*^9, 
  3.4806992456450768`*^9}, {3.4806992858633623`*^9, 
  3.480699289781164*^9}},ExpressionUUID->"ea161608-72ba-489b-84b2-\
a25ca58a24b6"],

Cell[CellGroupData[{

Cell["\<\
AODLvals = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.006,\t\t\t\t(* length *)
\t\ta->0.002/2,\t\t\t(* radius *)
\t\t(* coil length *)
\t\tcoillen->0.207*0.0254, (* D0901048-v4 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.304*0.0254, (* D0901048-v4 *)
\t\tcoilrad2->0.996/2*0.0254, (* D0901048-v4 *)
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453819143842659*^9, 3.45381916873015*^9}, {
   3.453819205916604*^9, 3.453819229397924*^9}, {3.4538192680904627`*^9, 
   3.453819317992671*^9}, {3.453819379538721*^9, 3.453819381962309*^9}, {
   3.453819414835219*^9, 3.453819449256628*^9}, {3.453823205503562*^9, 
   3.453823222597754*^9}, {3.453826073117807*^9, 3.453826150751071*^9}, 
   3.4538373389188223`*^9, 3.453841092308299*^9, {3.453841283965046*^9, 
   3.4538412881475286`*^9}, {3.4538413725493402`*^9, 
   3.4538413849806833`*^9}, {3.453841501978483*^9, 3.453841779519685*^9}, {
   3.480274240165839*^9, 3.480274249772677*^9}, 3.480694811626128*^9, {
   3.4806948459029713`*^9, 3.480694858042783*^9}, {3.480694900775441*^9, 
   3.480694950070912*^9}, 3.480695858267105*^9, {3.480696997173448*^9, 
   3.48069702724988*^9}, {3.48069930379321*^9, 3.480699340598193*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"833a7cc4-7698-419b-8138-47a32295faaf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0001394867138193868`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.011999999999999999`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.006`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.005257799999999999`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.0026288999999999996`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.0026288999999999996`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.0077215999999999995`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.0126492`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.5439046765338914`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4538417843516493`*^9, 3.463844900775058*^9, 
  3.480692290540955*^9, 3.480695055734477*^9, 3.480697045556779*^9, 
  3.480699411967904*^9, 3.481566894140891*^9, 3.4819420607019053`*^9, 
  3.6626247130171137`*^9, 3.799212566602963*^9, 3.799212758204702*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"b44cffa4-79c9-4737-9b61-87bfd4fda41b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "AODL", "]"}], " ", ":=", " ", "AODLvals"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, {
   3.453823624487136*^9, 3.453823640631469*^9}, {3.453837378474317*^9, 
   3.453837393571328*^9}, {3.4538388861923847`*^9, 3.453838889904484*^9}, {
   3.453841247783547*^9, 3.4538412572609777`*^9}, 3.4538417923838587`*^9, {
   3.480694812819429*^9, 3.480694813277412*^9}, {3.4806958602050734`*^9, 
   3.480695860693163*^9}, {3.480699304968781*^9, 3.480699305631609*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"be4e8432-0b2c-4c7b-8ead-9006ac266c55"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.01577331278972314`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"AODL", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, {3.4806950416816607`*^9, 
   3.48069504236414*^9}, 3.4806950855740757`*^9, 3.480695391023115*^9, {
   3.480695424453774*^9, 3.480695426213916*^9}, {3.4806958612576303`*^9, 
   3.480695861809552*^9}, 3.480697041276504*^9, {3.480699306305072*^9, 
   3.480699307040391*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"ef0bc78a-c785-440d-86b2-44ebe6c8e09d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.01577331278972314`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005342368876734437`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4806971192435513`*^9, 3.480699516644302*^9, 
  3.481566985502486*^9, 3.481942060779174*^9, 3.662624769885214*^9, 
  3.7992125666558647`*^9, 3.799212758243636*^9},
 CellLabel->"Out[93]=",ExpressionUUID->"052ca5fc-976e-469a-b891-0999568533d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"AODL", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, {3.480695043059854*^9, 3.480695043824891*^9}, 
   3.480695087059374*^9, 3.480695404783731*^9, {3.4806958623058577`*^9, 
   3.480695862857663*^9}, 3.4806970427358437`*^9, {3.480699307709909*^9, 
   3.4806993083441687`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"7be5236c-19c8-4a9a-acc4-e94c22ff0d3d"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8VOsfB3C0EJLspIuSshNtwkebuCHK0kaijRBmzgwzk50yjDNZElGR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.01577331278116163}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.48069712546273*^9, 3.480699525015361*^9, 
  3.481566993083891*^9, 3.4819420608359413`*^9, 3.6626247782161903`*^9, 
  3.799212566665503*^9, 3.799212758279677*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"5760ab03-0f85-4f64-87a5-3baee8a9b031"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}, {3.480695044500922*^9, 3.480695045299432*^9}, {
   3.48069586344763*^9, 3.480695864000742*^9}, {3.4806993090802107`*^9, 
   3.480699309671587*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"61afc4f0-c899-47cb-b3ea-0b99486537da"],

Cell[BoxData["0.005342368876734437`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.480695182351778*^9, 3.480697125524988*^9, 3.4806995251344767`*^9, 
  3.481566993139513*^9, 3.481942060861919*^9, 3.662624778303006*^9, 
  3.799212566717863*^9, 3.799212758288528*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"364cb738-c6ca-4ef0-9608-d3e3ad0953d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}, {3.480695045805807*^9, 3.480695046244318*^9}, {
   3.480695864548365*^9, 3.4806958649909143`*^9}, {3.4806993103161793`*^9, 
   3.480699311077731*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"f1dc5dde-6f3b-400d-b913-88e2d8e5ff9a"],

Cell[BoxData["0.01577331278972314`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.480695182407237*^9, 3.480697125554319*^9, 3.480699525202236*^9, 
  3.481566993161881*^9, 3.4819420609176197`*^9, 3.662624778357869*^9, 
  3.79921256673073*^9, 3.799212758322772*^9},
 CellLabel->"Out[96]=",ExpressionUUID->"4d6a443a-ddb2-4309-a909-763cd3e2088a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623603106723*^9, 3.662623611969966*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"440efa85-b8a4-4816-83fc-a299e3eb1262"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+CU4LWPVolVsaHopWnzhtSR9NcWpY7ZYphrVUfVnNOl1FF3
5ChxRCTkqPbpObp4jrJQ6tHn6DP2HjUzpmtHoyg6rxTb/vjeZx6eyIhSIxAI
tP/8/6qk1TTTfYFOIJgtd2ebn5q876lc7bVG7qu7zJydYWi8Ha2msUyDas9P
Lz97kATdlA9uJdmueM2ofdh6NxVeKprTcKQXBI9lmgcp2bh2+Jso78WvsFom
9Z3xyIedY2S0f5wfKhctR1w12bjjwm6xsA3EAoPD//COhyqqSurxJgS19ID7
e+7woXT+csqDEoZFgWT6aVopWLPNwhHdcPTk2yf7U8rRozwXGzccgY1QX3Fo
gwA9xH922XCi0FEQcGbpEyHMziuGgy9FwwGN1j9nVWJRWdEktIjBA7uYp8db
RNhPZnXaaMYifYO7fXNeDOJeoXBzKg6/hsz0qG9XIdJyiDMuTsBRyvqh0b+q
oWu0a4RHS0Jr8TjftEuCew5db21Mvoez/ZnyhStSJARsmRTtTsazqZ1Gzw1l
IJ0YUGR8TMZlE+X7IakMTNkxP+ZvV3Axks7R3yGHujZJ23TgB/g2xfdbMeTw
2lsyPPyQiXBV3zFjlhzMX6o/GrGvojOYXN58W47BIrKTQUoKfEzVGKQ6OSZn
fNmG/qkAK89hoEYOYyphbtDtGkhl2647cuRwdKY92meXBrKWwrzCWw79We38
WL10DC7dSO3VkcOIFxGXpJaB9gFReudjGSZ6voi4PpOBlfCg2j+DZchs63ty
oCMTbQOBiVnvpfCq6z+R+uN1PMr1W19Lk2L0ZFj9KDcLTywvKxy3JTg3TTdb
oWdjm3jkqGWSBFlLFUlZ9dn4/aKS4PKyGvcmm1ZGTXJA7NBo5/hWY7ZPRCgU
5KCLEdTv1lAFDbVegRMxF1RPneMv9lXB3qG5wT0zFzdi3EOt48UI8U5QN1/N
xditN9WHukUIrUua2AzPA71+vs/ZQgSmNpVuM5GHSccWngGzEt+1uB6M98xH
xmmr8YwRIXzw6dnk1nyQ1/XqS2yE8Oxt+XuIUgCtipyzduwKWIolpM9vFoC1
/K3BizkBSLEuA/OGLIS12l4inxZgdX9jYzKfhaz457NmknIoSAlWm5ssXP1j
iyfWKEfBbpXpNLMQjnFvLfyiykD9uqHm2atC8F9vjPWPlGJLRKvTusDGkZoL
5JSTpWhuK1bpjbIx03HKsOlWCTwPWysOuHIQ3tWt8jEuwZqAS+C1cxBENZ+T
GfKR7W07tkbmoouirzNFKsY7ATWxQ87FGpG7HGhQhH8Bb+a9Xw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$237713#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687752`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+CU4LWPVolVsaHopWnzhtSR9NcWpY7ZYphrVUfVnNOl1FF3
5ChxRCTkqPbpObp4jrJQ6tHn6DP2HjUzpmtHoyg6rxTb/vjeZx6eyIhSIxAI
tP/8/6qk1TTTfYFOIJgtd2ebn5q876lc7bVG7qu7zJydYWi8Ha2msUyDas9P
Lz97kATdlA9uJdmueM2ofdh6NxVeKprTcKQXBI9lmgcp2bh2+Jso78WvsFom
9Z3xyIedY2S0f5wfKhctR1w12bjjwm6xsA3EAoPD//COhyqqSurxJgS19ID7
e+7woXT+csqDEoZFgWT6aVopWLPNwhHdcPTk2yf7U8rRozwXGzccgY1QX3Fo
gwA9xH922XCi0FEQcGbpEyHMziuGgy9FwwGN1j9nVWJRWdEktIjBA7uYp8db
RNhPZnXaaMYifYO7fXNeDOJeoXBzKg6/hsz0qG9XIdJyiDMuTsBRyvqh0b+q
oWu0a4RHS0Jr8TjftEuCew5db21Mvoez/ZnyhStSJARsmRTtTsazqZ1Gzw1l
IJ0YUGR8TMZlE+X7IakMTNkxP+ZvV3Axks7R3yGHujZJ23TgB/g2xfdbMeTw
2lsyPPyQiXBV3zFjlhzMX6o/GrGvojOYXN58W47BIrKTQUoKfEzVGKQ6OSZn
fNmG/qkAK89hoEYOYyphbtDtGkhl2647cuRwdKY92meXBrKWwrzCWw79We38
WL10DC7dSO3VkcOIFxGXpJaB9gFReudjGSZ6voi4PpOBlfCg2j+DZchs63ty
oCMTbQOBiVnvpfCq6z+R+uN1PMr1W19Lk2L0ZFj9KDcLTywvKxy3JTg3TTdb
oWdjm3jkqGWSBFlLFUlZ9dn4/aKS4PKyGvcmm1ZGTXJA7NBo5/hWY7ZPRCgU
5KCLEdTv1lAFDbVegRMxF1RPneMv9lXB3qG5wT0zFzdi3EOt48UI8U5QN1/N
xditN9WHukUIrUua2AzPA71+vs/ZQgSmNpVuM5GHSccWngGzEt+1uB6M98xH
xmmr8YwRIXzw6dnk1nyQ1/XqS2yE8Oxt+XuIUgCtipyzduwKWIolpM9vFoC1
/K3BizkBSLEuA/OGLIS12l4inxZgdX9jYzKfhaz457NmknIoSAlWm5ssXP1j
iyfWKEfBbpXpNLMQjnFvLfyiykD9uqHm2atC8F9vjPWPlGJLRKvTusDGkZoL
5JSTpWhuK1bpjbIx03HKsOlWCTwPWysOuHIQ3tWt8jEuwZqAS+C1cxBENZ+T
GfKR7W07tkbmoouirzNFKsY7ATWxQ87FGpG7HGhQhH8Bb+a9Xw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$237713#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687752`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {25}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010291666666666666`, 
   0.010833333333333334`, 0.011375, 0.011916666666666666`, 
   0.012458333333333332`, 0.013}}, {{0.}, {0.004980807111936509}, {
   0.009810238162392298}, {0.014346227217215901`}, {0.018464393153341013`}, {
   0.022064704980054188`}, {0.025075932164168424`}, {0.02745766837337204}, {
   0.02919997712232828}, {0.030320906486767236`}, {0.03086226877234603}, {
   0.030884202131749795`}, {0.03045909369943538}, {0.02966545644149213}, {
   0.028582684007914066`}, {0.027286003909747704`}, {0.02584374798800854}, {
   0.024315097005136864`}, {0.022749291817872132`}, {0.02118570216276538}, {
   0.019654527865652402`}, {0.01817787617956351}, {0.016771007101224984`}, {
   0.015443590647925326`}, {0.0142008802442115}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.66262477963708*^9, 3.7992125668182993`*^9, 
  3.799212759422963*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"875c275c-bc96-4396-8f33-2984b4ac5ee3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236050185127`*^9, 
   3.662623609386401*^9}, 3.799212531136713*^9},
 CellLabel->
  "In[237]:=",ExpressionUUID->"90692c4b-af96-47c0-bba3-84fe2d59ded3"],

Cell[BoxData["1798.4757640815658`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662624779712291*^9, 3.7992125668301373`*^9, 3.799212759473455*^9, 
   3.7992244859239483`*^9},
 CellLabel->
  "Out[237]=",ExpressionUUID->"6ecf317e-067d-40f6-be8f-3ad9b74435a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sweet spot relative to centre of coil", "Text",
 CellChangeTimes->{{3.453823657396553*^9, 
  3.45382366152324*^9}},ExpressionUUID->"ed069afb-65a9-4706-a035-\
58555d00a52a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"-", "0.010"}], ",", "0.010"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453750960628242*^9, 3.453750962514122*^9}, 
   3.453823640869858*^9, 3.4538373938007517`*^9, {3.453838657031551*^9, 
   3.453838662984824*^9}, 3.453838901400448*^9, 3.453841257421837*^9, 
   3.4806948139055853`*^9, 3.48069586856068*^9, 3.48069931407596*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"de04cda8-cce7-4f5f-8e4c-19e1df4a03ea"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt2Xk01P/3B3ApKkJlS2Rrs0RCWtC1lSWEQiSRSgqDGfOesVUMSqSQfeZd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       "]]},
     Annotation[#, "Charting`Private`Tag$237826#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.01, 0.01}, {-0.030934220270975643`, 0.03093422209015647}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.45374974088566*^9, 3.453751021464161*^9, 3.453823734388617*^9, 
   3.45382595105693*^9, 3.453826495876092*^9, 3.453837430614188*^9, {
   3.453838660033111*^9, 3.45383867436195*^9}, 3.4538389289668913`*^9, 
   3.4538418441367064`*^9, 3.4638449203570347`*^9, 3.480692306252309*^9, 
   3.480697135921809*^9, 3.480699539484208*^9, 3.481567006130314*^9, 
   3.481942077639205*^9, 3.66262479351025*^9, 3.799212566887249*^9, 
   3.7992127713239603`*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"eb76286c-2a2c-4ac0-92b2-80089a1b2861"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"fz", "[", 
    RowBox[{"AODL", ",", "p"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.0", ",", "0.01"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, 
   3.453823640937874*^9, {3.4538265543875103`*^9, 3.453826559178968*^9}, 
   3.453837393850636*^9, {3.453838705965811*^9, 3.453838717842711*^9}, 
   3.453838901436325*^9, 3.453841257441544*^9, 3.480694814624156*^9, 
   3.480695869313149*^9, 3.480699314862365*^9},
 CellLabel->
  "In[100]:=",ExpressionUUID->"c546244e-c6e7-4dcf-8f92-58c09faf7ac7"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV1nk4VV8XB3BDoSiJpBCVlJKQEslXJaFkLBLKPIRwh3MvMnVTaEBcQ+49
mRoMDZpMTSoh0UilRKVBoSThp7z7/es8n+c55+x91ll7rTXfa5+Dr5iIiMgk
URGR/18NzYf7omS+rxsZVvr8aqW6qaxhTc716kZT+Qc//12r+mu6YNfduNjq
V6abGeLGrKpp0A7ZzPSu/mr6NXXduF2VKvTYU0K3V4+atsrqh+lVLcflyN6g
bdVTgKWiw98q12Fo3PWrdfUcbDljEzp43QazTE8ssarWgpTPzs65V9xRJfrh
mGWrMcw4A0fU34fCdUm0yt7ejZgX8MKH+YaNpirO+9it1kjjLrVxko6B17HP
vsl5dvDzcrR88yoBg9XhFhfaHeGSvfLAfZdEbH58do2CizN+lErN+yaVjMzX
LgvVG1yxMWawd1LyUQy/+8yV+OuODRTnZaxLKqZ9lgvn1+zB7ueug1rjaTi3
S61DcZcXZgULHr0IP4E71oF3gga9oT1pso9cSwZMzidd9CjzxaJrtNpxfT7M
jue8uGXpj9B08zHroCyc+RgrfkcyEDm7zmmfLMpG8pWC8sybQYic9EGz5HYO
/ohePdruHIy5qZTGlsu5qL8rYFfJh2KBr/Tet/knoSbOzpSq2AeT1v5bboF5
CNmV3hlVFYaAcQcdxyUCJA0e0n2bGY6gYVoqsUmArjNrU+VzwlEaMtnmSrMA
a9wHBqzywqH8o8Kou0WALw92XLhWEA59L3MZw2cCWAgW6aReCId29lD20w4B
xCzvLtvYGI7fx+f5Nn4XIFLwT/PceDiUDrE516YJEWTJUmV5R2C4Qdc9Y4sQ
JSXGN374RWDTa8oi00aIXhkR9+CgCEiOCgszbIXY+yQ5zzs8AnU/FlcfcxQi
2PWUskNsBGrT/dzCdgkRGvxwzoqTEYhsmJH9NUgIRup8xa9PI1BhlSl59bAQ
0S8fTXffwED885SZVbeEqJwzcViwiYHEuCc1JneE+OWqK95pyUD/ceVZt+rI
/t6m//GwZSBr/Y6Xt+4L4fzeuWuPGwMaGoLiSw+F0P/efcmHzYC8VeT+He1C
fJn47RRcwkBn7knD031CaKxf3FpWzsDY3IPLRQaE2J3gYtV3kYFajeCXLj+E
aJtUsy70OgMSS1/aSPwS4u6UOM2wewxccauosR8RQig/dYTRyUDGr2kNJWI0
HBfPOxk1kwnr/umP/BRp8Lo315bOYqLw2p3qtNk0rpwMf9uhxMTgsfB9NUo0
FGbcVzNRY+Lxs1AdaWUabSN7i8aXMbHhaZhknhoNl6aq8v2bmNjDsbE+sISG
R8j227EcJtzy9UwDjWgcWxzbfSGKid16We4hxjRudp8V64oh7690sApbS0Nt
x7i52UEmfndFJUaso9FlWtgoks4E69+mvID1NLxn/HwaX8rE4seH3JWtaARc
PtJzoJMJmbOnwvKcacTPbbAY7WYifvGY0VEXGrnx4mdDe5ioTOuho3fSaLaN
DNr5nQmvTx4bnHfR0PvuP6AzxsS/Dq8v/3nQGNPYOPpqFgtDwtvfxfxopPBH
ZXRtWGg0WB4zhUGj6K9BaLEdC5PXGG1rIb7pE9Y614mFuO6gujQmjR/6n9Mm
72Jhe61htgKbhlPrc8WOABZ6C5eLTOXSUJG6qJ7IY0H5pfLo5Rga57l+Bm9q
WMg8H2ApkUSj7ta0MMVbLKRsCu7IJG6bfLXUro4Fx8t+FhrJNCbSxBfeb2Ah
qXdm8boUGnYlp+TOv2BhpuqMFK+jNH6+ft0fO8BCyMAkFVYaDYn5CUurB1n4
nWq7eZB4rr+W39BvFuw5H2xC02ls+EW9DRhn4VDLjT6vEzTSpWc1209hg45f
E2OaScPAxPbcwoVsVJr+nnErm4ZlwvBHd002FqeqTF2aQ8OtQaCercXGeF1/
9wlintP3LBldNopWh+r45NJ4EZyU+NuEDQvPF2Z/TtJgC+56P9jBho2TWdRn
IY3kD0G0qCsbe/RbOWY0DaHWzI617mzcKGW5ZBM/uLrH4aI3G/pHft40P0VD
qeWvWU4YGy/OVOmk5tOo+mc4b28yGzMeb2/6WUjj2s8fOb1H2ZgfID9gWkSj
4uO5WUFpbJzoVmlIJi5rUp4WmM2Ggpt+9rxiGqf4E//5nSbrHVpfufo0DUFS
JfXpHBv17UaHuMS50eG/fMvZ6Cq4IVNDnOH1odfnChutPOl1xmdoHNZ58Mqr
jo26sJOGWmdpHJwft/39fTbarr+u8yROUDB64tnIxr/9XyVyiKPHShr2PGZj
9El2tfg5GmH1x657dJL4uhm9bCQOqdq8srObjduf+/VGiIPKRC6495DnUWux
qISGT3rEabfvZP2bdwuiiJ09dmS6jrHB3n1ce04pyTd7WbnXf9kQs5bxX0ds
Z95wZKcohZTIPo89xNZLjXkuUhQyMsrTC4g3q/6aaJemcKow/t4dYvMZZVHO
shT0Xj278o7YdFiVsUORgvKWDU9nl9FY+7Wt/8UcCoN7+yf0iNe8OR60XZXC
geU+fdbEq1otPz1Xp7D6v8ZcL2L9OlEvJw0KH+24UlziFVer3z5bTEGxuHb1
MWLts4ydjsuIYzoXFRBrHuuxc9Cn4KHxZXM98cJ4YfOTVRRqrX2j2ojVmc6W
9kYUNp79FtZDrOo/495jEwppsvVLfhHPdW2EnRmF/V4onCCebZNQ07qRQk1a
QdfUclK/zNYa2m6moCUw7lYglls5VNFiTSH8hEOxKvF0zXKdbdsoOKWvWr6I
WHqOX8kjewoy9TrcZcRSMmqaNtsp3A9MStIlnjzRnt/sQvYbdtTDgFhsMFV1
qxuFhndHRlYTT3y0ynm4m4J/Q6vzGuLxdrFZW7wpnKbzo//vkaaa1CY/Cpyv
Nv6GxL9vMGWsgyhMX6OutIr4k5bmiqoQEk+76wV6xC8z2+2XhFOIzvGa0CZu
Ek1iZjEpHPnjrbOYuDbEOEuCQ8FusoSuOvH5V9+qWFEUOhNTJykRn9okePMx
hoKfzZay6cTpl7ZNOCZQ0DCMWTyJmKcqsuDuQbL+inD2CIkfO+mSuX4SBbFh
35xvxAG/vfzzj1DYO3Ex9S2xq6dC8oxUCkMaGW4txFsf3S+LPUGhkOf89wax
qRHV2s+noGm1kVFGrFu8ZNA9l8Ktc/TNHGKF/SmGJvkUTEZa28KIJb6auJYW
UfjWt6LIlXjEqT967lkK017Nt9xI/Ebbvm7kPIXysLcKcsQt2WI9/hUUFmqv
MR0m+Xp70hXJ9qsUHo9Z4DVx4RtFm6u15P+xChuFxBmWDfs0bpP7xRIdY4kT
r3DTT9ylYCZrcs2DOOjIm/bwJgr9e+wk5xLrmxR46bwk+a+i0JVAzpvGWceD
gg4K4uuz1rgSKypMPivzjkLdJeNgXeKxb/59vT0U8n2l/V6R83vn5HLOmV8k
HrfbSlWJKyTf5Sr+oSDF9Or5RupBESP1xsExCl9lno9XEh/e8kvMR5SDlcXz
79kS2/1XeVRdloNA/d2395F6s8E/6OLxmRwYWT38bkBs8Ez52b9ZHNhVeI6O
kPqkVBqj9FaFA63E3or9xF2u5oU5Szn49qDrPJfUu33VrZUzLTjg9hdPMyH1
0m1y31ULKw5Y4g+ThwpIfbebejlyKwcJA2pyZcQLPpmXv3fgYOySl7EScZtc
dX7Fbg6uuvRO7iH12DSwKNmBy8FzvWnX7Eg9X3blzqHEaA6YXOkPowKyn4lO
XnUsB9HiMqoFxIMZc2IXJHIgwZCsGsijcfr2McZgOgcXzdKzYkl/mK7EdUsv
40B0e6xGBOk3/3nxd9ZfIO/3MzaVIf5SfnnHWAUHkR/SA4qzSL/c2G/nVcVB
u9qXH8/5JF/3eW/Sr+cgwj6ubQnpX531NjpP33HwYuZBrSLS/86zFojMlOdC
3jAir5f0V16I/boURS7yr9cuciN29Y2LnDSXi0CpfmHzYXK+t3cODatzcXro
j2fJIRIvg9yvHTpcLIqzXbnzII2pv+SeFVtzcR9Olrw4Gn5hoqeNErgY2u7t
P5P0f5MA3Q8VB7kQb1DjebFozNyzW107iYvHGYW5l8i8cMP2Ru68VC6ey6pc
20rmCYUV3OPiQi5GJFIusMPI9/X94Dyq4iLaSm8wJ4jGvL1dWzx/chFww/Kz
GplXBtZHedNDXFj0ylx1dyf5r6QY9fYPF7J1o6dz3Wh41m8p2fmPC7lChxE5
Mu8Uzb8u5SAdiQgpTZdhMi8te3n0/oZFkcDr+E18e1LPN62Fxs5IyJe9P2Vg
TuZDNb7+59uRuFDXVDqqSf7nPq2fCvcicd9UxV+SuPNm7YUNDyJxs+Ojh8Ii
cn48PmgLH0ViesLAJO2FpP8JdBdvfx0Jkz4RPQcyH15Ufqh891ckGiLkzSLJ
fCmjJDKZ1ozCPJHqXmNJGvUzgtp3HInC73/ywykfybxsci5OMTAaGzY9PXfz
uBDPNLvuyRjux6W91u9rVgkRsiVhmqNiDHZ45P8IbxSgWUflZ+unGOi6szfa
7RIg0PZ5+urLsUh/vkCr/XMeVF5E5bEt4zC2/saT1d55+OQ5ZV3fhTg43PSR
De0+icaU5nfS6vEIuLdVwtj2JLY8F3qqHYtHQ5fsm4nqXKwY/67bMhQP+/LO
cMfludC+Eya2yCcBpVHms5tTc5DiGzZ/dnMCnB68qswbz0bSkli1f3oHkKH3
pUssKBunDt9VO3rqANAwb7V8UxbmNBwIuS7Jg1X12XOHDLLQ4vNYgTeFh/GJ
+aPf9LLAE1WttZPmodZt4Va7FVn4YXxtau90HiIMdvxVWpqF+vIvZ1QUeQgr
pVNL1LIQccLmfbwGD5ID+3Napmah2WO289b1POytNNqk3M1Hwn/e/5Q28qDe
LbMtrpMPw+yLxT3mPJTtk9zd08FHwROroRhLHl7GZeRcaOODax6ddsmWh8xp
RyjzZj40l3Y/VPTgwVM0Z3DfdT7e1C9nfNjNw9TuzGMvrvCR5h0596Inud/u
p8HaCj7G8+QDrXx5OMSyzZco5+OZrIVEdDAPT0PZ44ICPg6XpZdbhvLAaFs1
IH6KD1Ord06zwngI2hnYFyjgoySBU3iewYP25msyq7P52KN23zqKxcOwk4JO
XiYfs2rlBjdTPBjf27dL7AQfTS4eOQpcHopu9mYEpPIR97vErDuShz73M69b
jvLxPyVhprY=
       "]]},
     Annotation[#, "Charting`Private`Tag$264185#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 0.01}, {0., 0.030934221846478892`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4538234640829372`*^9, 3.45382375947115*^9, 
  3.453825952943671*^9, 3.4538265081040163`*^9, 3.453826563804844*^9, 
  3.45383743232346*^9, 3.453838725272155*^9, 3.453838935442772*^9, 
  3.453841854513754*^9, 3.463844932499839*^9, 3.480692315858614*^9, 
  3.480697141979739*^9, 3.480699548181242*^9, 3.481567013982223*^9, 
  3.4819420873711357`*^9, 3.662624801931018*^9, 3.799212566920704*^9, 
  3.79921277848875*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"36c10732-f114-4041-a2b1-f3f46539d2dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "p"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0.005"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823404829797*^9, 3.453823405956604*^9}, {
   3.453823506088236*^9, 3.453823516693254*^9}, 3.453823641011278*^9, {
   3.4538265379087467`*^9, 3.453826543745769*^9}, 3.453837393910678*^9, {
   3.4538387257460747`*^9, 3.453838749683352*^9}, {3.4538387973199577`*^9, 
   3.453838821469616*^9}, 3.453838901466652*^9, 3.453841257454495*^9, 
   3.480694816395583*^9, 3.4806958708335733`*^9, 3.4806993158810596`*^9},
 CellLabel->
  "In[101]:=",ExpressionUUID->"82eafcc7-3e81-42cc-8856-b31f68018464"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030934223187089323`"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", "0.005708643128285952`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.453823468555167*^9, 3.453823535452108*^9, 3.453825954168241*^9, {
   3.453826526324848*^9, 3.453826545225122*^9}, 3.4538374328189507`*^9, {
   3.4538387298936996`*^9, 3.4538387449128933`*^9}, {3.4538387984605837`*^9, 
   3.453838822542676*^9}, 3.453838936153399*^9, 3.453839519837987*^9, 
   3.453841855442709*^9, 3.463844933406391*^9, 3.48069231649853*^9, 
   3.480697142379641*^9, 3.480699548871449*^9, 3.481567014542268*^9, 
   3.4819420880567417`*^9, 3.662624802649501*^9, 3.7992125669352283`*^9, 
   3.799212779099167*^9},
 CellLabel->
  "Out[101]=",ExpressionUUID->"ff3e0a65-d4bb-4c7d-ad20-4c42d512a702"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
New coil calc for bigmagnetvals5 (5x10 magnet, 400 turn coil)\
\>", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.79921627913453*^9, 
   3.7992162941664057`*^9}},ExpressionUUID->"2813d2a2-de64-4046-a4e2-\
dd4ff7805916"],

Cell[CellGroupData[{

Cell["\<\
bigmagnetvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of half-big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of half-big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.16*0.0254,
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254,
\t\tcoilrad2->0.55*0.0254,
\t\t(* the number of turns *)
\t\tcoilturns->400, (* T980043-00, p25 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
]\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"377650f6-9d15-4e9d-b438-1fb4d43219f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"w0", "\[Rule]", "4.668406683234433`"}], ",", 
   RowBox[{"rwire", "\[Rule]", "0.00155`"}], ",", 
   RowBox[{"awire", "\[Rule]", "7.547676350249477`*^-6"}], ",", 
   RowBox[{"dpend", "\[Rule]", "0.45`"}], ",", 
   RowBox[{"dyaw", "\[Rule]", "0.0333`"}], ",", 
   RowBox[{"massoptic", "\[Rule]", "10.7`"}], ",", 
   RowBox[{"loptic", "\[Rule]", "0.1`"}], ",", 
   RowBox[{"roptic", "\[Rule]", "0.125`"}], ",", 
   RowBox[{"Ioptic", "\[Rule]", "0.05071354166666667`"}], ",", 
   RowBox[{"wpitch", "\[Rule]", "3.7699111843077517`"}], ",", 
   RowBox[{"wpend", "\[Rule]", "4.674689868541612`"}], ",", 
   RowBox[{"wyaw", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"kpitch", "\[Rule]", "0.7207525354005531`"}], ",", 
   RowBox[{"kyaw", "\[Rule]", "0.5005225940281619`"}], ",", 
   RowBox[{"pitchlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"yawlever", "\[Rule]", "0.0808`"}], ",", 
   RowBox[{"kxpitch", "\[Rule]", "8.920204646046448`"}], ",", 
   RowBox[{"kB", "\[Rule]", "1.38`*^-23"}], ",", 
   RowBox[{"T", "\[Rule]", "295"}], ",", 
   RowBox[{"g", "\[Rule]", "9.8`"}], ",", 
   RowBox[{"mu0", "\[Rule]", "1.2566370614359173`*^-6"}], ",", 
   RowBox[{"rhoeAl", "\[Rule]", "2.65`*^-8"}], ",", 
   RowBox[{"rhoepianowire", "\[Rule]", "7.95`*^-7"}], ",", 
   RowBox[{"sigmaeAu", "\[Rule]", "2.67`"}], ",", 
   RowBox[{"dipoleM", "\[Rule]", "994718.3943243459`"}], ",", 
   RowBox[{"massSOS", "\[Rule]", "0.25`"}], ",", 
   RowBox[{"massM", "\[Rule]", "0.0029059732045705585`"}], ",", 
   RowBox[{"Bresid", "\[Rule]", "1.25`"}], ",", 
   RowBox[{"\[Pi]", "\[Rule]", "3.141592653589793`"}], ",", 
   RowBox[{"rhomM", "\[Rule]", "7400"}], ",", 
   RowBox[{"ztube", "\[Rule]", "0.0155`"}], ",", 
   RowBox[{"zpickup", "\[Rule]", "0.012999999999999998`"}], ",", 
   RowBox[{"masspullapart", "\[Rule]", "0.06`"}], ",", 
   RowBox[{"mzpref", "\[Rule]", "0.00794563213587432`"}], ",", 
   RowBox[{"mz", "\[Rule]", "878020.9598010788`"}], ",", 
   RowBox[{"lold", "\[Rule]", "0.003175`"}], ",", 
   RowBox[{"aold", "\[Rule]", "0.0009525`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"a", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"coillen", "\[Rule]", "0.004064`"}], ",", 
   RowBox[{"coilz1", "\[Rule]", 
    RowBox[{"-", "0.002032`"}]}], ",", 
   RowBox[{"coilz2", "\[Rule]", "0.002032`"}], ",", 
   RowBox[{"coilrad1", "\[Rule]", "0.008889999999999999`"}], ",", 
   RowBox[{"coilrad2", "\[Rule]", "0.01397`"}], ",", 
   RowBox[{"coilturns", "\[Rule]", "400"}], ",", 
   RowBox[{"coilsigma", "\[Rule]", "1.9375038750077497`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.463844933665338*^9, 3.47966690722052*^9, 
  3.4802449126813803`*^9, 3.4806923165771303`*^9, 3.481941607857794*^9, 
  3.481942088088718*^9, 3.662624802714809*^9, 3.799212566985938*^9, 
  3.7992127791094713`*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"10386a98-940d-4c3d-af8f-e110b3a5e7f0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BM5", "]"}], " ", ":=", " ", "bigmagnetvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9},
 CellLabel->
  "In[103]:=",ExpressionUUID->"d7341d39-4812-48b4-ab2d-5d6ef0b56354"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.6371543615438662`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0050900302724624065`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BM5", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.479667008672338*^9, 3.4796670332310963`*^9}, {
   3.480244318582687*^9, 3.4802443450940313`*^9}, 3.6626239941508102`*^9},
 CellLabel->
  "In[104]:=",ExpressionUUID->"e34482ee-c873-4a58-8d7e-00471656aa43"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.6371543615438662`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0050900302724624065`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662625110723606*^9, 3.799212567040732*^9, 
  3.799212779146633*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"3015b92f-6859-4781-8577-5a087fa64be3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BM5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.479666887455168*^9, 
   3.479666888838862*^9}, {3.480244879780376*^9, 3.480244897499516*^9}, 
   3.4802450058581*^9, 3.662623996847999*^9},
 CellLabel->
  "In[105]:=",ExpressionUUID->"94469ae9-0aa1-4d7b-bde4-deec403b3e7a"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.6626251467152987`*^9, 3.7992125670504713`*^9, 
  3.7992127791877413`*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"1982ac6b-55e5-44a0-be8a-07be84e5024f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.479666890574193*^9, 
   3.479666892310862*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"cc740a61-a5f2-4a3e-95e3-83f535b4fb22"],

Cell[BoxData["0.0050900302724624065`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.4796669544241667`*^9, 
  3.479667628122774*^9, 3.480244912925961*^9, 3.480692316685502*^9, 
  3.4819416080006037`*^9, 3.4819420881974697`*^9, 3.662625146797575*^9, 
  3.799212567102704*^9, 3.799212779197138*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"2efc3972-7e5a-43ca-8aef-9e8988aed0ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BM5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BM5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.479666893782012*^9, 
   3.479666894910797*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"9a31230c-7433-4b9d-99bf-6abf92d55d95"],

Cell[BoxData["0.6371543615438662`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.479666954466415*^9, 
  3.4796676281467333`*^9, 3.480244912993281*^9, 3.480692316727179*^9, 
  3.481941608053739*^9, 3.4819420882381277`*^9, 3.662625146876009*^9, 
  3.799212567112886*^9, 3.7992127792319937`*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"e7b89250-bc75-4a42-afdc-404b4af80bc2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623628457925*^9, 3.662623630065835*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"ed33ce46-c711-4ecf-9625-01290b2a55e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVj3tQEwQAh9cYQjg5hGk8ZrwVRQ5sMhKGPw8EjJfghPJkuniEMuSlg1k8
NoTBhhgaLCQyUNNVIDfiERxBSTwGeDCEEcyxja2LR6ggl8cdcNEf333/fP98
jvHpZ5KIBAKBsc3/XqvtsM879dKfQBgzjh2/fFz9Q1jXWr87UgWmuqvSx2h5
kEw0XmWg6dN7vNqKX2CRsx5SwQ8Cy32MJnB9ivAlhp8iMRw7ec3HnQYHcN3t
k6SIV9GIlO+Sn+18Bm/fxOTY1Bi0urc1vFOmwKOTpe3OR8/B/NGLTBPmBGro
S9+GLsZhdbYjI2pRia7AKE2oFxt27/68Y/rINITzbZJxi3is8oprAgQq9HUF
c1IVCZAe9GRH8NXoI/1rRhMlwTSJxToUoYHDRzLF+c+SYTKyqC4QafGqq6pV
4nwZt7wtuUdCdLDxEP5G28GBOfNimXRDB9JuiWRTkwqz2ttNhZI5JLqMiqbv
pqGHtuxQb6GHha3ZeBkjA7Kd5lR2vh7SY78v06iZiCJt7KGP6ZH28Ra13DwL
VjZePSlWBlA8h2W5G1kYJSrcxk4YwL13OIY7cxVWy9kS/TkDjMgUsv3wNZBS
POSiBAPCd1coFD9x0Ut7uZfJ2u7HvtmwLc3Gfdn5ov2hBoyUe/jtyclBrsSM
aOpmgHqOWWody8MlbmH90oYednTCwkjIdfRF9QYH9OrhG8hoes/7c6xemMjT
8/WwmicXcSy/gNyafYHtp4dtWUJqBjEXK+Vx1pPzc1D1RSbkz+WCvHdXtOn2
f16nvMepOw9Pq7u/jjkxh/DGIU9eQz4kmhKii0YHpQ/7iVJcACcP1c1AgQ7B
Wn+HN/58GHfyDgxa61Dwuiqj4AkfAws1ON2qhVTd+kZJFeD7niKS+IwW8/Jq
QkmlAEnv+4xSnmlgTOyv9CMVYh/87f4gavDhsbbmU3mFCPDpyK47MIu4iDQj
x7VCrDs/9GVHq8FqzFBtxt9A2o8p68viF+CS6f401Q0wJ4w3ta0qpLQH7b8S
VoRVomvQlZUZnMa+gKyOIvTetr3Dp80grL/971GvYghz0jFwaRoud2spH9QV
o+HxcaVR05+gcE4O/2MtBLWOHHl/YQprNi0tWV8KMVuFIcrhKcgoaa6bm0JU
8/uo9AIlis2X7LXcEnC8DmbZD06Cfra5fuCvEhTc4cZkOE5iq5rRaHKxFFVV
hzjZmRNo67y1ZKkshZTpyLgmf44wN3eZU5AIgw8Ehtdez/G2Ukwo+1WEIV3N
TVrFOPgRR6feeojBCn2YlbmlwEolPb37OzFcvhr380xX4D9/ab0n
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$287518#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.6371506623502801}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVj3tQEwQAh9cYQjg5hGk8ZrwVRQ5sMhKGPw8EjJfghPJkuniEMuSlg1k8
NoTBhhgaLCQyUNNVIDfiERxBSTwGeDCEEcyxja2LR6ggl8cdcNEf333/fP98
jvHpZ5KIBAKBsc3/XqvtsM879dKfQBgzjh2/fFz9Q1jXWr87UgWmuqvSx2h5
kEw0XmWg6dN7vNqKX2CRsx5SwQ8Cy32MJnB9ivAlhp8iMRw7ec3HnQYHcN3t
k6SIV9GIlO+Sn+18Bm/fxOTY1Bi0urc1vFOmwKOTpe3OR8/B/NGLTBPmBGro
S9+GLsZhdbYjI2pRia7AKE2oFxt27/68Y/rINITzbZJxi3is8oprAgQq9HUF
c1IVCZAe9GRH8NXoI/1rRhMlwTSJxToUoYHDRzLF+c+SYTKyqC4QafGqq6pV
4nwZt7wtuUdCdLDxEP5G28GBOfNimXRDB9JuiWRTkwqz2ttNhZI5JLqMiqbv
pqGHtuxQb6GHha3ZeBkjA7Kd5lR2vh7SY78v06iZiCJt7KGP6ZH28Ra13DwL
VjZePSlWBlA8h2W5G1kYJSrcxk4YwL13OIY7cxVWy9kS/TkDjMgUsv3wNZBS
POSiBAPCd1coFD9x0Ut7uZfJ2u7HvtmwLc3Gfdn5ov2hBoyUe/jtyclBrsSM
aOpmgHqOWWody8MlbmH90oYednTCwkjIdfRF9QYH9OrhG8hoes/7c6xemMjT
8/WwmicXcSy/gNyafYHtp4dtWUJqBjEXK+Vx1pPzc1D1RSbkz+WCvHdXtOn2
f16nvMepOw9Pq7u/jjkxh/DGIU9eQz4kmhKii0YHpQ/7iVJcACcP1c1AgQ7B
Wn+HN/58GHfyDgxa61Dwuiqj4AkfAws1ON2qhVTd+kZJFeD7niKS+IwW8/Jq
QkmlAEnv+4xSnmlgTOyv9CMVYh/87f4gavDhsbbmU3mFCPDpyK47MIu4iDQj
x7VCrDs/9GVHq8FqzFBtxt9A2o8p68viF+CS6f401Q0wJ4w3ta0qpLQH7b8S
VoRVomvQlZUZnMa+gKyOIvTetr3Dp80grL/971GvYghz0jFwaRoud2spH9QV
o+HxcaVR05+gcE4O/2MtBLWOHHl/YQprNi0tWV8KMVuFIcrhKcgoaa6bm0JU
8/uo9AIlis2X7LXcEnC8DmbZD06Cfra5fuCvEhTc4cZkOE5iq5rRaHKxFFVV
hzjZmRNo67y1ZKkshZTpyLgmf44wN3eZU5AIgw8Ehtdez/G2Ukwo+1WEIV3N
TVrFOPgRR6feeojBCn2YlbmlwEolPb37OzFcvhr380xX4D9/ab0n
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$287518#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.6371506623502801}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {55}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJzBgRQqzDwv7Lf0B5CO9pbbjlRtm++l73zpSldm/n9
oeKB9trtYjfPfQ+2N5j2J+mkfpi96dJHbw6nR0DVR9nbHV7HsPN6DFRfvP2S
Aluu64sToPoT7VfUK0+5eDsJak6y/bo+TrkzwqlQ89LsN819v/yYdzrU3Az7
HWuuGh5szoSanwU1Pwdqfj7U/AKo+YVQ84ug5hdDzS+Fml8GNb8can4F1PxK
qPlV9rvBoBpqT439gVMLXbd9rrV3AttXbw/SdUO0AWpvg33ql21AExqh9jfa
P/+98uMl3yaoO5rsM5nnml3IbIa6p9n+DdeE6rOtLfZrwe5qtc8TagZa0Qp1
X5v9J8ky1hN726DubLc3Abuzw34b2J2dUHd22QMAgjfY7w==
   "], CompressedData["
1:eJwByQE2/iFib1JlAgAAADcAAAABAAAAAAAAAAAAAAATrfhPuzauPymvD5ts
Dr4/d39DU+hYxj+UXn/A6OzJP8Em5/ADcM0/OwiCFgxw0D+B43KCjx3SP4Jz
9uaXv9M/eLo/6UBV1T8k/+0jt93WPz0Ar+44WNg/RbQaDRfE2T+MecIztSDb
P6OQI2aKbdw/3DOcNCGq3T99TxXUF9beP9YOBhcg8d8/fHCton994D9RDozo
xvngP9hKQHdbbeE/rua9CjzY4T8keZriB5TiP/WKpbzJLeM/b05TxZmm4z9a
kID5+P/jPyMz2oG+O+Q/vFcPZwRc5D9+ageyE2PkPwrrubJRU+Q/Y+dz6i0v
5D+rjaT7EvnjP3KM/3FZs+M/B5Lm/z1g4z+/feaZ2gHjPzi6KisgmuI/jtKR
c9Uq4j94vehilbXhP+/3XbfPO+E/3p6/ksq+4D80o/mppD/gP3hWNOCvft8/
J0J4/3h93j+KhOBwF33dP1SpwjfGftw/D/fdgI6D2z+mfs4aTYzaP15K64C3
mdk/PMoqpmCs2D/Ny4IpvcTXP3+zWU0n49Y/+KH5ZuIH1j9ghLrB+GTUP5IW
KaS/3NI/9KFuMi9v0T+csOP4
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625159674733*^9, 3.799212567205351*^9, 
  3.799212790103311*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"0b071736-6c26-4725-aa48-eff36d06fcd4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BM5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623631777481*^9, 
   3.66262363489753*^9}, 3.799212531138236*^9},
 CellLabel->
  "In[109]:=",ExpressionUUID->"f6234f0a-64d6-4d54-b176-b040b7db139d"],

Cell[BoxData["38794.468607424984`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625159753221*^9, 3.799212567216333*^9, 3.79921279016667*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"7899290b-2597-400e-a514-657a84cf9d95"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BM5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.4794964690726423`*^9, 
   3.4794964944567127`*^9}, {3.479496975356181*^9, 3.479496976183571*^9}, {
   3.47949787094656*^9, 3.479497874578391*^9}, {3.4794981429899273`*^9, 
   3.479498147044504*^9}, {3.479498193967552*^9, 3.479498236581649*^9}, {
   3.479662116006764*^9, 3.479662117075882*^9}, {3.479666955542605*^9, 
   3.479666963425733*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"837fae9f-d025-4dd0-a738-adfe2d58ee62"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nc8Vf8fB3ANo5KZFZUVDX1pkKyXSsMsWREZTXvcc+xN4qLQoK3SllQq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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.6371543536135365}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.478973514856566*^9, 
   3.479486967021886*^9, {3.479496470359309*^9, 3.479496495124946*^9}, 
   3.479496976846184*^9, 3.479497079117694*^9, 3.479497903680291*^9, 
   3.4794981476612797`*^9, 3.4794982377851954`*^9, 3.479663512480014*^9, 
   3.479664582004204*^9, 3.4796657495921383`*^9, 3.479665823576626*^9, 
   3.47966696773402*^9, 3.479667628752988*^9, 3.480245019281752*^9, 
   3.48069231710384*^9, 3.481941608391829*^9, 3.4819420887496758`*^9, 
   3.6626251598288507`*^9, 3.799212567265808*^9, 3.7992127901811323`*^9},
 CellLabel->
  "Out[110]=",ExpressionUUID->"050222f3-8f92-453a-9942-65e81a4c8d8e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 
   3.4788951754720497`*^9}},ExpressionUUID->"50028e12-664d-4797-b26a-\
9e356f598b23"],

Cell["\<\
bigmagnetvalsSA = bosemvals10 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}},
 CellLabel->
  "In[111]:=",ExpressionUUID->"f15ccc8c-1273-46df-894d-99940b8f8b0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO10", "]"}], " ", ":=", " ", "bosemvals10"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9},
 CellLabel->
  "In[112]:=",ExpressionUUID->"65d4aeeb-a263-4296-9eb2-cfe938d46820"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.694858202857608`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0071958504693359565`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BO10", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, 
   3.66262400355859*^9},
 CellLabel->
  "In[113]:=",ExpressionUUID->"9e29d255-97ef-4440-b21e-f182851efff1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.694858202857608`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0071958504693359565`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.66262557733585*^9, 3.799212567306459*^9, 
  3.79921279023442*^9},
 CellLabel->
  "Out[113]=",ExpressionUUID->"5d50e20d-46ac-49b2-b8f2-279acf2ceb4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, 3.662624006302704*^9},
 CellLabel->
  "In[114]:=",ExpressionUUID->"86da488b-07c5-42ac-abad-116c78ad154d"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662625615035322*^9, 3.79921256735336*^9, 
  3.799212790273066*^9},
 CellLabel->
  "Out[114]=",ExpressionUUID->"430f0cbf-a2cc-4140-98a3-14215d803a91"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9},
 CellLabel->
  "In[115]:=",ExpressionUUID->"7fb93265-7e27-4cad-8673-f16f2172d585"],

Cell[BoxData["0.0071958504693359565`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481941615983523*^9, 3.4819420888840933`*^9, 
  3.6626256151021233`*^9, 3.7992125673632507`*^9, 3.799212790282357*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"b076b6fa-9009-40b1-86ff-eb9324cbb807"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9},
 CellLabel->
  "In[116]:=",ExpressionUUID->"4f528aab-fdf6-421c-af92-23b463b6b6bd"],

Cell[BoxData["1.694858202857608`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.481941616034875*^9, 3.481942088922996*^9, 
  3.6626256151756268`*^9, 3.799212567408977*^9, 3.799212790316127*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"1fb76a46-0755-4c01-b6e0-5b04c9fd2838"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623646129085*^9, 3.662623647656955*^9}},
 CellLabel->
  "In[117]:=",ExpressionUUID->"3b437d79-499c-427c-93bd-703723471f2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AANCro4J3Pt2pS7z0
xis/pg0Qjc6NtT+0o2cCBfI8PwCKjRp2bMY/EHf5R5CART/Zc5vXap3QP0zr
PDvRZEw/Nq8lxyvd1T95KFhlTe9RP9DlGwigfNs/NTpkZ1ZsVT9xc8GIdFPg
P6ZEiLcjNFk/NzeInUYS4z+aNuudSupcP+8jWLRZtOU/vENQ30owYD8WPyC0
IRnoP4botpbSEGI/xq5+zl2e6j/FvEZrbNFjP/RLCpAe5ew/xQT2CjOJZT+I
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7i4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/EAV0WMcc9j9uV/4cjQ5yPzxAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pvaReM8h+D8DDBQMH8t0Pz2f44jp
s/g/TBGQ0dGrdT91YmQs8y35P3XQm/waiHY/qyc5tSmY+T/MjS07FXd3PxPe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/aRsO6aOT+j86QzyvFzV6
P1uCYVT7yvo/E+gMhGsSez+GZYDTpPH6PxqLY2xwAnw/IqGYS8wN+z/bxU5j
fuJ8P+8FpDCGG/s/fbrJvyK+fT/CbrAmmh37P0ytyi94rH4/lw2LZZkT+z/W
N2Cu1op/P3ANZJhA//o/RuA9IPM9gD8wc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1C9B
O8UA+j84ObaySH2CP2ITGAIJsPk/XE1uAyH0gj9XgEhmS1n5P12tcNv9YoM/
XGEQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/hPnjb9jv4P08/HUJy
uYQ/g2vxfqfX9z9LxrfnzzCFP1A2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/ouiUeCeD9j/0GbS0co+GP+a+MB5rC/Y/sRRuJf39hj9j5a7vUpr1
P4UO6x/gdYc/S2jNFJce9T82VLKhx+WHPw68uxR8qvQ//pg8rQdfiD/nGdNb
biz0P7a6jusS1og/HKxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/0DHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/wvjIBw==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$292350#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981908`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AANCro4J3Pt2pS7z0
xis/pg0Qjc6NtT+0o2cCBfI8PwCKjRp2bMY/EHf5R5CART/Zc5vXap3QP0zr
PDvRZEw/Nq8lxyvd1T95KFhlTe9RP9DlGwigfNs/NTpkZ1ZsVT9xc8GIdFPg
P6ZEiLcjNFk/NzeInUYS4z+aNuudSupcP+8jWLRZtOU/vENQ30owYD8WPyC0
IRnoP4botpbSEGI/xq5+zl2e6j/FvEZrbNFjP/RLCpAe5ew/xQT2CjOJZT+I
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7i4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/EAV0WMcc9j9uV/4cjQ5yPzxAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pvaReM8h+D8DDBQMH8t0Pz2f44jp
s/g/TBGQ0dGrdT91YmQs8y35P3XQm/waiHY/qyc5tSmY+T/MjS07FXd3PxPe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/aRsO6aOT+j86QzyvFzV6
P1uCYVT7yvo/E+gMhGsSez+GZYDTpPH6PxqLY2xwAnw/IqGYS8wN+z/bxU5j
fuJ8P+8FpDCGG/s/fbrJvyK+fT/CbrAmmh37P0ytyi94rH4/lw2LZZkT+z/W
N2Cu1op/P3ANZJhA//o/RuA9IPM9gD8wc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1C9B
O8UA+j84ObaySH2CP2ITGAIJsPk/XE1uAyH0gj9XgEhmS1n5P12tcNv9YoM/
XGEQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/hPnjb9jv4P08/HUJy
uYQ/g2vxfqfX9z9LxrfnzzCFP1A2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/ouiUeCeD9j/0GbS0co+GP+a+MB5rC/Y/sRRuJf39hj9j5a7vUpr1
P4UO6x/gdYc/S2jNFJce9T82VLKhx+WHPw68uxR8qvQ//pg8rQdfiD/nGdNb
biz0P7a6jusS1og/HKxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/0DHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/wvjIBw==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$292350#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981908`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {46}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGI9BgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gaovY1Qe5ug9jbbv+GaUH22tcV+Ldj+Vvs8oWagUa1Qd7TZf5IsYz2x
tw3qnnb7YsVMr6M32+1NwO7qsP+qEdN/6GuH/Taw+zrty0HWCHZB3dllDwCe
S7Qu
   "], CompressedData["
1:eJwBgQF+/iFib1JlAgAAAC4AAAABAAAAAAAAAAAAAAA0ioxNc4m7P2Y0/HmX
eMs/Or5lU3eF1D8U1V6ZujXbP5qJJ9yb4uA/xZaudDYW5D8H/89kIzLnP0yF
V+MXM+o/egcvBg8W7T/v39TDSdjvP776IaesO/E/pV+NnIx48j/4nril2KHz
P+8ZapvKtvQ/aa2a68C29T8gt2mAPaH2P52zt5Hkdfc/YdVJaXs0+D82xyZL
59z4P5eZCXosb/k/VK98dG3r+T/JmJ9A6lH6P3Mp+e//ovo/9BtLKSjf+j/H
G+Cy+Ab7P81tg9giG/s/cASuxHIc+z+EkIj9zQv7P1TF1lgy6vo/T2EOJLO4
+j/DvEY2sir6P3+7qTCaa/k//jhFb56F+D8koFeRMAf4PzBzks68gvc/hFkZ
5WP59j8sgVIqNGz2P3Nlwbcn3PU/dpUqSCNK9T9x2XoH9rb0Pw678INZI/Q/
r9lrh/KP8z9XNsH1Uf3yPxL/Wh/2a/I/u8Ks/Evc8T9Tg8EQ
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662625626200384*^9, 3.7992125674964523`*^9, 
  3.799212800167831*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"ef1e1ede-6800-4e1a-9a8a-71f8ecc43416"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626236492010603`*^9, 
   3.662623652752903*^9}, 3.799212531139517*^9},
 CellLabel->
  "In[238]:=",ExpressionUUID->"757f8d27-49aa-4b6a-bf4d-99a07057acb5"],

Cell[BoxData["61049.63188023506`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662625626266868*^9, 3.799212567508616*^9, 3.799212800221095*^9, 
   3.799224529550167*^9},
 CellLabel->
  "Out[238]=",ExpressionUUID->"eee69ecc-f092-4802-8ee2-4af0e3c4de0f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9},
 CellLabel->
  "In[119]:=",ExpressionUUID->"4d8ac11c-2d99-4a2c-9304-7c7688c4bfc1"],

Cell[BoxData["0.00897570642964323`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819416198814373`*^9, 3.481942093179961*^9, 3.6626256284126587`*^9, 
   3.7992125675779953`*^9, 3.799212802210847*^9},
 CellLabel->
  "Out[119]=",ExpressionUUID->"e19ad825-b69e-494f-98e7-7fde24afe947"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BO10", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BO10", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BO10", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9},
 CellLabel->
  "In[120]:=",ExpressionUUID->"bace1cb2-a4e2-4b19-8fa7-dd30a5449edf"],

Cell[BoxData["0.005594057700839172`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.481941624492373*^9, 
   3.481942097749235*^9, 3.66262563115217*^9, 3.799212567606304*^9, 
   3.799212804408636*^9},
 CellLabel->
  "Out[120]=",ExpressionUUID->"e599eda5-e74c-47c2-a819-ffe781a1260c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 
  3.478970602486655*^9}},ExpressionUUID->"17a3342e-9e8b-4795-a16a-\
47c460a7b7cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v10", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.010"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.47836555422621*^9, 3.478365578866078*^9}, 
   3.478366553883871*^9, 3.4783667391579103`*^9, {3.479485983949397*^9, 
   3.4794860302373734`*^9}, {3.4794860941303663`*^9, 3.479486095079904*^9}, 
   3.4794861957899227`*^9, {3.479502242049817*^9, 3.4795022420685263`*^9}, {
   3.47965572449089*^9, 3.479655724556625*^9}, {3.479655785531518*^9, 
   3.479655785532816*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"bfa8b184-c367-4662-ac83-aa02c4a7b9f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.0125405`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.4794861147697887`*^9, 3.479486119482292*^9}, 
   3.479661794400094*^9, 3.4796627436715107`*^9, 3.47966574239032*^9, 
   3.4802437567011843`*^9, 3.4806923249227753`*^9, 3.4815660675895853`*^9, 
   3.4819416246164713`*^9, 3.4819420978508997`*^9, 3.662625631374776*^9, 
   3.799212567648368*^9, 3.799212804451633*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"611b3ed1-16d2-40b3-bec1-42b6253522a2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "0", ",", " ", "0.5", ",", " ", "1", ",", " ", "1.5", ",", " ", "2", ",", 
     " ", "2.5", ",", " ", "3", ",", " ", "3.5", ",", " ", "4", ",", " ", 
     "4.5", ",", " ", "\[IndentingNewLine]", "5", ",", " ", "5.5", ",", " ", 
     "6", ",", " ", "6.5", ",", " ", "7", ",", " ", "7.5", ",", " ", "8", ",",
      " ", "8.5", ",", " ", "9", ",", " ", "9.5", ",", " ", 
     "\[IndentingNewLine]", "10", ",", " ", "10.5", ",", " ", "11", ",", " ", 
     "11.5", ",", " ", "12", ",", " ", "12.5", ",", " ", "13", ",", " ", 
     "13.5", ",", " ", "14", ",", " ", "14.5", ",", " ", 
     "\[IndentingNewLine]", "15", ",", " ", "15.5", ",", " ", "16", ",", " ", 
     "16.5", ",", " ", "17", ",", " ", "17.5", ",", " ", "18", ",", " ", 
     "18.5", ",", " ", "19", ",", " ", "19.5", ",", " ", 
     "\[IndentingNewLine]", "20", ",", " ", "20.5", ",", " ", "21", ",", " ", 
     "21.5", ",", " ", "22", ",", " ", "22.5", ",", " ", "21.10", ",", " ", 
     "21.03"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478359123403325*^9, 3.478359312201968*^9}, {
   3.478359382197403*^9, 3.478359482378661*^9}, 3.4783602880061617`*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"385289ce-be9a-46d2-8000-5cd05c46f4d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.6", ",", " ", "24", ",", " ", "26.4", ",", " ", "28.6", ",", " ", 
     "30.7", ",", " ", "32.7", ",", " ", "34.7", ",", " ", "36.4", ",", " ", 
     "38.3", ",", " ", "39.7", ",", " ", "\[IndentingNewLine]", "41", ",", 
     " ", "42.6", ",", " ", "43.8", ",", " ", "44.8", ",", " ", "45.7", ",", 
     " ", "46.4", ",", " ", "47", ",", " ", "47.6", ",", " ", "48", ",", " ", 
     "48.2", ",", "\[IndentingNewLine]", "48.4", ",", " ", "48.8", ",", " ", 
     "48.7", ",", " ", "48.6", ",", " ", "48.3", ",", " ", "48.0", ",", " ", 
     "47.4", ",", " ", "47.1", ",", " ", "46.2", ",", " ", "45.6", ",", 
     "\[IndentingNewLine]", "44.8", ",", " ", "44.0", ",", " ", "43.4", ",", 
     " ", "42.5", ",", " ", "41.6", ",", " ", "40.6", ",", " ", "39.6", ",", 
     " ", "38.7", ",", " ", "37.8", ",", " ", "36.7", ",", 
     "\[IndentingNewLine]", "35.8", ",", " ", "34.9", ",", " ", "34", ",", 
     " ", "33.1", ",", " ", "32.1", ",", " ", "31.3", ",", " ", "33.3", ",", 
     " ", "33.4"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47835979499054*^9, 
   3.478360057375266*^9}, {3.478360132331086*^9, 3.478360132808681*^9}, {
   3.478360292284709*^9, 3.478360320802071*^9}, 3.478360369604032*^9},
 CellLabel->
  "In[123]:=",ExpressionUUID->"85cc34c7-864e-4269-8e0f-16cbc322e570"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10", "-", 
         RowBox[{"m10", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.",
     "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
  3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
  3.479486146227991*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"137e75f8-6f4d-40fa-ad7e-bad45f9f505f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25.", ",", " ", "24.5", ",", " ", "24.", ",", " ", "23.5", ",", " ", 
     "23.", ",", " ", "22.5", ",", " ", "22.", ",", " ", "21.5", ",", " ", 
     "21.", ",", " ", "20.5", ",", " ", "\[IndentingNewLine]", "20.", ",", 
     " ", "19.5", ",", " ", "19.", ",", " ", "18.5", ",", " ", "18.", ",", 
     " ", "17.5", ",", " ", "17.", ",", " ", "16.5", ",", " ", "16.", ",", 
     " ", "15.5", ",", " ", "\[IndentingNewLine]", "15.", ",", " ", "14.5", 
     ",", " ", "14.", ",", " ", "13.5", ",", " ", "13.", ",", " ", "12.5", 
     ",", " ", "12.", ",", " ", "11.5", ",", " ", "11.", ",", " ", "10.5", 
     ",", " ", "\[IndentingNewLine]", "10.", ",", " ", "9.5", ",", " ", "9.", 
     ",", " ", "8.5", ",", " ", "8.", ",", " ", "7.5", ",", " ", "7.", ",", 
     " ", "6.5", ",", " ", "6.", ",", " ", "5.5", ",", " ", 
     "\[IndentingNewLine]", "5.", ",", " ", "4.5", ",", " ", "4.", ",", " ", 
     "3.5", ",", " ", "3.", ",", " ", "2.5", ",", " ", "2.", ",", " ", "1.5", 
     ",", " ", "1.", ",", " ", "0.5", ",", " ", "\[IndentingNewLine]", "0.", 
     ",", " ", 
     RowBox[{"-", "0.42"}]}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.480242266026979*^9, 3.4802422811926517`*^9}, {
  3.480242551485073*^9, 3.480242638696825*^9}, {3.480243603406623*^9, 
  3.480243604629949*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"08ac2375-fbe3-484d-8d93-994ce7d26d31"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f10b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "33", ",", " ", "33.9", ",", " ", "34.8", ",", " ", "35.6", ",", " ", 
     "36.4", ",", " ", "37.3", ",", " ", "38.5", ",", " ", "39.3", ",", " ", 
     "40.2", ",", " ", "40.9", ",", "\[IndentingNewLine]", "41.7", ",", " ", 
     "42.6", ",", " ", "43.3", ",", " ", "43.9", ",", " ", "44.5", ",", " ", 
     "45.2", ",", " ", "45.5", ",", " ", "46", ",", " ", "46.3", ",", " ", 
     "46.6", ",", "\[IndentingNewLine]", "46.7", ",", " ", "46.7", ",", " ", 
     "46.7", ",", " ", "46.7", ",", " ", "46.4", ",", " ", "45.9", ",", " ", 
     "45.4", ",", " ", "44.7", ",", " ", "44.1", ",", " ", "43.1", ",", 
     "\[IndentingNewLine]", "42.1", ",", " ", "41.0", ",", " ", "39.7", ",", 
     " ", "38.4", ",", " ", "37.0", ",", " ", "35.3", ",", " ", "33.5", ",", 
     " ", "31.6", ",", " ", "29.7", ",", " ", "27.6", ",", 
     "\[IndentingNewLine]", "25.6", ",", " ", "23.3", ",", " ", "21", ",", 
     " ", "18.5", ",", " ", "16.1", ",", " ", "13.5", ",", " ", "10.9", ",", 
     " ", "8.35", ",", " ", "5.70", ",", " ", "2.97", ",", 
     "\[IndentingNewLine]", "0.376", ",", " ", "1.90"}], " ", 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480242672165991*^9, 3.480242777357607*^9}, {
  3.4802428393374243`*^9, 3.480242994903599*^9}, {3.4802430986494913`*^9, 
  3.4802431295923853`*^9}, {3.480243226913352*^9, 3.480243571963694*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"fb52f218-0295-4138-aee9-078f0f6dbdfd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c10b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m10b", "-", 
         RowBox[{"m10b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v10"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47837088802363*^9, 3.478370914162881*^9}, {
   3.478961618977281*^9, 3.478961625407113*^9}, {3.479486145012785*^9, 
   3.479486146227991*^9}, {3.480243648203948*^9, 3.4802436546744833`*^9}, 
   3.4802439178688*^9},
 CellLabel->
  "In[127]:=",ExpressionUUID->"89f9ff9b-b7d8-44c6-a739-d7366d4e4c08"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1000", "*", "c10b"}], ",", "f10b"}], "}"}], "]"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.478358869240918*^9, 3.478358894149914*^9}, {
   3.478358970183876*^9, 3.4783590158067007`*^9}, {3.47836015386373*^9, 
   3.478360163119385*^9}, {3.478366673756214*^9, 3.478366679969379*^9}, {
   3.478367462673428*^9, 3.4783674799853067`*^9}, {3.478368631699589*^9, 
   3.478368685400792*^9}, {3.4783687314761667`*^9, 3.478368733441554*^9}, {
   3.4783687696995564`*^9, 3.478368770875265*^9}, {3.478370370616754*^9, 
   3.478370372904202*^9}, {3.478370502073501*^9, 3.478370514529298*^9}, 
   3.478370885346918*^9, {3.478370917867898*^9, 3.4783709191468763`*^9}, {
   3.478961631541224*^9, 3.4789616328231297`*^9}, {3.480243885079197*^9, 
   3.480243886827784*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"d71f22e6-3597-4777-981b-faefce5cd1af"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdk8srRHEUx28S0jR5XMN4zmDGTFIyJEm/M2bmzgIppJSVoryysLHS/AFk
ozTKziOSBbFSRKywGBaGhWQhK6Yh5BHzO9+fhVO326fP+Z1zOvd37X1jHf1J
mqbV/j6J9/X75NCu7iYtESEiybMu8iQiDtZdNCDDC19BpyeJ8NKV9BWc72mG
d3L+Mlh3cn3ywTvgwbqD5sO/YfXDl3O9cbBezj6qfBn3bw3Al6EeeLYU8ytf
iv4GvJ3rhcG6nf2+8jZmLQhv4/rOIO3Evy4m3CXor7iY6/UEaVty0R+zL/zH
Bf84H/tT562Y3wDnMW8ZyM/FecUWnsek8nOYpwLwOrzibHxvPzgL+/XhfCbm
UZyB/GYauv9YjXWYsW8vDUo2YX9Eo5LTsV9BI5LTMH8TOAW+kYYlJ4MbwEnY
bz36afgedXR+9tp5t/QpeJ4aupL8Jvj+VFNU8jN7rZIuJT8Jvq8O2lh4XDlu
eRA8j43WJd/CW6ir8aZ9ei4iDl9cvTMHqRSSF3xRrMUibX0Zl8JI7jZXbR7t
8f/wLX4AeiSFBA==
      "]]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.16950000000000126`, 12.5405}, {0., 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.478358895979022*^9, 3.478358972250873*^9, {3.478359003617921*^9, 
   3.478359016368936*^9}, {3.47836013995588*^9, 3.478360163674849*^9}, 
   3.478360374248694*^9, 3.478366680674487*^9, 3.478367480647264*^9, {
   3.478368632443274*^9, 3.478368686420216*^9}, 3.478368734382247*^9, 
   3.478368772182708*^9, 3.47837037368084*^9, {3.478370502759603*^9, 
   3.478370515076358*^9}, 3.478370922682131*^9, 3.478894392703998*^9, 
   3.4789609320542917`*^9, 3.478961633495669*^9, 3.479485745361719*^9, {
   3.479486132534732*^9, 3.4794861523034983`*^9}, 3.479661794640168*^9, 
   3.479662743820785*^9, 3.479665742592085*^9, 3.480243756892487*^9, 
   3.4802438881018877`*^9, 3.480243922252112*^9, 3.480692325124424*^9, 
   3.481566067790287*^9, 3.481941625063833*^9, 3.481942098115423*^9, 
   3.662625631567731*^9, 3.799212567775642*^9, 3.799212804559462*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"d529a869-07d0-4237-80da-69fd5964d65b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"quadsect", "[", "BO10", "]"}], " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c10b", ",", "f10b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "15"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, {
   3.479496268693829*^9, 3.4794962786689043`*^9}, {3.479496348223323*^9, 
   3.4794963960461197`*^9}, {3.479498099636911*^9, 3.479498116836277*^9}, {
   3.479661771654023*^9, 3.4796617820129557`*^9}, {3.4802439413724613`*^9, 
   3.480243944481743*^9}, {3.480243980865246*^9, 3.4802439981026154`*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"0e5bf6c5-df10-4466-adb0-1a4bb5380fbc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"quadsect", "[", "BO10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, {
   3.47949628323759*^9, 3.479496283675993*^9}, 3.479661799309276*^9},
 CellLabel->
  "In[130]:=",ExpressionUUID->"aab122d0-9757-415d-acd6-ff7fa2ba159a"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
      0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
      45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
      46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
      0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
      0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.005212375000000222, 42.9},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.005212375000000222, 0.0090405}, {42.9, 46.7}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.4794962841775846`*^9, {3.479496352894401*^9, 
   3.4794963992533207`*^9}, {3.4794981044621353`*^9, 3.47949812000502*^9}, 
   3.479661800865757*^9, 3.4796627438875427`*^9, 3.47966574265806*^9, 
   3.480243756913067*^9, 3.480243949523509*^9, {3.480243993159051*^9, 
   3.48024400283206*^9}, 3.480692325191889*^9, 3.481566067857037*^9, 
   3.481941625118208*^9, 3.481942098169249*^9, 3.662625631684383*^9, 
   3.799212567812482*^9, 3.799212804595092*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"d28d59cb-400d-4b2c-a6f0-a100311723a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{
    RowBox[{"quadsect", "[", "BO10", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, {3.479496292861574*^9, 
   3.479496298886504*^9}, {3.4796617492454433`*^9, 3.479661752316023*^9}, 
   3.4796618065898314`*^9},
 CellLabel->
  "In[131]:=",ExpressionUUID->"f79e74b4-094f-44cd-87ce-9907a0a87f23"],

Cell[BoxData[
 RowBox[{"1.5052714250000179`", "\[VeryThinSpace]", "+", 
  RowBox[{"12320.257983193287`", " ", "z"}], "-", 
  RowBox[{"837815.126050421`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4794962995907373`*^9, {3.479496356170768*^9, 
   3.4794964020264187`*^9}, 3.479661807352735*^9, 3.479662743921276*^9, 
   3.479665742692679*^9, 3.480243756989594*^9, 3.480244010141424*^9, 
   3.480692325243474*^9, 3.481566067893443*^9, 3.481941625191751*^9, 
   3.4819420981852303`*^9, 3.662625631766376*^9, 3.799212567844816*^9, 
   3.799212804611115*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"e16912de-3840-4a6a-8871-1ea4d7f89b5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{"quadsect", "[", "BO10", "]"}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO10", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479496302750866*^9, 3.479496325477083*^9}, 3.479496410959276*^9, 
   3.4794980716129704`*^9, {3.479498110109133*^9, 3.479498134380343*^9}, {
   3.47966180953386*^9, 3.479661832340538*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"c769e96c-c61c-40a0-9e0c-b4f689616d07"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{0.005290499999999999, 43.1}, {0.005540499999999999, 44.1}, {
       0.0057905, 44.7}, {0.006040499999999999, 45.4}, {0.006290499999999999, 
       45.9}, {0.0065404999999999994`, 46.4}, {0.0067905, 46.7}, {0.0070405, 
       46.7}, {0.007290499999999999, 46.7}, {0.0075404999999999995`, 46.7}, {
       0.0077905, 46.6}, {0.008040499999999999, 46.3}, {0.0082905, 46.}, {
       0.0085405, 45.5}, {0.0087905, 45.2}, {0.0090405, 44.5}}]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VO0XAHBLtqQdobyIsiQhS5Fzw8y8SmUrIVtK/KyRsc29w0jZi1ey
VJRSSkqEkJDKUhJRihKiUAlRpvQ789d8vp/zuXOfe855nnuu4sEAm8MCfHx8
Evx8fLzf8HQ3EY2TTOjd8r1uzQyNUPY/2e8Rx4Tp3BPm6eg2RvG9c/FMUPZd
cHfhLMa5XJ/FSUx4o3/vwCy6zf1s+/fTTDh5RuTJ8180QkmrLasymwmToQYi
5B8a0dJstIFezIRlLwb1mhfQCbm/UtbuXUzwfOlvqbqCTkgvPPpIQz0Uvj5x
ktmpTSdS+7Ie24eHgu/X+yfULemEqu9r3ZnHoTAzu2Ot7WE6IZNT1aoqFwb7
ZmWDLdh0Ii7NZ6LGOwzijLR6zDPohLV6HXysDYMNqso32m/SCQNSncteHg7U
cwPzlId0IifTw4zlFg5/TG6o5nTTCUc7onzR3XBY/HN82/hnOnH29djdecEI
UL12OPDOHJ2YkL6p6GEdARcDb0jMiDGIy7PLKp2uRMDOlt0xujIMojuX9vbu
VATkGpbZb1zHIA5+Wq12+d9I8PSq//RRh0GIj4sNLjgXCcdkTJIFTRiETuUj
tSefI8HK3y5VlcEgSpVVctaYsCC+vdqydg+DONG3JnI/sMDjpdG9t2jHDCmn
/wgW9JcfWv4LLSAqKidmxoKn0iUJulYMwmZsNHuawQJni83/XUVPltzObrXG
632GBJOs8X5gnB1+mAXSN8Y86LYM4o6DbVZXEgvEZTLko/cxCNGLM83qKSz4
5c9uyEE7f8qaY59iQTRVuqecFw/td1JPY4FrC1dljBdP95Nnn2WBg6REg609
xp+fzFe9xAJGmE6lwn4G4WJeczOyggULg+LOFTowiLJE13ftlRjnNnnXo8U6
BZasq2KBgomdQg8v7m4R2F7DgtyJHRaijhhnd+uoNLDgnei9hMPosnsTFW1P
WWAnnNkq54T51FJpUBxgwXo9d1roAQZh+SysJnCQBRc7mW8S0Sk+T8sfDLEg
5es1hzz08mvBN5xHWFCTdVCqGS2r2JCeNc6CY4804mWcGYTqCtcjy2ZZsC1I
0q4cTZ/NXMS/iASaIp393oVBxJ0ZF7aSIOHvrjH77+gWXYI/dzEJ6rNFsoKu
DGJ34MgP42UkdNfGuqxD7/2s9z5MioSYtcnvfdCH3naUTCiQYGw69XgSHf1g
kX2/HgnKXas1JtwYxFDmf69WGZBQJsk0n0f/GyS739qQBL6khh2L3BnEUhVV
h4atJDyT0ZNXReclmDldBhK2VkX1u6Br90a4elmQ4LT4TkcTmjs2cmTiAAn3
BUm/lINYj0f+n1RdSHjBNVbJRjdc+OHl7krCJbWJ5ivoBGvB/3W4kxCxbtOb
GrRshbxvmScJ3MtSUqNoQ87ewLBAEszvklzCg0GErHoYxnechFmlMlY/2jFq
2sI2loT9yttzRtHEJxW5ghMkjAd550+jF1bG3d8ZT8Kt2cRA0UMM4oL9boGz
KSRk5q6a34huyuhJ1MwiYc7LajgUfXN+oXNUNglJ29IuRKHTPI03duaQYO0a
QMSjnfVz28MukBCcwCWy0ZNdhyQb80n4h+2kV41eLTlxwbGYBJGBLWM/0fyk
YuDNWyQ0xW/axneYQQwP2WznKyHhAdUQJoIuKbs7eKWUBFOryiJJNN0uUvV7
JQm3U8dEtNEaNUW/zKpIWJhfU2CAXqr8riWjmoQsfjUtE/TbKcLPuJaEXQWd
v3egA/8TvnPyIQlyKYGJHui9XIOYN40kSIitDvVGb/XwttN8TILei4OWAWgh
3aczHU0kyFg0lEagsztSjeTbSLB41RRyGt24bM2jstckbPGbflyBbi2LXv29
h4T6IuCrQXfYDwdrvsXrU4XW1aE/nL+lVNBHgs6//AZN6Hk106izAySIB1b6
v+Ld71nBq85BEoS6X4u/RS8KFNda+pGE1v7gM+/QsuUv++JGSGgckvH/iDYw
PWIUMY79VaCiN4k2+diaVv6FhEc6cvo/ePmK2zQ6+RX7xSNx7U+0XduvTJ/v
2G9lbx/+QTsddZm4OklC0MtqJp8nno8rHzKGpkjoz5SSEkQHOibNHJghQXWp
sawoOvTPxK6sWdxvDcLshWgqb++Vrp8kFMhati9CJw/L2+3mknCgkm64DH09
qKQE+CgIvMldI4MukZQSY/FTUHkiZ1gWXVkZ4VYpQMGzBeU5q9FP5s2WaAtR
cPCbY+s/6LaL1zz9hCkYcPpIU0R3m0vUFopQoOU3WqSEHkro9lVaSIE+dYhQ
QY9pGjW6iFMwTvb4rkNPtufK5Syi4KhSc+x69FzwguBXEhQ0+ugmqqL5pb1b
ViyhYNhhFamGFq16pmi1lILu8VAndfRSZ53wpGUUpCnbrNNAS/OdbW9aToE8
/9U+nuXzueuFVlIQwmFGb0Cr0N3Y2yUpOH+tbpkmesPnxm5SioLU4NgUnjcn
qW2skqbAbrBxlmcjrZTYmVV4/1lq10a0acdkr44sBWYlpad43hFivzlAjoKg
JR61PFuvqkm8sZoCn+XJPTzvr1YYHFlDweYq7Q88u7rEblX+h4JmYesunj35
R1PdFDBfP0fv8ux3effnc4qY35S/HJ6PMUqJHiUK3JpTjHmOHJXOlFSmYFNh
5gBvfZxk1jdrFQqeaq4J4Tlh0wd6yjoK9OxXT/OeN7WTdqFlPQX+KhmuPB9/
5viAT42C35RINS8/YU8C+vXVKfhf111Bnn3rj/P7aVBQoXpxCy+/btVZSvkb
sL5hzQd4+be7W2zWo0nB2KONfrz6MG49PLREi4KOJS/+x6vfxvwvBZHaFJhk
P9Xk1VvpvEBTiQ4FD9+oTK1FS52V/jyiS4HyqporvP74k7Bdw06fguPxuR28
fpo4vs8ywYACzv1xS3le/1A+fnWGFLh+ZZbx+u9p0JlbG4wouEM33cnr1zrf
6+0HjSnQ8I+JkEaXej74nrmNgug0/rOS6GzHz7pCBAWtL8rO8vo9xW7ezmg7
BTXjnyOX8PK3ewXzqCkFSQsO7JJAe5tuq+wzp6BFfbaCt58OGNv0rKBj/25R
sBZGW+kfmbNgUBBlfuIVb/8Zqqcal1vgeqzFiuZxvwov/1iXshvXTx8LnkLP
ic99aNxDwaDRb+YE+ovQEkGuFQVrN+448gX98pch7YgtBdvEzi8ZQed/SGqG
/RS8z5Jn96Az3l4cDXHA/mFKj3ehE7rKxYscKfDcs4vegQ5q7t+1yhn77WdA
QwuaKNncMeFOQZ9yak8VevMNi6l1HhSs/3T0djl6/RWXlc6HKNhz7dSxO+jF
WXH7mj0pMPqH01iI7ovqfXPRB59vxDTmLDrC6vigTQjW74Mui3fefntttjef
SUHkd807vPP4kLvgk6lQCsRsVnTwzuvdQZzr6REUFAnlPbdHK6VHHe1mUzCv
X1/PO+9bX7H+OiRQ0F+vxBHlrdfN+Oj1RAoE3r/Yx48u/8QdmEuigGvpKzmH
75+8XxGPc07h+STnYTWGPiYXntyXToEXZ//9p7z3lWuInHsuBZlhB4MT0akj
m5NL8rC/8h8Pc9DCgdPz/JcoOCEvZR6BnogKHrh0mYJ2kdAaL3TjpaOFQ4X4
/5eJy+Zov2E/A68yCr4JTe35ie/fWj9P24BmrIf3S+k96L3aDjsLW3B9H6oT
zNHj0zvNBlspmC72Gt2ClmVp69q3UcBiLA9URjMTfi+HTowHXUn/ifPAxqtp
HYv7KAgobTU9j87tr7UunqAg+4207mucP/Qvl1h8+o7P97XQpBXdduTydqUp
ClbY8xvUon9/jdfO+EGB0Hq+r/no/X/sllFzFOyo3xbiz5t3ZMfady1gg9v7
yk9/cR6KspW2+iLNhsb6Yo+V6MwrZZnbZdjwlht9XxBdMmv94YwsG9Kf1PJN
4Xw1kJMUZLKGDd9WhJi9QJsP8Z85pcQGRtTLe0lokZDxHm1NNoRfdfnfX5zn
UjLqPZimbPillfemE+e/gk8uRS1mbDhy4Yp7HfrB1t/T8jQ2RF5Y2VGEnnin
f+IJgw0nbbUCYtE264uurdrFBrNU+2w9tGRlxpcqezYQTsFlqThvnuvxCf3r
y4Y9aq9nDXF+vci5F7/Lnw3Pe5kr16ILNETO5QSwocvOSk4CfZu8VGcQxAb/
tNKRfpx/Hyr2iAWGsmHIzCjyJHrUm36uP5oNTew9ye04PxvOKdTXZ7DhuFOi
sw3O312y3QuP17Gh5ZJV8cq9mO/5ffnV9Wy4KSumzbXDfh58ZTTVwIY4kRd5
H9CBN3p8Dz5igxpxilGMXmTc10a0sEFC81EJHW3qPJT2p5MN3j+kfgXj98Pt
3EnZ0BGsD2FjW4ffF7S0k5J6IlHg9mC9vsJu3D8jP7YGaUcB8aD+vQkN939e
67r+/VEwp2eqVGqE57NB0b8n2VGw1lNRSl2bQQRceMcOK4yCqqnXI97KWE/v
MDK7PQoaD4tHMaQZhILQodPC3ChomFk8dlsE+2lBhXe+UjRk3a9f8m6WTogP
rAwPt4iG2OfttuojdCLkVOP5rOBoCLbvel7RSSfkL76NG82OBpPq4pPWdXRi
mmMeH/soGpLHW1W+FdKJ/aaVDxy+RUOBnEVoehqd4B7+r8ZFigPyJhL005F0
4qlDXdtNggPMeNtSM3c60Vtid1XTiwMbNKWZwQw6ETEydXc4hQM1mVfPzWyg
E7QvQz2fKzkgrJX9e3gxndhjv61xTT8HWM/H/uZ8pxFRgufbn6INo2QjpNC3
b/3ujfzAgX1Bbr2nJ2jEUtGaHz0DHLgtq+MQ+41GdFRuXZ/xkQP9keO6fl9o
xD5Zw4TFYxz4N+q+n+FnGuHSp2P19wcHFFLbJ2v6aURKfNqB4hkOvPMbCdiM
fqA36eU8y4HfiZJdN97TCIWUkujqn3i/pAr77Hc0YsBkU2kolwOnzy83YfbS
CM88TakJvhgQFVA5pfaaRmRYJivl8sdA0/St5NxXNOLJz/GNuwViYFjV5pgk
WtW6iFEkGAP0vb2/+LppxCi/RriXcAxwakWGuztphGxxQqy0SAyY11iqWKJ3
Oo6mPkYf5F6zrO+gEUV3Cq8ri8VA3bartjde0IheF7GKTrTAdgtdBbSEuPdD
zsIYyIsV4Ka30wiTiqbn2uJo8c7rYmh/D9XefjRfZ5Up9ZxG/B/DCXxp
        "]]},
      Annotation[#, "Charting`Private`Tag$294506#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.005212375000000222, 42.9},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, {3.479496311016521*^9, 3.479496326374604*^9}, {
   3.479496357540121*^9, 3.479496411535761*^9}, 3.479498073597056*^9, {
   3.479498111163803*^9, 3.479498134994309*^9}, {3.4796618101860933`*^9, 
   3.479661833787763*^9}, 3.479662743973064*^9, 3.479665742731904*^9, 
   3.4802437570207*^9, 3.480244013149205*^9, 3.480692325283217*^9, 
   3.481566067931078*^9, 3.4819416252399197`*^9, 3.481942098241775*^9, 
   3.662625631852418*^9, 3.799212567910635*^9, 3.7992128046693277`*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"6bfbc409-c98b-4f68-a7b9-e9e5bccc1552"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO10", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9, {
   3.480252658965609*^9, 3.4802526608978167`*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"becee2b2-4d84-4484-9d32-defedfca584e"],

Cell[BoxData["0.007352611334002004`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480252685630768*^9, 3.4806923253165283`*^9, 
   3.481941625292397*^9, 3.481942098249529*^9, 3.662625631900302*^9, 
   3.799212567919506*^9, 3.799212804678075*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"9e970f14-24d9-445f-b2b5-1926d5f51793"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO10", ",", 
    RowBox[{"zmaxq", "[", "BO10", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9, {3.480252661732663*^9, 3.480252662768613*^9}},
 CellLabel->
  "In[134]:=",ExpressionUUID->"2b309981-7b7d-440a-b82c-8c01b1981b68"],

Cell[BoxData["46.798305667527835`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480252685747806*^9, 3.4806923253494253`*^9, 
  3.481941625327002*^9, 3.481942098307748*^9, 3.662625631954908*^9, 
  3.7992125679541473`*^9, 3.799212804710845*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"dbde4cfe-446c-4aed-aa60-97b4daa54dd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO10", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO10", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}, {3.480252663458889*^9, 3.480252664767067*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"7c49e19e-4363-4f73-8b6e-1a43e496b3ee"],

Cell[BoxData["0.00015676086466604768`"], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.4802526858259706`*^9, 3.480692325383745*^9, 3.4819416253693733`*^9, 
  3.481942098341453*^9, 3.662625632016404*^9, 3.7992125679638157`*^9, 
  3.799212804718833*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"e3db57d7-d7d2-4a91-8c7d-e0c68706362b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 
  3.478970908928837*^9}},ExpressionUUID->"33369bd6-4667-4e2d-9f02-\
e69a722930b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO10", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO10", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}, {3.480252675294587*^9, 3.4802526771361427`*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"c7efb6f5-403c-4fe9-808d-5c2ffef498ea"],

Cell[BoxData["0.03621623002547349`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480252685882967*^9, 3.4806923254154778`*^9, 3.481941625424059*^9, 
   3.4819420983918962`*^9, 3.662625632057599*^9, 3.79921256799863*^9, 
   3.799212804753097*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"52cb7017-bdc9-4774-8afd-53f1fe2f7613"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO10", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c10b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO10", "]"}], "*", "f10b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO10", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO10", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.0055", ",", "0.0093"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"cf9944be-38ea-4989-849a-5e06ab1b9d29"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4VdsbB3BDRQiRWWiiwU9Cg8I31VUpogFxyVhRpCScc/Y5h5BOEyVT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      "]]}}, {{}, {
     {RGBColor[0, 0, 1], PointSize[0.011000000000000001`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw90HtQ0wUAB/CfXHoIAiEZzNSdiC/gkglYsNGXgcxLROpHREAaEZsoGjQE
B24BAwbjoeb5QB6WOC9qh0iKg8AbGY8kPTeW3BE74EY8hiAie/5Ykd55/PG9
733++953c3I6ybUjCCLgZV7130tE2pObUpBbovM49AWU8Y/a7vtIEe4jTvtD
toDgcXXlrYZSBPq3xO33NmA6Lph+dWspas7qFKYfDKjuq79VXl8CYsbF47q7
EZEhjmE59BLML4S9sbXOiMWmTA2vVoKy/yQXtkebIPfUpnxCk2Au4Y5B021C
4sW9JvalYuiSJ0djI81wtG8s2eVWjDY3lxbf22a0566jbTxXBHoGa93gTguO
z4p+dnAqgqsgfUVikwUbkiaYFmkh9DsuP2G4W/Gw/+Cj8VWFCHy3baN/hhXC
CMVhTaEYBf5D3IAHVvi20p93EmIk/mMX7MigoPUuLbgpKgAx6TZcfohCRd3z
tbVUPpShftWKHymw3oyXSU/lgxvO/uD9vygMrixMezaVhzUcUtdKLCLoacyZ
B7pvUTUf9/UZl0VcUXk1y7SiZVMtRk3egHDZCTU9pgTV6WX/mn+ZtqcvFy+e
cfqcxiis56WyXLtysPuit7OuikJuZNAXM/cEyGQ6k3cPUhjycxD3Kk6hpmxC
NDJhBfPtIVl9czaii7sChyutqFmU94rkWVCpy+9JrBbYRoXTn904CXJTTMQu
rgWf90Q5BXyfCY7yLbbdfTM65Jv8XK7w4bn6Ty/vFWZs+G6OnD7/Df4lC+zJ
UBOE2Z1Z3RUZODDPSJJlGNGq8GSwndJhqFC7ZZ80QCDuyjYTJ+AqSmPyjy6A
FcXraDQcw7Xflgaqol/A5m5vlzKVCr9VF/jKwHl06H7at17Lw4HJoJks2xyE
jZGVqscpIGlxjh7yWbAEs/2S35Nf//sUtrCzHiGKJHTzo9riP52C4J3kjonY
Q6/3jINovrEvJiQesz2b6dUNOuRz9P1Kr1jc0RoTM/ePgND6HvZd8zHO+TTk
/BI+CGJstJ8x+SGK1Nym2gQNCOdUvcNdNirP0459ebwPBH94qXe1P24PzHy0
W9oOIpR3RM1cidMjat5XY+Xo1Kv0Oe9tU9or2jmX6prxP6CHlNU=
       "]]}, {
      {RGBColor[0, 0, 1], PointSize[0.011000000000000001`], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[0, 0, 1], PointSize[0.011000000000000001`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k4VV0XAHAaZMjQYIgIUVIUFX2iJUQKITIUpWQIEZnvOZerhKRI5llU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        "]]},
      Annotation[#, "Charting`Private`Tag$294587#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{641., Automatic},
  PlotRange->{{0, 0.013}, {0., 1.6948581299755139`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481941625474936*^9, 3.4819420984427*^9, 3.6626256321537743`*^9, 
   3.799212568061824*^9, 3.799212804819854*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"c9320f06-1d91-4968-ae91-117659f2bacf"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (5x10 magnet)", "Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.478895153999941*^9, 
   3.478895157728011*^9}},ExpressionUUID->"3e8ab641-d0ac-4724-a259-\
68c331873309"],

Cell["\<\
bosemvals5 = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.005,\t\t\t\t(* length of big magnets *)
\t\ta->0.005,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.478895116514908*^9, 
  3.478895118897944*^9}, {3.478895285651181*^9, 3.478895286185315*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"fd944fd5-79d6-47c7-8f61-db697a9b9078"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BO5", "]"}], " ", ":=", " ", "bosemvals5"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.478895122464415*^9, 3.478895146305952*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"8ab6d7d1-aec3-4982-9aeb-d4f7c5ad9135"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9628352953498257"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0061809572312008145`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BO5", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, 3.662624014406456*^9},
 CellLabel->
  "In[140]:=",ExpressionUUID->"f55e7bfe-ea93-4c0f-8155-1bd9f471e265"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9628352953498257`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0061809572312008145`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662626007345862*^9, 3.799212568089175*^9, 
  3.799212804847822*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"38c74d42-8094-4c19-aba1-206c72b9a2c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BO5", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.478973523175459*^9, 3.478973523782423*^9}, {3.4802448296734753`*^9, 
   3.480244857272909*^9}, 3.662624016974782*^9},
 CellLabel->
  "In[141]:=",ExpressionUUID->"7e4b96fe-abcd-4197-ae39-f1075f7afa58"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662626043423575*^9, 3.799212568134398*^9, 
  3.799212804883904*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"c368cabe-9a8a-4632-aebb-41b866ca1f78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9},
 CellLabel->
  "In[142]:=",ExpressionUUID->"126f4d47-0600-43f1-aa14-0dd4c6aaac9c"],

Cell[BoxData["0.0061809572312008145`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480692325590218*^9, 3.481941625685656*^9, 3.481942098570314*^9, 
  3.662626043505526*^9, 3.799212568143976*^9, 3.799212804892929*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"85af67fd-a4ee-45e5-9106-9608638343c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BO5", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BO5", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9},
 CellLabel->
  "In[143]:=",ExpressionUUID->"4917d071-f59b-4f1e-a96c-a6c9042c6636"],

Cell[BoxData["0.9628352953498257`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.4806923256341553`*^9, 
  3.481941625797789*^9, 3.4819420986261683`*^9, 3.6626260435614357`*^9, 
  3.799212568179838*^9, 3.799212804930097*^9},
 CellLabel->
  "Out[143]=",ExpressionUUID->"331334d4-a000-4b6f-9202-91b934bf4de5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO5", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623663118393*^9, 3.662623666744122*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"2c444fb3-82df-43cc-9185-44884396c783"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxn04FAYAx3GP1x7Rc3QmhyHE1ozI5eX0a/LuZAupB2Mcljsc50bNIXEO
ed2xWu3FUtNC47mISXg6zUuPHc9YydtxnHtTuc3aaGt/fJ/P1yYx82SypoaG
BuVN/6u+1mPFCVL5vNmNZJvMo3O3QvvUwwex2UZzIZe3QnA9VVPnJQWSNJlO
Zut9EHJfBdYW+SOunmXC/ksIqpziLaJRsX1HzV9eGsc5x9PJYRsf4ejLnBmS
zSTcvWippxhRENhHk1yLfsNNP1637eEz2O16ItKM8ARfkeVfh8hi8XF4obFW
zjP0Hf9wIcQlASvBi4mmxQvgSrsaJwmJqLktflx8egnCvgA6Q5SECNOrNdoP
xRBq/6nvVp4M06bR7k9NV2Ad3CGKSUmFpCnKhceSYKOv4W6j7Vkca+b8fKl5
FWZO3AE3XToU/VkFHb+vQduosXFngYF5psuzng0paHYT5U+uZIDSp2vBmV8H
gaQ/WUlhIs7oj6nWERlaPAeVbhZZiDZx0GuvliMj+rVF1Z5sbKR42NeHKkB0
HuvI386G9BCVH6RQgP3Ne1HspyxEykqI8QwltAyIBlZjOZjxW++dW1CCalQr
Et1mY27IgxhMVoH969VtEu8zfMmgllblqjBe5eRtkpuLHlsH7ie3VJgTR/D2
ncqD+cOtQ/pCFczJGuvjgecw5GR5r2xCBa/jlDum7ufhH/Fjk+8jFfZKDUro
xp9j1/O2RP2fVCBVJjGYmvnYJhnlOZapMCs8kVQgzkdSDI1Ji1CB0zvyYH8/
BxP1Xxi+IqpAbRt1zmstQFqFV0OsUInpIwnt0xWFECVFk3ZlKRGw6GO96VOE
f6eIdU93K1H4vIFZ2F4E1uDZmwE3FGiZu7s5bXEB1w/46xp7KSAduaxRxr8A
Rr55c8wDOXQ0h/ne2sUgjgnS2wPl8PDs6gziFCPdWW4bPihDbFiGlo26GAV1
TYQSTxni2pizO4kXcX6TlWN2bx1sA7KP2+xFdKaOvuC8s460bv8D6aElKDxT
9/fj76UIh6Vvdk8JrLWkdiJLKUKHu9cmXEpR9W7K2/9cWoPdlWtE1+9K0Sz/
QadfZw1Eut+YYh8XIYbc8QLWKtRmAkF2DRcCh4naGysSdBAz7Hd2uLDYpp+M
T5CgdI/capFdhg/mB/QwuQJyZGfTI0kZpEe0aUbhK3h9mdKmF8/D+FuT3b8M
LaOrt1puPM2DryHhmJX3MkIdD3bs9y+Ht/377tX9YmzxKzQq75djbDUzYcpT
jKKwwzNbThVQWwe0OA0s4QWfnNn/bQWaM9LpqYFL+A9c5MWI
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$299722#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.9628332706428682}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxn04FAYAx3GP1x7Rc3QmhyHE1ozI5eX0a/LuZAupB2Mcljsc50bNIXEO
ed2xWu3FUtNC47mISXg6zUuPHc9YydtxnHtTuc3aaGt/fJ/P1yYx82SypoaG
BuVN/6u+1mPFCVL5vNmNZJvMo3O3QvvUwwex2UZzIZe3QnA9VVPnJQWSNJlO
Zut9EHJfBdYW+SOunmXC/ksIqpziLaJRsX1HzV9eGsc5x9PJYRsf4ejLnBmS
zSTcvWippxhRENhHk1yLfsNNP1637eEz2O16ItKM8ARfkeVfh8hi8XF4obFW
zjP0Hf9wIcQlASvBi4mmxQvgSrsaJwmJqLktflx8egnCvgA6Q5SECNOrNdoP
xRBq/6nvVp4M06bR7k9NV2Ad3CGKSUmFpCnKhceSYKOv4W6j7Vkca+b8fKl5
FWZO3AE3XToU/VkFHb+vQduosXFngYF5psuzng0paHYT5U+uZIDSp2vBmV8H
gaQ/WUlhIs7oj6nWERlaPAeVbhZZiDZx0GuvliMj+rVF1Z5sbKR42NeHKkB0
HuvI386G9BCVH6RQgP3Ne1HspyxEykqI8QwltAyIBlZjOZjxW++dW1CCalQr
Et1mY27IgxhMVoH969VtEu8zfMmgllblqjBe5eRtkpuLHlsH7ie3VJgTR/D2
ncqD+cOtQ/pCFczJGuvjgecw5GR5r2xCBa/jlDum7ufhH/Fjk+8jFfZKDUro
xp9j1/O2RP2fVCBVJjGYmvnYJhnlOZapMCs8kVQgzkdSDI1Ji1CB0zvyYH8/
BxP1Xxi+IqpAbRt1zmstQFqFV0OsUInpIwnt0xWFECVFk3ZlKRGw6GO96VOE
f6eIdU93K1H4vIFZ2F4E1uDZmwE3FGiZu7s5bXEB1w/46xp7KSAduaxRxr8A
Rr55c8wDOXQ0h/ne2sUgjgnS2wPl8PDs6gziFCPdWW4bPihDbFiGlo26GAV1
TYQSTxni2pizO4kXcX6TlWN2bx1sA7KP2+xFdKaOvuC8s460bv8D6aElKDxT
9/fj76UIh6Vvdk8JrLWkdiJLKUKHu9cmXEpR9W7K2/9cWoPdlWtE1+9K0Sz/
QadfZw1Eut+YYh8XIYbc8QLWKtRmAkF2DRcCh4naGysSdBAz7Hd2uLDYpp+M
T5CgdI/capFdhg/mB/QwuQJyZGfTI0kZpEe0aUbhK3h9mdKmF8/D+FuT3b8M
LaOrt1puPM2DryHhmJX3MkIdD3bs9y+Ht/377tX9YmzxKzQq75djbDUzYcpT
jKKwwzNbThVQWwe0OA0s4QWfnNn/bQWaM9LpqYFL+A9c5MWI
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$299722#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.9628332706428682}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAADmgSH/FjqyP1oLMOS7
K8I/tBbLq9cdyz8LzRa0tPLRP51FwgZyOtY/MLUqfaNf2j+xL1IeI1zeP150
/dkbFeE/X07ki1Pi4j8wyxNUY5PkP1xul95EJuY/WRyrgUaZ5z/v8SNhD+vo
P1J6wYqiGuo/sBYOBGAn6z/LvjXtBBHsP4psrN+p1+w/uYuLQ8B77T/++2Bh
Dv7tP2ZELlipX+4/oR7ym+6h7j9BswEse8buP+SycNohz+4/C/9lSOC97j9s
HyIj05TuP1p+wh0qVu4/+DauORwE7j8H18bL3KDtP5eupdeRLu0/fB/R30uv
7D9nHBOp/yTsPwS/456Bkes/ZryO6YL26j9Ft9L5j1XqP/S/lTEQsOk/h2mT
p0YH6T/z0YykU1zoPxq7rhI2sOc/89XBIc4D5z8Sj2Rz31fmP5SZwf4SreU/
gfUznfoD5T+04q3jEV3kP7CqFsrBuOM/v+mhKGEX4z9CVE+4N3niP1l9DPh/
3uE/2pt4Y2dH4T8HUcgA
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626054357819*^9, 3.7992125682593393`*^9, 
  3.799212814352689*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"c8377607-9031-40b4-b282-58765617e6d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BO5", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO5", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.662623664744658*^9, 
   3.662623670310789*^9}, 3.799212531141622*^9},
 CellLabel->
  "In[145]:=",ExpressionUUID->"2a59b881-d376-43d8-b396-175d1e1c9938"],

Cell[BoxData["43704.5752793726`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626260544412813`*^9, 3.799212568271042*^9, 3.799212814410021*^9},
 CellLabel->
  "Out[145]=",ExpressionUUID->"58ac029c-e6f1-4836-aa11-e17f66cebbdd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measurement", "Subsubsection",
 CellChangeTimes->{{3.478970601031336*^9, 
  3.478970602486655*^9}},ExpressionUUID->"8741529c-9780-4efa-acce-\
b0a7f8555815"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v5", " ", "=", " ", 
  RowBox[{"Recurse", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zflange", " ", "->", " ", 
      RowBox[{"0.1", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"end", " ", "flange", " ", "thickness"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"l", " ", "->", " ", "0.005"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zplug", " ", "->", " ", "0.001"}], ",", "\[IndentingNewLine]", 
     RowBox[{"zcoil", " ", "->", " ", 
      RowBox[{"0.315", "*", "0.0254"}]}], ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"coil", " ", "length"}], ",", " ", 
       RowBox[{"D060106", "-", "C"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"zc", " ", "->", " ", 
      RowBox[{
       RowBox[{"l", "/", "2"}], "+", "zplug", "+", "zflange", "+", 
       RowBox[{"zcoil", "/", "2"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"newportcal", " ", "->", " ", "0.5"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "micrometer", " ", "to", " ", "stage", " ", "factor", " ", "for", " ", 
      "Newport", " ", "NVM80"}], " ", "*)"}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478364871938177*^9, 3.4783650430215597`*^9}, {
   3.478365123922604*^9, 3.478365126702361*^9}, {3.478365254617469*^9, 
   3.4783652660805397`*^9}, {3.4783655084186296`*^9, 
   3.4783655130572557`*^9}, {3.478365552219092*^9, 3.4783656736355543`*^9}, 
   3.47948618034295*^9, 3.479486213991674*^9, {3.479502242119833*^9, 
   3.4795022421218023`*^9}, {3.479655724672627*^9, 3.479655724740677*^9}, {
   3.4796557854574213`*^9, 3.479655785465637*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"40407238-0b55-4802-84a1-94f993312b98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"zflange", "\[Rule]", "0.00254`"}], ",", 
   RowBox[{"l", "\[Rule]", "0.005`"}], ",", 
   RowBox[{"zplug", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"zcoil", "\[Rule]", "0.008001`"}], ",", 
   RowBox[{"zc", "\[Rule]", "0.010040499999999999`"}], ",", 
   RowBox[{"newportcal", "\[Rule]", "0.5`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.478365674218483*^9, 3.4788943916835203`*^9, 
  3.478960931218412*^9, 3.478973701033331*^9, 3.479490566372048*^9, 
  3.479664646024015*^9, 3.4796657673893423`*^9, 3.480084171866323*^9, 
  3.480244564038784*^9, 3.480245921425527*^9, 3.4806923260597963`*^9, 
  3.481941626208601*^9, 3.481942099102745*^9, 3.66262605449503*^9, 
  3.799212568309299*^9, 3.799212814419347*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"b09dd3e3-ffa3-4722-94d4-f01ce3e7fa13"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cal5", " ", "=", " ", "0.5"}], ";"}]], "Input",
 CellChangeTimes->{{3.4783589573423653`*^9, 3.478358966550098*^9}, 
   3.478973591713312*^9},
 CellLabel->
  "In[147]:=",ExpressionUUID->"c4821a4d-17ad-4a62-868d-79afc8bf9aef"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "20.02", ",", "\[IndentingNewLine]", "20.0", ",", "\[IndentingNewLine]", 
     "19", ",", "18", ",", "17", ",", "16", ",", "15", ",", 
     "\[IndentingNewLine]", "14", ",", "13", ",", "12", ",", "11.5", ",", 
     "11", ",", "10.5", ",", "10", ",", "\[IndentingNewLine]", "9.5", ",", 
     "9.0", ",", "8.5", ",", "8", ",", "7.5"}], "\[IndentingNewLine]", 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47835857022501*^9, 3.478358649532322*^9}, {
  3.478358853952238*^9, 3.478358855805633*^9}, {3.478370614629692*^9, 
  3.4783706455854597`*^9}, {3.478370676433776*^9, 3.478370679402834*^9}},
 CellLabel->
  "In[148]:=",ExpressionUUID->"fab4ed2e-8b7b-4354-a878-ca8d74d41502"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"21.7", ",", "  ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "21.7", 
     ",", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"was", " ", "25.7"}], " ", "-", " ", 
       RowBox[{"typo", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", "23", ",",
      "\:3000", "24", ",", "\:3000", "25", ",", "\:3000", "26", ",", "\:3000",
      "26.9", ",", "\:3000", "\[IndentingNewLine]", "27.6", ",", "\:3000", 
     "28.2", ",", "\:3000", "28.7", ",", "\:3000", "28.6", ",", "\:3000", 
     "28.7", ",", "\:3000", "28.5", ",", "\:3000", "28.2", ",", "\:3000", 
     "\[IndentingNewLine]", "27.6", ",", "\:3000", "27.4", ",", "\:3000", 
     "26.5", ",", "\:3000", "25.9", ",", "\:3000", "25.4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478358656639378*^9, 3.478358736957609*^9}, {
   3.478358785279069*^9, 3.478358785557148*^9}, {3.47836952405042*^9, 
   3.478369528607705*^9}, {3.4783705484182587`*^9, 3.478370609603867*^9}, 
   3.478370656935858*^9, {3.478370688621035*^9, 3.47837070158915*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"efcfd2d9-3339-4b5f-a21c-c05beabe29d0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5", "-", 
         RowBox[{"m5", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"9dc654f5-12e7-4376-b988-c7b6004ee35f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "25", ",", "24.5", ",", "24", ",", "23.5", ",", "23", ",", "22.5", ",", 
     "22", ",", "21.5", ",", "21", ",", "20.5", ",", "\[IndentingNewLine]", 
     "20", ",", "19.5", ",", "19", ",", "18.5", ",", "18", ",", "17.5", ",", 
     "17", ",", "16.5", ",", "16", ",", "15.5", ",", "\[IndentingNewLine]", 
     "15", ",", "14.4", ",", "14", ",", "13.5", ",", "13", ",", "12.5", ",", 
     "12", ",", "11.5", ",", "11", ",", "10.5", ",", "\[IndentingNewLine]", 
     "10", ",", "9.5", ",", "9", ",", "8.5", ",", "8", ",", "7.5", ",", "7", 
     ",", "6.5", ",", "6", ",", "5.5", ",", "\[IndentingNewLine]", "5.25", 
     ",", "5", ",", "4.75", ",", "4.5", ",", "4.25", ",", "4"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.480082947570427*^9, 3.4800831719740562`*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"bfd1fe49-5c2f-42b5-a27b-fbf16023de9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f5b", " ", "=", " ", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
    "21.9", ",", "22.5", ",", "23.0", ",", "23.4", ",", "23.9", ",", "24.4", 
     ",", "24.9", ",", "25.4", ",", "25.8", ",", "26.2", ",", 
     "\[IndentingNewLine]", "26.5", ",", "26.9", ",", "27.3", ",", "27.5", 
     ",", "27.6", ",", "27.7", ",", "27.8", ",", "27.9", ",", 
     "\[IndentingNewLine]", "27.7", ",", "27.5", ",", "27.1", ",", "26.6", 
     ",", "26.1", ",", "25.4", ",", "24.7", ",", "23.8", ",", "22.8", ",", 
     "21.8", ",", "20.7", ",", "19.4", ",", "\[IndentingNewLine]", "18", ",", 
     "16.6", ",", "15.0", ",", "13.4", ",", "11.7", ",", "10.0", ",", "8.17", 
     ",", "6.34", ",", "4.45", ",", "2.53", ",", "\[IndentingNewLine]", 
     "1.61", ",", "0.658", ",", "0.290", ",", "0.124", ",", "0.222", ",", 
     "3.19"}], "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48008383483594*^9, 3.4800841583652897`*^9}},
 CellLabel->
  "In[152]:=",ExpressionUUID->"a2cbe80f-09bc-4b53-8bff-04c2ae7c47c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c5b", " ", "=", " ", 
   RowBox[{
    RowBox[{"zc", "+", 
     RowBox[{"newportcal", "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m5b", "-", 
         RowBox[{"m5b", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "1000"}]}]}], "/.", 
    "v5"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.478370938123036*^9, 3.478370942043363*^9}, {
   3.478961639423946*^9, 3.478961643935979*^9}, 3.4789735974419727`*^9, 
   3.479490549175753*^9, {3.480085294755208*^9, 3.480085305264647*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"bfb484d5-820f-4006-ab1e-d64c012102c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.480244170219839*^9, 3.480244174751951*^9}},
 CellLabel->
  "In[154]:=",ExpressionUUID->"05db1675-ae50-40f9-b872-a707329c2930"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQvbtKVFJ2Qot9Ggg8M3XIflu7iou3xZ4BBBrMHKQT
nln/6GyG8BnMHU5f8jv7lK0Zoj7N3KHGdXvc5eYmqH5zB50d8h8OMED5aRYO
d7Q6GtfVNkLlLRx65n4QmvOrASpv6WAjELmks7zB/uwZELB0uMHanP3uRb29
MRhYOVi8Du47+agO6h4rh5kXVDYuuVMLNc/K4efWr5frr9VA9PtYO0TOPvYt
6kI1VL21w66G6ZJmp6rsZ80EAWsHqbQMG8EjlRDzN1s7VHlbxr/ZWwG139rh
lgFX0/Ht5VDzrR2sxW4vWbSxDK5+9u/Vx2tXl8LN//2g5lXE0hKI+ZLWDld7
y92PZRVD7bNy2LNazoB/ZhFU3spBZuL7oFeTCuH+ryk7UHq0pwBqvoXDju1K
ho68+VD3mDtUNR0p+86QC+WbOVj5pu1Z+yULyjd1+CXOwZTyIgOq38Rh16OV
7lJ30qDmGzvUrPXuvXA+BRp/Rg42FW8vtR1OgrrPwOGPU7+E7fYEqLyeQ4V0
0p5nobFQ87UcfmxY6h5sGwk1T92hwu3lpf0qoVD1Kg4Md3TidHgC7a8vLrDl
CldwYHj84JLhc0/7mP5DXzViJB0Y+DJecm1zhJon6MBQdO//cU5je1sukA4W
Bwar0zpOG1XtDwNV9x/6ac/gkJZ+0ZrVvnSyBEsY31N7BhODT5vUxPaDjeu/
ZM9whNNnean2/gjLLSfK9u23Z9he2//rten+i0q3f9ZlnbFn6PlWoShrt7/1
deAOuVZOBwCkWD22
      "]]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0004595000000000016, 0.010040499999999999`}, {0, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480244175910057*^9, 3.480244564266391*^9, 
  3.480245921792756*^9, 3.4806923262774763`*^9, 3.481941626785322*^9, 
  3.48194209932056*^9, 3.662626054674625*^9, 3.799212568412122*^9, 
  3.7992128144993067`*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"be2778ef-42a6-44cd-a5b1-d414c8090f9a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5", ",", "f5"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "6"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}},
 CellLabel->
  "In[155]:=",ExpressionUUID->"7a1d2727-4002-416b-a42f-e21aef650e48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g5b", " ", "=", " ", 
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"c5b", ",", "f5b"}], "}"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"23", ",", 
       RowBox[{"-", "10"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.479492900596332*^9, 3.479493003075787*^9}, {
   3.479493311477222*^9, 3.479493315988943*^9}, {3.4794935683920727`*^9, 
   3.4794935803839912`*^9}, {3.479493647064962*^9, 3.4794936781853*^9}, {
   3.479494587120398*^9, 3.479494587799402*^9}, 3.479495122108719*^9, 
   3.479664850461237*^9, {3.479666071209745*^9, 3.479666118376079*^9}, {
   3.4800842394941673`*^9, 3.480084256187529*^9}, {3.480085381741091*^9, 
   3.4800854050584*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"f483904d-facb-4226-90a0-92506a67fe1f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "g5b", "]"}]], "Input",
 CellChangeTimes->{{3.479492922070776*^9, 3.479492925832822*^9}, 
   3.480084241379088*^9},
 CellLabel->
  "In[157]:=",ExpressionUUID->"d7ded7f2-fd4e-48bc-afff-313ea28ab95e"],

Cell[BoxData[
 GraphicsBox[{{}, {
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
      0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
      0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
      0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
      0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
      0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
      0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
      0.007790499999999999, 26.2}}]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.004217583333333554, 25.261111111111113`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.004217583333333554, 0.007790499999999999}, {
   25.261111111111113`, 27.9}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.47949292648037*^9, {3.4794929901025677`*^9, 3.479493006913755*^9}, 
   3.479493322040373*^9, {3.479493571055421*^9, 3.479493582720769*^9}, {
   3.479493654111162*^9, 3.479493680849517*^9}, 3.479494594442368*^9, 
   3.4794951275012083`*^9, 3.479664646222107*^9, 3.479665767557681*^9, 
   3.4796658002277327`*^9, {3.479666082950231*^9, 3.479666122957705*^9}, 
   3.480085257681452*^9, 3.48008532219565*^9, {3.480085387449814*^9, 
   3.480085408824621*^9}, 3.4802445643515987`*^9, 3.480245921875152*^9, 
   3.4806923263613043`*^9, 3.481941626886848*^9, 3.481942099405159*^9, 
   3.662626054790688*^9, 3.799212568454192*^9, 3.7992128145398893`*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"a0a00e2e-643e-46ca-b4c1-5d406fcd8080"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", "z_"}], "]"}], " ", "=", " ", 
  RowBox[{"Fit", "[", 
   RowBox[{"g5b", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "z", ",", 
      RowBox[{"z", "^", "2"}]}], "}"}], ",", "z"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479492821084407*^9, 3.479492906857025*^9}, {
   3.479493026130746*^9, 3.479493088769916*^9}, 3.47966554034807*^9, 
   3.480085337997651*^9},
 CellLabel->
  "In[158]:=",ExpressionUUID->"3b0690d8-576a-4f50-805c-848c9bf88016"],

Cell[BoxData[
 RowBox[{"2.6127607538421684`", "\[VeryThinSpace]", "+", 
  RowBox[{"8218.061371644611`", " ", "z"}], "-", 
  RowBox[{"669099.8444305059`", " ", 
   SuperscriptBox["z", "2"]}]}]], "Output",
 CellChangeTimes->{{3.479493065534417*^9, 3.479493090921401*^9}, 
   3.479493347575324*^9, 3.479493687032943*^9, 3.4794945945082073`*^9, 
   3.479495127601207*^9, 3.4796646462647676`*^9, 3.4796655437102633`*^9, 
   3.479665767592616*^9, 3.479665800264008*^9, {3.4796660829847727`*^9, 
   3.479666123040353*^9}, 3.480085339448057*^9, 3.480085414970368*^9, 
   3.4802445643682337`*^9, 3.4802459219083157`*^9, 3.48069232640238*^9, 
   3.481941626925313*^9, 3.481942099421473*^9, 3.662626054845523*^9, 
   3.7992125684643803`*^9, 3.7992128145497*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"b4e9aad2-1add-430e-bd8c-3bce75f14ced"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "g5b", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"q", "[", 
      RowBox[{"BO5", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.479493098474358*^9, 3.4794931473471107`*^9}, {
   3.4794950541082687`*^9, 3.479495059418387*^9}, 3.479495140140613*^9, {
   3.479498020636153*^9, 3.4794980214908237`*^9}, 3.4796655403666763`*^9, 
   3.480085344678802*^9},
 CellLabel->
  "In[159]:=",ExpressionUUID->"48eeed37-8a15-4b27-b484-77994f6f7a0d"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{{0.004290499999999999, 25.4}, {0.004540499999999999, 26.1}, {
       0.004740499999999999, 26.6}, {0.005040499999999999, 27.1}, {
       0.005290499999999999, 27.5}, {0.005540499999999999, 27.7}, {
       0.005790499999999999, 27.9}, {0.006040499999999999, 27.8}, {
       0.006290499999999999, 27.7}, {0.0065404999999999994`, 27.6}, {
       0.006790499999999999, 27.5}, {0.007040499999999999, 27.3}, {
       0.007290499999999999, 26.9}, {0.007540499999999999, 26.5}, {
       0.007790499999999999, 26.2}}]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13lcTO0XAPAW0SZb/bQo8VaWt5IizVycp+VNeLVJkhayVdJCNfdOpUmk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        "]]},
      Annotation[#, "Charting`Private`Tag$299891#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.004217583333333554, 25.261111111111113`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.479493147789712*^9, 3.479493348745586*^9, 3.479493687869093*^9, 
   3.479494594544231*^9, 3.4794950600870647`*^9, {3.479495127635968*^9, 
   3.4794951412551003`*^9}, 3.479498022175354*^9, 3.479664646293791*^9, 
   3.479665767627028*^9, 3.479665800298114*^9, {3.4796660830395527`*^9, 
   3.4796661230758743`*^9}, 3.4800853458498983`*^9, 3.480085417240912*^9, 
   3.480244564408826*^9, 3.48024592195185*^9, 3.4806923264358673`*^9, 
   3.481941626979694*^9, 3.481942099477305*^9, 3.662626054895088*^9, 
   3.799212568521755*^9, 3.79921281460789*^9},
 CellLabel->
  "Out[159]=",ExpressionUUID->"79ced1b0-2e2f-447d-9f1a-82a88b8845ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"q", "[", 
        RowBox[{"BO5", ",", "z"}], "]"}], ",", "z"}], "]"}]}], "/", 
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}], ",", 
      RowBox[{"z", "^", "2"}]}], "]"}]}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.479495438249634*^9, 3.479495505318678*^9}, 
   3.479662502748355*^9, 3.4796629041886263`*^9, 3.479664469475191*^9, {
   3.479665540402864*^9, 3.479665540432529*^9}, 3.479665679958331*^9},
 CellLabel->
  "In[160]:=",ExpressionUUID->"5e378bec-8eea-41d9-b2cc-c81546e65412"],

Cell[BoxData["0.00614113232879264`"], "Output",
 CellChangeTimes->{{3.479495497456901*^9, 3.479495505729022*^9}, 
   3.479664646330089*^9, 3.479665767660248*^9, 3.4796658003302927`*^9, 
   3.479666123140691*^9, 3.480085429491647*^9, 3.480244564434903*^9, 
   3.480245921975265*^9, 3.480692326468603*^9, 3.481941627025852*^9, 
   3.481942099487645*^9, 3.6626260549302607`*^9, 3.799212568531901*^9, 
   3.799212814617373*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"d03b2dfe-ec5c-4d0c-bb69-24a32a27c1bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmaxq", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{"q", "[", 
   RowBox[{"BO5", ",", 
    RowBox[{"zmaxq", "[", "BO5", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4796645166114473`*^9, 3.4796645680107403`*^9}, {
   3.479664629540166*^9, 3.4796646354272118`*^9}, 3.479665680445608*^9, 
   3.479665788251362*^9},
 CellLabel->
  "In[161]:=",ExpressionUUID->"4d1ac0e4-ef35-46bc-bc7e-5fb5ef8e3016"],

Cell[BoxData["27.846861938546525`"], "Output",
 CellChangeTimes->{3.479664568867193*^9, 3.479664646359799*^9, 
  3.479665585669737*^9, 3.479665767693388*^9, 3.479665800365254*^9, 
  3.479666123176936*^9, 3.48008543183556*^9, 3.480244564491827*^9, 
  3.480245922030847*^9, 3.480692326501891*^9, 3.481941627098565*^9, 
  3.4819420995401154`*^9, 3.6626260549826117`*^9, 3.799212568567286*^9, 
  3.7992128146511183`*^9},
 CellLabel->
  "Out[161]=",ExpressionUUID->"6c400a1f-43d7-48f2-8b10-d777c09737ce"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"delta", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"zmaxq", "[", "BO5", "]"}], " ", "-", " ", 
   RowBox[{"zmax", "[", "BO5", "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.479495523610161*^9, 3.479495542381401*^9}, 
   3.479661946209796*^9, 3.479662081271207*^9, 3.47966250284426*^9, 
   3.47966290430508*^9, 3.479664469476417*^9, {3.479665683454405*^9, 
   3.479665683520638*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"3aa2d35d-0c01-4b12-8fd5-db47c23e14a8"],

Cell[BoxData[
 RowBox[{"-", "0.000039824902408174163`"}]], "Output",
 CellChangeTimes->{3.4794955436804543`*^9, 3.479665380340073*^9, 
  3.479665767759824*^9, 3.479665800431348*^9, 3.4796661232447157`*^9, 
  3.4800854342417307`*^9, 3.4802445645293713`*^9, 3.480245953636918*^9, 
  3.48069232653566*^9, 3.481941627141439*^9, 3.4819420995770683`*^9, 
  3.662626055031432*^9, 3.799212568575273*^9, 3.7992128146588984`*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"cea1019c-bdc8-4242-9606-c66daf7bf390"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Scale factor to make measured and theoretical curves have same maximum\
\>", "Text",
 CellChangeTimes->{{3.478970887912784*^9, 
  3.478970908928837*^9}},ExpressionUUID->"c5a22707-c3e3-4ef3-83ee-\
4d3cf36dcb3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"scale", "[", "BO5", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"fmax", "[", "BO5", "]"}], "/", 
   RowBox[{"fmaxq", "[", "BO5", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970696648231*^9, 3.478970705072441*^9}, {
   3.478970839616865*^9, 3.478970857497159*^9}, 3.4789715324564857`*^9, {
   3.478971784562731*^9, 3.4789717872495337`*^9}, 3.478971846731222*^9, {
   3.4789723755682993`*^9, 3.478972380734989*^9}, {3.4789735142646723`*^9, 
   3.4789735163909893`*^9}, 3.479661959846012*^9, 3.479662130234865*^9, {
   3.479665563524087*^9, 3.479665591276129*^9}, {3.479665788451865*^9, 
   3.479665788518486*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"94effaa2-9976-41e0-982f-16b2ea4c52ce"],

Cell[BoxData["0.03457607889444225`"], "Output",
 CellChangeTimes->{
  3.478971485608411*^9, 3.478971533659111*^9, 3.478971787849442*^9, {
   3.478971841091794*^9, 3.4789718473084917`*^9}, 3.478972382639682*^9, 
   3.4789745781001587`*^9, 3.478974629064003*^9, 3.4794913230668173`*^9, 
   3.4796653804411373`*^9, 3.479665592037429*^9, 3.4796657678267307`*^9, 
   3.47966580051572*^9, 3.479666123310278*^9, 3.480085442306896*^9, 
   3.480085474403487*^9, 3.480244564572826*^9, 3.480245967181128*^9, 
   3.480692326580511*^9, 3.4819416271735687`*^9, 3.481942099628888*^9, 
   3.662626055082137*^9, 3.7992125686094933`*^9, 3.7992128146946173`*^9},
 CellLabel->
  "Out[163]=",ExpressionUUID->"316e3fca-4a3d-4ef6-9f2c-f1f790dcab7b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BO5", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"c5b", ",", 
        RowBox[{
         RowBox[{"scale", "[", "BO5", "]"}], "*", "f5b"}]}], "}"}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Blue", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"scale", "[", "BO5", "]"}], "*", 
      RowBox[{"q", "[", 
       RowBox[{"BO5", ",", "z"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.00375", ",", "0.008"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", "Red", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"751718a7-0c82-478d-9e79-edcec149d036"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0], LineBox[CompressedData["
1:eJwV1ns4VNv/B/C+IaIkRAqhUqdUkopc3m5FJ5wUKoqiIiG3MbNnSK5pQhSi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      "]]}}, {{}, {
     {RGBColor[0, 0, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
      1.6], PointBox[CompressedData["
1:eJw9kXss1AEAx38YRV30JI/CpBW1I5UcvmGoddWQchWZzmOkcuVc5y7H6XHr
UFrpJkXISi+1XNO1uxAVlk5edbUbcQ93R1beTbU1f3z3/eez7/bZ1ynuRHi8
MUEQG//mX79kL1/pcDkXRQfswhwoaqToufctSLng02utrQbUsIsdpEwI+BgV
bX31mKFBi3xP24AZH9/HbwXM9GvACRbHdPBzELHBUVWcpoX7i9UjMiIH9XFl
QsqsFor1F7MfcbPhccPZ84twCMKSkSU3p3gobSvvZtvq4GtFqxBk8HDVbcHh
5ks69JjyUwzqLJwTMJRLf+vgPRSR/67vLKYtZUGkcD1E7S41FQou9Klr39Ia
9Jh8/qsjq4sDZUs+9a6XAbTiprGD7ZnoZdfnU1MNqOMVrdzyno394YrHtwUG
2CYk+S5uPAP5urH20UoD2Lu2HdG9YmGvkdVocL0Bn8kWOc3iDLT0rFsq+mYA
ZcWXijs1zDm+eLq6mVudPrc/reRooypPQ2V/yIKY0aMzLyO0KfkUWKpeeuxx
PSTVq8iWIgbMn0ZJZUod7K8Mh2sL0+b8OUxZ+hvhSXhrDMNe+4bwQuzsEUA6
ge5Is6YdkVqwcxqZ40QqJrUmmeY+GvjsTpA8/JkMO54R+f0qNaas5xvT1UmQ
+Q00bFUNoq7vXqitIgHHqNeWzzIHwHm4K6/9Ax03+W4hp7T98GXp5ecb4tBa
95qpiu7DTGCBjZ84FsZBLvHPbyjBsouTDEZGI+06qcqs6ismnlSGRvjR/v/d
C1aIRi51iUQUjaz44dgFQuEe474wDE4uNhcCl8lB9CvlHqqd6Pw6e9TVshXE
oiSNRW0Ayj+Nm7TVNIBgfJttNt8E+4l5hTp6LQifFvfAmjV4S0lUM3gPQGxP
SPxIMYVjqM07ErUIhBd59KnrCqmk1Fm0WJALotGcWpXuJh1eZuv/rCANhJhb
MDW0WUor0w3KTmaBEI6xnBz8pSYlBZ4sXwn+ABmtbRg=
       "]]}, {
      {RGBColor[0, 0, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}, {
      {RGBColor[0, 0, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwV13k8VG0bB3BLKjvhoexbKEnlIUqXpVeorBFCiEKyxpwztkFJeVplKUUJ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        "]]},
      Annotation[#, "Charting`Private`Tag$299972#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{641., Automatic},
  PlotRange->{{0, 0.013}, {0., 0.9628352949866621}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480692326631896*^9, 3.481941627229917*^9, 3.481942099677737*^9, 
   3.662626055125484*^9, 3.799212568670271*^9, 3.799212814754312*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"c2187c37-901b-4059-ab23-23417881c731"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New coil calc for BOSEM (10x\[OSlash]5 magnet as for tiptilt)", \
"Section",
 CellChangeTimes->{{3.453751016056313*^9, 3.453751037487228*^9}, 
   3.463844192181329*^9, {3.478894850822432*^9, 3.478894851717502*^9}, {
   3.4788951705281897`*^9, 3.4788951754720497`*^9}, {3.4819407269664*^9, 
   3.481940736973164*^9}},ExpressionUUID->"4efd5b93-148c-456b-9645-\
92b2cb33f148"],

Cell["\<\
bosemvalsTT = Recurse[
\tLOSvals~Join~{
\t\tkB->1.38 10^-23,
\t\tT->295,
\t\tg->9.8,
\t\tmu0->4 N[Pi] 10^-7,
\t\trhoeAl->2.65 10^-8,\t\t\t(* Resistivity of Al *)
\t\trhoepianowire->30 rhoeAl,\t(* Resistivity of P.W., GUESSTIMATE *)
\t\tsigmaeAu->2.67,\t\t\t\t(* Resistivity of Au paint, measured *)
\t\tdipoleM->Bresid/mu0,\t\t(* Magnetization *)
\t\tmassSOS->0.25,\t\t\t\t(* Final design value *)
\t\tmassM->rhomM l N[Pi] a^2,
\t\tBresid->1.25,\t\t\t\t(* Residual field *)
\t\tPi->N[Pi],
\t\trhomM->7400,\t\t\t\t(* Mass density of magnets *)
\t\tztube->0.0155,\t\t\t\t(* Separation for magnet to push its own weight, \
measured *)
\t\tzpickup->0.018-l,\t\t\t(* Separation for magnet to pull its own weight, \
measured *)
\t\tmasspullapart->0.060,\t\t(* Force (in kgf) to separate magnets *)
\t\t(* preferred value of small magnet dipole moment *)
\t\tmzpref->0.007945632135874319,
\t\t(* magnet moment per unit volume for magnet stuff, assumed the same for \
big and small *)
\t\tmz->mzpref/(lold*N[Pi]*aold^2),
\t\tlold->0.003175,\t\t\t\t(* length of small magnets *)
\t\taold->0.0009525,\t\t\t(* radius of small magnets *)
\t\tl->0.010,\t\t\t\t(* length of big magnets *)
\t\ta->0.005/2,\t\t\t\t(* radius of big magnets *)
\t\t(* coil length *)
\t\tcoillen->0.315*0.0254,  (* SA email, 08/14/06 *)
\t\t(* the ends of the coil relative to the centre of the coil *)
\t\tcoilz1->-coillen/2,
\t\tcoilz2->+coillen/2,
\t\t(* the inner and outer radii of the coil *)
\t\tcoilrad1->0.35*0.0254, (* unchanged *)
\t\tcoilrad2->0.65*0.0254, (* SA email, 08/14/06 *)
\t\t(* the number of turns *)
\t\tcoilturns->800, (* SA email, 08/14/06 *)
\t\tcoilsigma -> coilturns/((coilrad2 - coilrad1)*(coilz2 - coilz1))
\t}
];\
\>", "Input",
 CellChangeTimes->{{3.453837228357688*^9, 3.453837230833909*^9}, {
  3.463844183252262*^9, 3.463844223147016*^9}, {3.478894862544446*^9, 
  3.4788948852377567`*^9}, {3.478894985619047*^9, 3.4788949913587503`*^9}, {
  3.4788950240972023`*^9, 3.478895025494358*^9}, {3.481940748223406*^9, 
  3.481940763510077*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"454dd928-09a4-486a-aecd-7774f1d75e6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vals", "[", "BOTT", "]"}], " ", ":=", " ", "bosemvalsTT"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.453752708796636*^9, 3.453752725376184*^9}, 
   3.463844187524227*^9, 3.463845359588154*^9, {3.47889491108751*^9, 
   3.47889491212925*^9}, {3.4788949966551943`*^9, 3.478894997123682*^9}, 
   3.4788950699694643`*^9, {3.4819407740626507`*^9, 3.481940800888165*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"e6910de8-019b-40a7-add6-27cfea9f6e47"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3925374169455943`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.00759707468312686`"}], "}"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"fz", "[", 
          RowBox[{"BOTT", ",", "z"}], "]"}]}], ",", " ", 
        RowBox[{"0.006", " ", "<", " ", "z", " ", "<", " ", "0.010"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, 
   3.4796619224973173`*^9, {3.480244382554545*^9, 3.480244405961742*^9}, {
   3.4819408015577917`*^9, 3.4819408027090397`*^9}, {3.481940979763582*^9, 
   3.481940981746011*^9}, {3.481941548420309*^9, 3.481941559738948*^9}, 
   3.662607121040988*^9},
 CellLabel->
  "In[167]:=",ExpressionUUID->"0c306e42-9206-451e-b276-7f25d1a13d5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.3925374169455943`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.00759707468312686`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.662607374243556*^9, 3.6626261664898033`*^9, 
  3.799212568698752*^9, 3.799212814782001*^9},
 CellLabel->
  "Out[167]=",ExpressionUUID->"3deec005-1079-4b48-bc38-7539da438e1b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
     PlotRangeClipping->True,
     PlotRangePadding->{
       Scaled[0.02], 
       Scaled[0.02]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "p"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "0", ",", "0.013"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.4789618100364523`*^9, 3.478961850760915*^9}, 
   3.478969868098156*^9, 3.4789702271107073`*^9, {3.478971402742322*^9, 
   3.478971407269801*^9}, {3.478973436528585*^9, 3.4789734559838*^9}, {
   3.4794970273251*^9, 3.4794970280748262`*^9}, {3.479497850691868*^9, 
   3.479497851721608*^9}, {3.4802445496159487`*^9, 3.4802445841180058`*^9}, {
   3.4802446656757193`*^9, 3.4802446687524443`*^9}, {3.481940803363203*^9, 
   3.481940804034131*^9}, {3.481941063760079*^9, 3.4819410664063997`*^9}, {
   3.481941556057631*^9, 3.4819415664906*^9}, 3.6626071369677134`*^9},
 CellLabel->
  "In[168]:=",ExpressionUUID->"00e8cb3d-befa-4bba-b9d8-2d8e7eaf6b21"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.662607247679082*^9, 3.662626182329171*^9, 
  3.799212568737772*^9, 3.799212814817355*^9},
 CellLabel->
  "Out[168]=",ExpressionUUID->"21a258b2-597d-4ca2-affd-560a12db1df7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.4796619220112333`*^9, 3.4796619454416037`*^9}, 3.479665671740583*^9, {
   3.48194080448247*^9, 3.481940804971867*^9}},
 CellLabel->
  "In[169]:=",ExpressionUUID->"657a4614-756e-46da-90b8-1da0ad443cd5"],

Cell[BoxData["0.00759707468312686`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.479486914888383*^9, 
  3.479659289850292*^9, 3.4796634565750093`*^9, 3.479665742764594*^9, 
  3.479665816570661*^9, 3.480243747684814*^9, 3.480692317253339*^9, 
  3.481566060871256*^9, 3.481940897154257*^9, 3.481940954139496*^9, 
  3.4819414009024477`*^9, 3.481941627387727*^9, 3.481942099804831*^9, 
  3.6626070429154387`*^9, 3.66260724788386*^9, 3.6626261823851137`*^9, 
  3.799212568747365*^9, 3.799212814826435*^9},
 CellLabel->
  "Out[169]=",ExpressionUUID->"3adcc00d-29d6-42c0-bded-98afaa646ee7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax", "[", "BOTT", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata", "[", "BOTT", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, 
   3.479661922078005*^9, 3.4796619593447857`*^9, 3.479665787682528*^9, {
   3.481940805601218*^9, 3.481940806091435*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"4f5e3a6e-21e1-49d9-aa63-433c66fd4a38"],

Cell[BoxData["0.3925374169455943`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.479486914934926*^9, 
  3.479659289887826*^9, 3.479663456628942*^9, 3.479665742793458*^9, 
  3.4796658166882772`*^9, 3.480243747711088*^9, 3.480692317295466*^9, 
  3.481566060924111*^9, 3.48194089720923*^9, 3.48194095418651*^9, 
  3.481941400927742*^9, 3.4819416274500303`*^9, 3.48194209986127*^9, 
  3.6626070429656773`*^9, 3.662607247938093*^9, 3.662626182432036*^9, 
  3.799212568783473*^9, 3.79921281486211*^9},
 CellLabel->
  "Out[170]=",ExpressionUUID->"c77627dc-b825-4408-8fcb-5af3c0bb9976"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BOTT", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}},
 CellLabel->
  "In[171]:=",ExpressionUUID->"2d21b415-427f-49d4-9f11-30820cfce8dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkn80FAYAx2/C3prkdIWb5vKrRmKOS5y+3vycOz/ysz2ttXNGMQ67/AiH
OHdOqy1dd9hqWhsWTZOjqYyOGUt37idTpozya5aXt5ertT8+7/M+/392sLJi
UowIBAL9Ff97taHbrjhsyZ9AoDyKlMTtn2xm9KwOuCJKLY6t+PNLdFxKNTL5
h47vQ+5aJVy+BIu8f0PPlAYjl3SRw7RrBXOe7qdgMyEwX5sqcv0JBbsOpkQs
H8DLLwKJ+du74O3LTk3IiAfPapnZ1NKD74IEMgevDxDza9tN775e1NHmvwp/
cgixhWXTWVb96AmMfhDucQQftqYzrX3k4M91ipUWLNRvqiRfyRuEvCckPUOR
jCBpa2VD2RDkxs82UoUpkO6dv9+VPQzK++2KpE9S4fU8weVowe9Y7jl3Xexw
FLpeF9E4YxQ2bvxeqmk6rJ8E0Bwk92BMFIsNDzIQS/JJ7C5UgO04KtRLM/HY
6c7D5kAlLMgblSI6ByRBf8AicQxN+35ZpNpm43KiSwx1cAyZiS9sT5nnYKlm
ocaGpwLJfbi9aD0H7xpdXex3VoP79e547nguzp4VLvJlamwwI5nZDX+GmU0v
z7eEasAknlEofuDC0WDq59KnAfde/TpZcByeVZK7S3u0GDnl5rc1Lw8cdthK
uESLyelYgXVCPro03x5WL2nxFo3weCS0AAcaoy0XoINvIP2qlXchuPXLI3+U
67Blzqwi3fIEzkez1zw6dSCLkjM4RkU4UbrZmzCtw4Q8MrlkugjsSfHmNwl6
FN8Yum1/qxh8k8iZ+i16MFt/c8+/UgKsuTIob+uh2XukTVPNQ8HCImX/qw6Z
8qc89S9FQn4UxZekB+/vcxxeWylSXBp2y1/To2ny+lONbRlYiGeKZnWYG5IQ
qmrLUHZfTC7u08HEaKDWz7gckI0dC5bo4LOv81pYcTkIpQ/JP7N0OBSRuWHH
ajmSj+t3qpx1r77gTBhYJxFQt81qak4LrhnNnzpxEmltuXzpBS2OyYKdP2VU
YHyrc/9qvBZR2P5eTncF6LouYvgbWjAGZLOjHpWg/3gwTdKugaO0geR5sRJZ
A41/GZI0IKUHDS9Y81H3MS+p5rkaqzYdHTmn+TClix61SdVoJ2U6GQx8eNIr
Rlb81Kg0n7eb4lahhZZ221SlAi3u2jeDM1Vg3emPY2ar8EJCb339IwGElMZ3
ho1V6Lzx+bylRoC0ZneZk3QMjF2u7fbBQhA07SXr1DGs1VYTRDeFsN82W6eS
K1Ea4aVdc6uG/849ROVhJVZqaVm3LlSj7nRtUuczBf4DTN7DAQ==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$303855#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.39247086730728814`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVkn80FAYAx2/C3prkdIWb5vKrRmKOS5y+3vycOz/ysz2ttXNGMQ67/AiH
OHdOqy1dd9hqWhsWTZOjqYyOGUt37idTpozya5aXt5ertT8+7/M+/392sLJi
UowIBAL9Ff97taHbrjhsyZ9AoDyKlMTtn2xm9KwOuCJKLY6t+PNLdFxKNTL5
h47vQ+5aJVy+BIu8f0PPlAYjl3SRw7RrBXOe7qdgMyEwX5sqcv0JBbsOpkQs
H8DLLwKJ+du74O3LTk3IiAfPapnZ1NKD74IEMgevDxDza9tN775e1NHmvwp/
cgixhWXTWVb96AmMfhDucQQftqYzrX3k4M91ipUWLNRvqiRfyRuEvCckPUOR
jCBpa2VD2RDkxs82UoUpkO6dv9+VPQzK++2KpE9S4fU8weVowe9Y7jl3Xexw
FLpeF9E4YxQ2bvxeqmk6rJ8E0Bwk92BMFIsNDzIQS/JJ7C5UgO04KtRLM/HY
6c7D5kAlLMgblSI6ByRBf8AicQxN+35ZpNpm43KiSwx1cAyZiS9sT5nnYKlm
ocaGpwLJfbi9aD0H7xpdXex3VoP79e547nguzp4VLvJlamwwI5nZDX+GmU0v
z7eEasAknlEofuDC0WDq59KnAfde/TpZcByeVZK7S3u0GDnl5rc1Lw8cdthK
uESLyelYgXVCPro03x5WL2nxFo3weCS0AAcaoy0XoINvIP2qlXchuPXLI3+U
67Blzqwi3fIEzkez1zw6dSCLkjM4RkU4UbrZmzCtw4Q8MrlkugjsSfHmNwl6
FN8Yum1/qxh8k8iZ+i16MFt/c8+/UgKsuTIob+uh2XukTVPNQ8HCImX/qw6Z
8qc89S9FQn4UxZekB+/vcxxeWylSXBp2y1/To2ny+lONbRlYiGeKZnWYG5IQ
qmrLUHZfTC7u08HEaKDWz7gckI0dC5bo4LOv81pYcTkIpQ/JP7N0OBSRuWHH
ajmSj+t3qpx1r77gTBhYJxFQt81qak4LrhnNnzpxEmltuXzpBS2OyYKdP2VU
YHyrc/9qvBZR2P5eTncF6LouYvgbWjAGZLOjHpWg/3gwTdKugaO0geR5sRJZ
A41/GZI0IKUHDS9Y81H3MS+p5rkaqzYdHTmn+TClix61SdVoJ2U6GQx8eNIr
Rlb81Kg0n7eb4lahhZZ221SlAi3u2jeDM1Vg3emPY2ar8EJCb339IwGElMZ3
ho1V6Lzx+bylRoC0ZneZk3QMjF2u7fbBQhA07SXr1DGs1VYTRDeFsN82W6eS
K1Ea4aVdc6uG/849ROVhJVZqaVm3LlSj7nRtUuczBf4DTN7DAQ==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$303855#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.39247086730728814`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {37}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0018958333333333334`, 0.0021666666666666666`, 0.0024375, 
   0.0027083333333333334`, 0.002979166666666667, 0.00325, 
   0.0035208333333333333`, 0.0037916666666666667`, 0.0040625, 
   0.004333333333333333, 0.004604166666666666, 0.004875, 0.005145833333333334,
    0.005416666666666667, 0.0056875, 0.005958333333333334, 
   0.006229166666666668, 0.0065, 0.006770833333333333, 0.0070416666666666666`,
    0.0073124999999999996`, 0.0075833333333333326`, 0.007854166666666666, 
   0.008125, 0.008666666666666666, 0.009208333333333332, 0.00975, 
   0.010291666666666666`, 0.010833333333333334`, 0.011375, 
   0.011916666666666666`, 0.012458333333333332`, 0.013}}, {{0.}, {
   0.04701349415994795}, {0.09324745034375366}, {0.13794860130965853`}, {
   0.15950224077108074`}, {0.18041439040537233`}, {0.20060861124814158`}, {
   0.22001402724221536`}, {0.23856573100456643`}, {0.2562051115590299}, {
   0.27288010703066534`}, {0.2885453862015324}, {0.30316246530475005`}, {
   0.31669976525054455`}, {0.329132614416478}, {0.3404432064031839}, {
   0.35062051330437666`}, {0.3596601625743149}, {0.36756427818720233`}, {
   0.37434128788325244`}, {0.3800056973142644}, {0.3845778331779538}, {
   0.38808354353001595`}, {0.3905538713603741}, {0.39202467815701764`}, {
   0.3925362408391984}, {0.39213279797323064`}, {0.39086206452845423`}, {
   0.3859238098780676}, {0.37815229188543864`}, {0.36799841335653066`}, {
   0.3559149822897691}, {0.34233995455814425`}, {0.3276824195679935}, {
   0.3123123552834056}, {0.29655398908142594`}, {0.28068311946827973`}}, {
   Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662626186307064*^9, 3.799212568859078*^9, 3.799212818360805*^9},
 CellLabel->
  "Out[171]=",ExpressionUUID->"0c743654-6f80-48aa-bd07-31ae263cbba9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"fzi", "[", "BOTT", "]"}], "[", "z", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BOTT", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, 
   3.7992125311458797`*^9},
 CellLabel->
  "In[172]:=",ExpressionUUID->"6a1ad74d-aa0f-455c-b75d-91c2cdcb9618"],

Cell[BoxData["12441.390320159337`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662626186396759*^9, 
   3.799212568872841*^9, 3.7992128184110413`*^9},
 CellLabel->
  "Out[172]=",ExpressionUUID->"a0af7a63-8b04-405d-bf07-8fb71d61c68b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95plus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.001"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "+", "0.005"}]}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658987032153*^9, 3.47965898990287*^9}, {3.479659310386307*^9, 
   3.4796593125701933`*^9}, {3.479661624172262*^9, 3.479661679901505*^9}, {
   3.479661945541445*^9, 3.4796619594445953`*^9}, {3.4796656734658623`*^9, 
   3.479665674680963*^9}, 3.47966578778349*^9, {3.481940808072547*^9, 
   3.4819408112927933`*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"d98c8203-05d9-46c7-9f72-a2b2a847834d"],

Cell[BoxData["0.009502179799014018`"], "Output",
 CellChangeTimes->{{3.479659290207419*^9, 3.4796593177022877`*^9}, {
   3.479661644377719*^9, 3.4796616514833097`*^9}, 3.479661686065053*^9, 
   3.4796634593803263`*^9, 3.479665745824663*^9, 3.4796658197389708`*^9, 
   3.480243751933235*^9, 3.480692320796873*^9, 3.4815660640155077`*^9, 
   3.4819408973674994`*^9, 3.481940954361327*^9, 3.481941402301373*^9, 
   3.481941628781619*^9, 3.481942101498692*^9, 3.662607043922553*^9, 
   3.662607248914266*^9, 3.662626187196279*^9, 3.799212568930994*^9, 
   3.799212819110424*^9},
 CellLabel->
  "Out[173]=",ExpressionUUID->"c4a982dc-854e-4b4c-848b-09d6c68dd9bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f95minus", "[", "BOTT", "]"}], " ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fz", "[", 
       RowBox[{"BOTT", ",", "z"}], "]"}], "-", 
      RowBox[{"0.95", "*", 
       RowBox[{"fmax", "[", "BOTT", "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.001"}], ",", 
       RowBox[{
        RowBox[{"zmax", "[", "BOTT", "]"}], "-", "0.005"}], ",", 
       RowBox[{"zmax", "[", "BOTT", "]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479658613425561*^9, 3.4796587501410933`*^9}, {
   3.479658790462825*^9, 3.4796587993088913`*^9}, {3.479658852062684*^9, 
   3.479658891629363*^9}, {3.4796589431729183`*^9, 3.479658948798299*^9}, {
   3.479658997678957*^9, 3.4796590027188377`*^9}, {3.479659318794853*^9, 
   3.479659344898431*^9}, {3.479661657421668*^9, 3.4796616780054293`*^9}, {
   3.479661945775414*^9, 3.479661959545474*^9}, {3.479665675209929*^9, 
   3.479665676278386*^9}, 3.4796657878831253`*^9, {3.481940812147341*^9, 
   3.481940829419257*^9}},
 CellLabel->
  "In[174]:=",ExpressionUUID->"c42e2814-1f08-4f70-81a8-0ff89bc9e521"],

Cell[BoxData["0.005897248057591012`"], "Output",
 CellChangeTimes->{
  3.479659290545846*^9, {3.479659322545879*^9, 3.479659348979048*^9}, {
   3.4796616661527233`*^9, 3.479661689555737*^9}, 3.479663462870864*^9, 
   3.479665749329587*^9, 3.479665823257647*^9, 3.480243756605932*^9, 
   3.480692324819867*^9, 3.481566067504561*^9, 3.4819408974084797`*^9, 
   3.481940954404307*^9, 3.481941404076367*^9, 3.481941630539411*^9, 
   3.481942103389555*^9, 3.66260704523952*^9, 3.6626072502629004`*^9, 
   3.66262618829943*^9, 3.799212568959055*^9, 3.79921282007318*^9},
 CellLabel->
  "Out[174]=",ExpressionUUID->"69c91a00-74d9-4148-83ea-eb33cf1b7abb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"plot", "[", "BOTT", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<z (m)\>\"", ",", "\"\<F (N/A)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453823397414776*^9, 3.453823397824687*^9}, {
   3.453838538440839*^9, 3.453838572806719*^9}, 3.463844247723119*^9, 
   3.478894943196905*^9, 3.4788950132010527`*^9, {3.478961709433363*^9, 
   3.47896175216029*^9}, {3.478961842569364*^9, 3.478961894377494*^9}, {
   3.4789619830038633`*^9, 3.478961984506156*^9}, {3.4789699280628653`*^9, 
   3.478969982243393*^9}, {3.478970021389124*^9, 3.478970165180615*^9}, {
   3.478970224319232*^9, 3.478970261501657*^9}, {3.4789703108875017`*^9, 
   3.478970348344078*^9}, 3.478970398020482*^9, {3.478970871122594*^9, 
   3.47897087265033*^9}, {3.478971414854863*^9, 3.4789714317583723`*^9}, {
   3.4789723334965277`*^9, 3.4789723911200447`*^9}, {3.478973525233735*^9, 
   3.47897352833882*^9}, {3.479495227181163*^9, 3.4794952662789087`*^9}, {
   3.4794954131043873`*^9, 3.4794954161349077`*^9}, {3.479497883443406*^9, 
   3.479497887306903*^9}, {3.4794980354692507`*^9, 3.479498036795588*^9}, 
   3.4794982488155937`*^9, {3.479662131489229*^9, 3.479662133377276*^9}, 
   3.479665540471899*^9, {3.4802459792714577`*^9, 3.480245981573744*^9}, {
   3.4802525542284737`*^9, 3.4802525884311867`*^9}, {3.48194087775911*^9, 
   3.481940886937986*^9}},
 CellLabel->
  "In[175]:=",ExpressionUUID->"9b4a253e-aa44-4989-976d-0d18868730fa"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nk4Fe0bB3BR2ZckS5EoKiolhMo3RKVCSrRQka1EQjjOOXOOLR3SqkWb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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"z (m)\"", TraditionalForm], 
    FormBox["\"F (N/A)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.013}, {0., 0.3925374150688015}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.478970312655707*^9, 3.478970349956621*^9}, 
   3.4789703994875298`*^9, 3.478971607584939*^9, 3.4789719008193083`*^9, {
   3.478972321794873*^9, 3.4789723915815496`*^9}, 3.47897462857933*^9, 
   3.479491375853756*^9, {3.479495240008403*^9, 3.479495266824088*^9}, 
   3.479495416841895*^9, 3.479497903792444*^9, 3.4794980383520308`*^9, 
   3.4794982508041973`*^9, 3.479665430756591*^9, 3.47966555437061*^9, 
   3.4796655952965937`*^9, 3.479665767861109*^9, 3.479665800596849*^9, 
   3.479666123343511*^9, 3.480085442474633*^9, 3.480085476792396*^9, 
   3.480244564663542*^9, {3.480245967281913*^9, 3.4802459841655083`*^9}, 
   3.480252591260969*^9, 3.480252685939891*^9, 3.480692325467414*^9, 
   3.481940897619549*^9, 3.481940954553793*^9, 3.4819414042893677`*^9, 
   3.481941630662005*^9, 3.4819421034795094`*^9, 3.662607045369123*^9, 
   3.6626072503934526`*^9, 3.662626188358437*^9, 3.799212568996962*^9, 
   3.799212820114786*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"57f74154-c8c9-49d7-91fa-2ae85a211661"]
}, Open  ]]
}, Open  ]],

Cell["Combinations with opposed magnets", "Section",
 CellChangeTimes->{{3.4802635577614393`*^9, 
  3.480263564378763*^9}},ExpressionUUID->"c3b09d43-f3b6-4a18-b0db-\
d33ac90e0b1c"],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 5 mm apart with hybrid OSEM coil - historical interest only.\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.4807001348451366`*^9}, {
  3.481565209358251*^9, 3.48156521929447*^9}, {3.481565959348879*^9, 
  3.48156595959684*^9}},ExpressionUUID->"3c2133ea-c6b3-4e20-9c0b-\
5677ddc7ddd8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", "z"}], "]"}], "-", 
     RowBox[{"fz", "[", 
      RowBox[{"BM", ",", 
       RowBox[{"z", "+", "0.015"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", "Black", "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.4802639392440853`*^9, 3.480263973553187*^9}, 3.480264058574482*^9, 
   3.480264152546308*^9, {3.480264362832872*^9, 3.480264366942833*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"3295a945-7d3c-451f-83e8-c148033f7623"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV1nk4VdsbB3BxlUJS0oQUKdFAitulrzKEUoYkEqVEMiQZztnH2KlrrKt+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       "]]},
     Annotation[#, "Charting`Private`Tag$305952#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263609670712*^9, 3.480264091847402*^9, 
  3.480264219397868*^9, 3.480692381982799*^9, 3.481568304979225*^9, 
  3.662626226196561*^9, 3.799212569106269*^9, 3.7992128541521072`*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"15dc98bd-3fed-4e57-bd88-b7a896c29bd8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.9124418416937872`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BM", ",", 
             RowBox[{"z", "+", "0.015"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264827573757*^9, 3.480264835420212*^9}, 
   3.480265037916628*^9, 3.480693722607716*^9},
 CellLabel->
  "In[179]:=",ExpressionUUID->"669c2f71-30fd-4ee2-a1be-27ec0e3f0c0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.9124418416937872`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.0068007634327481815`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480264812348777*^9, 3.480265632924423*^9, 
  3.480693092309564*^9, 3.481568926418055*^9, 3.662626522075367*^9, 
  3.79921256911581*^9, 3.799212854202753*^9},
 CellLabel->
  "Out[179]=",ExpressionUUID->"1b634ab1-1c7b-4ef1-9bc5-4e4ca3bce323"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"31db6a62-ff27-4e38-bd76-ac28d9c01d8b"],

Cell[BoxData["0.0068007634327481815`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480265633025037*^9, 3.480693092364389*^9, 3.481568926517033*^9, 
  3.662626522160326*^9, 3.799212569150943*^9, 3.799212854211009*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"4c8a1c28-3e85-40ca-bce3-f11545b0833d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BM", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BM", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"fe6f9ed8-6623-4eef-97b8-c489a8a5923b"],

Cell[BoxData["0.9124418416937872`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480265633047605*^9, 
  3.4806930923900967`*^9, 3.481568926569429*^9, 3.6626265222042217`*^9, 
  3.799212569158848*^9, 3.799212854257913*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"84e76f2f-a94c-43ad-be41-44c2391a042a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BM", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"97af3af2-c4ae-4e04-a6f7-b5103efeb3a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXswGwYAB+As0rlqlvNKp5FOqzrMUI/akOxXrVS9WjWUG2UEN1JSW4YK
DSKIMreirLWt19NVTTs9j9I0m96ij6guVlGvqyIaEnlUyu0Ot+2P7769qbnR
6UQCgcD4z/+brvQ7FB/TMQkES6sAc+5nM+3hEtOQG0a8lncGszvRfS2TuO0N
A9/n2q7ca5TCMv+fkHoBC1nTDQphxxAiNIxABTsCiUVt7KIXT1HoEp8eqT8J
O78wwyXZKA4GsDPjOLGglVH2M6OUuB5c1bfPNwFnqeeYbdRJ/OCnaQ1bToRj
ZsDmZvcMJEeiXoYdSMHfbr5dBYJZiNS9TaOWqVBlJduRmHOQSY5mcxRpGF/b
ITs9Mg8Zac3CpzodxX018t5QFfaEdim+yMgESh8lUZ4vQi9p7Gna9xUWFx7Z
lXursctd9IfPu9mgvHLcUrcsgWTV1LT5kgOTpMPt9sIy2E7PqidacpCcIb6b
RtLCkmYxWsPg4rcL73hLnFZww39wxYd+Fh5SrUFO0yHn1Ba9lpKH8YHmDtEO
PWw95V38jTykku+x7Gf04P34cSxv8muQGGfqvIINMCPbkh3k3yA0hsoZvGhA
hFW9QtHBg3/fSbNLCgN4f13eoFV9C9eK0+xfiEYM17oHUvPzoR1JmHN1M2Jm
7vMqu7gC1N2cSopmGWHvR1gaDilElMogTo81IuAI4/b7B8/hCe1PFSvBCBs1
WZhtXQRhu3D9YbQRtJo0DpfIh8XGzu0JQUZMyY6nlczxcc21X210NqJ44PHv
jtJi1DvnBNqbGxHR+cSz4NcStJ7Sv3diygDlJym3lOLzWNo6NJ3fYcDRWeae
VaYA5N0spYxrwHlDI/f8LQE87/bcP+RrwI2ZnlUlvRT0rOMNHLUe6sfNhMqG
UvC3V8viY/TYRhxqCCSVYbFsMOXpAx0+9e+9c6y4DKMPgr7M+ECHxMgcs72m
Mrxasl4pyl9BUid3ajO1HGlvdJUL41rwyH5Mn6lyxEXRKtqctcjqY314JlwI
A5mqXRNocAK7D+f1C9F5s1ITNr2M8KG+188OVKCRwJW+dVmGU8sVW++fK0Bv
pXq0li7BNjtYrrUTYWOydmxiWA3Tru7uvO9E4GbrrC/S1eiyzdm/uSlCyHMP
r/bC16igaBxmeZUgk2yuE+WL8Iu5c/WhqhJjE3SLgI8WsdXM6DRPrkI3xYYg
K1Ghd6BOY62sQjwjyJI/sYBwF7cuR1Y1Yt+OXfY9vID1BjGh5n41+ENzq3VX
5yGI9B1fdxfDbmxd+oIyD2ODX670JzFMEUZxT/Ec/gUgJMys
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$343552#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980085`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXswGwYAB+As0rlqlvNKp5FOqzrMUI/akOxXrVS9WjWUG2UEN1JSW4YK
DSKIMreirLWt19NVTTs9j9I0m96ij6guVlGvqyIaEnlUyu0Ot+2P7769qbnR
6UQCgcD4z/+brvQ7FB/TMQkES6sAc+5nM+3hEtOQG0a8lncGszvRfS2TuO0N
A9/n2q7ca5TCMv+fkHoBC1nTDQphxxAiNIxABTsCiUVt7KIXT1HoEp8eqT8J
O78wwyXZKA4GsDPjOLGglVH2M6OUuB5c1bfPNwFnqeeYbdRJ/OCnaQ1bToRj
ZsDmZvcMJEeiXoYdSMHfbr5dBYJZiNS9TaOWqVBlJduRmHOQSY5mcxRpGF/b
ITs9Mg8Zac3CpzodxX018t5QFfaEdim+yMgESh8lUZ4vQi9p7Gna9xUWFx7Z
lXursctd9IfPu9mgvHLcUrcsgWTV1LT5kgOTpMPt9sIy2E7PqidacpCcIb6b
RtLCkmYxWsPg4rcL73hLnFZww39wxYd+Fh5SrUFO0yHn1Ba9lpKH8YHmDtEO
PWw95V38jTykku+x7Gf04P34cSxv8muQGGfqvIINMCPbkh3k3yA0hsoZvGhA
hFW9QtHBg3/fSbNLCgN4f13eoFV9C9eK0+xfiEYM17oHUvPzoR1JmHN1M2Jm
7vMqu7gC1N2cSopmGWHvR1gaDilElMogTo81IuAI4/b7B8/hCe1PFSvBCBs1
WZhtXQRhu3D9YbQRtJo0DpfIh8XGzu0JQUZMyY6nlczxcc21X210NqJ44PHv
jtJi1DvnBNqbGxHR+cSz4NcStJ7Sv3diygDlJym3lOLzWNo6NJ3fYcDRWeae
VaYA5N0spYxrwHlDI/f8LQE87/bcP+RrwI2ZnlUlvRT0rOMNHLUe6sfNhMqG
UvC3V8viY/TYRhxqCCSVYbFsMOXpAx0+9e+9c6y4DKMPgr7M+ECHxMgcs72m
Mrxasl4pyl9BUid3ajO1HGlvdJUL41rwyH5Mn6lyxEXRKtqctcjqY314JlwI
A5mqXRNocAK7D+f1C9F5s1ITNr2M8KG+188OVKCRwJW+dVmGU8sVW++fK0Bv
pXq0li7BNjtYrrUTYWOydmxiWA3Tru7uvO9E4GbrrC/S1eiyzdm/uSlCyHMP
r/bC16igaBxmeZUgk2yuE+WL8Iu5c/WhqhJjE3SLgI8WsdXM6DRPrkI3xYYg
K1Ghd6BOY62sQjwjyJI/sYBwF7cuR1Y1Yt+OXfY9vID1BjGh5n41+ENzq3VX
5yGI9B1fdxfDbmxd+oIyD2ODX670JzFMEUZxT/Ec/gUgJMys
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$343552#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.0842951750980085`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {49}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGJDBgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gb71C/bgCY0Qu1vtH/+e+XHS75NUHc02WcyzzW7kNkMdU+z/RuuCdVn
W1vs14Ld1WqfJ9QMtKIV6r42+0+SZawn9rZB3dluX6yY6XX0Zru9Cdi9HfZf
NWL6D33tsN8GdnenfTnIWsEuqPu77AGyNMFI
   "], CompressedData["
1:eJwBmQFm/iFib1JlAgAAADEAAAABAAAAAAAAAAAAAAD7AMncqMayP4cqdsrG
vMI/9IH4t2ECzD8sYYLNBZXSP/hmMh69FNc/Fe0rnhZ72z+65jqMuMLfP6G0
2iAb8+E/GdspKg7w4z8VVl4kgdXlP92kYo3QoOc/rmGR7HZP6T+HfsxfG9/q
P6g+53KgTew/l7+vizKZ7T+5tGjNVMDuP4ItCw/swe8/2KrwlaNO8D/DuIcl
EqnwPyfGYt5Z8PA/1aLrIcsk8T8pRpbA7EbxP56nllB4V/E/S69jDFVX8T83
Z2tzkUfxP+Y4G8NbKfE/ptBCq/n98D/xeyxXwMbwPy/VRd0KhfA/fW/EgzM6
8D+j4sO7GM/vP3X9LveyHO8/uvEy+5hf7j9HDRCUAprtP/45jVT4zew/T13h
RFH96z/0pSwQsynrP3UsZeqSVOo/ugjN1zd/6T+C67BavaroPzoXB8cW2Oc/
HU9itBII5z9/lclNXjvmP5QE3OOIcuU/GALQHweu5D93fSoYNu7jP9L1cRVe
M+M/pSZmgbV94j8pjsms
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662626531280512*^9, 3.799212569233944*^9, 
  3.7992128623662033`*^9},
 CellLabel->
  "Out[182]=",ExpressionUUID->"a29779ca-4c62-485e-9aef-02991baf11cd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling", "[", "BM", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BM", "]"}], "[", 
          RowBox[{"z", "+", "0.015"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BM", "]"}], ",", "2"}], "}"}]}], "]"}], "]"}],
      ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, 3.662623730198477*^9, {
   3.662846418987355*^9, 3.6628464235824213`*^9}, 3.799212531148233*^9},
 CellLabel->
  "In[183]:=",ExpressionUUID->"0639adc6-6737-4ad7-851a-9a0285bb4887"],

Cell[BoxData["73712.45272737803`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.6626265314140587`*^9, 3.662846424961239*^9, 3.799212569296418*^9, 
   3.7992128624416113`*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"e8053031-8815-4037-9c8a-3f1b31502039"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BM", "]"}], ",", 
      RowBox[{"zmax", "[", "BM", "]"}], ",", 
      RowBox[{"fmax", "[", "BM", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BM", "]"}], ",", 
      RowBox[{"zmax2", "[", "BM", "]"}], ",", 
      RowBox[{"fmax2", "[", "BM", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.4815681797948217`*^9, 3.48156818542627*^9}, {
  3.662623414299822*^9, 3.6626234188219624`*^9}, {3.799212531148889*^9, 
  3.799212531149397*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"62f882dc-4d25-432d-8550-6cb963756cf7"],

Cell[BoxData[
 TagBox[GridBox[{
    {"73712.45272737803`", "0.006361536563952735`", "1.084332204665714`"},
    {"73712.45272737803`", "0.0068007634327481815`", "0.9124418416937872`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.481568186322205*^9, 3.4815689269394617`*^9, 
  3.6626265314412413`*^9, 3.6628464281771193`*^9, 3.799212569310655*^9, 
  3.7992128624495077`*^9},
 CellLabel->
  "Out[184]//TableForm=",ExpressionUUID->"341d574d-beed-417c-be19-\
072822b5b9ae"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
10x10 magnets 20 mm apart (between faces) with BOSEM coil per pitch magnets \
on top mass and UIM of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
  3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
  3.48156609404573*^9}, {3.799224311732572*^9, 
  3.799224314556679*^9}},ExpressionUUID->"82549c51-83fb-4a0c-ace5-\
8082f6200c29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"BO10", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, 
   3.4815682113946342`*^9},
 CellLabel->
  "In[185]:=",ExpressionUUID->"9ba64c0b-d7f4-4cf4-aebd-e3d6ae2a9ab6"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV13k8Vc0fB3ASiSRlS7ZKSkmJ0sZHRaEIJUkUZQlJC3HvPede3FK2HipR
ikq0iZAslUg82gipX8gaES2263gsv/HXfb3va8585szrzMx35rses3WbIiQk
JCksJDT5a2Ay1Mue0WPomGN3cJ5WSZG0QWHC04IKIzuVn9ZJE8VFCxxf8bgF
/zOamRrttbCuuEj76LZThwq6jHaKOqtphxYX6QZM97UrYIxwNqMQjS+Lslnd
XlYF09E6Yb2tdUFR0cDovi6LgrkY+S18X3ogv0jO6OIS8wItpE7N3H5aN6Mo
X7gt2qxyPZY4J/VmL72GfUs4yt7dW1AStlJnd0wh3uQHtnJ3WGBQ2z59rKUc
rtGdbuGJ1lCN3pfAdfyIvoLjWzM+78I7m5uafPs6bKu6u1Z2rz1SWhYYWqfV
4/LXvQvV/90Hmwc3Oj+4NGOoqTNIbMwJ4/IPNqfktkKqU+Z4XOFBsI8ci/93
+Xfcc1Srl3d0xZ1lgfdSvTpRbHGk2KvvEMKHGpRqIrqw8dH5TOeHbpiz8Nbj
ivKfML6Q8KnIzANpb7InNN70Iq2dK1I87QgqKpRs4lt+IzznVvrlF14QGSp/
NvbzDwTCT6I+2/tgmcMDt+C3f1H26npA/hxftIYuW17/uA9qIgGXxbOOIZDt
Ym5M9eOoY+w3dr4fNv/htBbuGMD5vrCVjZePI5LWkVgqOQgvM38V/0MncHll
xp/KzEFwvryf6bT5JA7dk7ihZz+EXYtVr7Fnn0LHtZP75TqG4Jkd+T302yl4
WnaGHXcX4FGQu35DoT/qXD84xrULkD9uoOodHgA95a6DklbDGHx+aoaF12ns
0lxwf1b2MI4VVObN3hoIx2OfE/+IM9gv2vtkq3kg8i8eMlGUYGBmLZHN2hGI
kebvayDJYEGHSXqrbSBU1wyOhksxqJMpuJl1IBAVyYdmKs1mYHQkJdw2KBBP
7m/cKT+PwUzFoP2xDwPh9tMhNkybwSP/BUKz5wThcNrd4J2WDPhHbQwj5IOQ
kmp+4IAVg31uPNZUpSBUR2/19t3JQNTu28CQehDsPsfODLch49O/2lWvE4TT
0dGhT+0YSPTL1NyxCIK6UOrqn04M3P2EU9eFBEEyRkkr9ygDVe/m7S5/gyBx
ak1nYziD35vYh5IGgtDsEGj0IILBS0V5dqMgCNu2+LSejmTgUrb9vsN4ELQ8
H8tIRzNImf9U3FaSBZOARKnVMQyWfYl6vXkRC3yNxrADVxisNd0ADQcWYgx6
funcZjBduW6P634WNkyMTnwn/trn55t8gIXMjZ8PJKYw4CSnXld2ZyFAWGPG
tFQGRf/JjMqeZIGOblWsvctga9aPPNEoFrrb02ZZPmKwSy1uVedLFnKEFnUV
5DFQPKb1V7aUhdcZfeV78xl8e/EsY3M5C3ITB8YHib2c27RvvGchut7+hE4h
g5DrKxfbfWWhIfR04JXnDDLnvZ33qp+M77iapEUJgxmKQqJJmmykXfuWr/uW
QbXHxVfvtNj44uP0oIA4/qlmyIg2G3I0Z2jzOwYL7S0n7PTYaLBrTLB5z2B9
3FVmhjEbc5QZeY9KBkdkV/9iObChuESLOVHDoGyW1+c9kWz4j/vXzKxncEpK
uq7iAhsddqNDkcQLJXJqN15ko36aioNEAwOeyPjHBVfZSMkI+d+URtL/UMy7
X2lslP9v9/vubwwy6vOLz74i7bnZl+JaGTh/cX7JlLERrGPzULyNvM8nkSKf
N2wob/kjwiL2+mD5zPYjG9efRJ7c185Ao7glV7WJDfP11/bM7iDvlzr9Ye4I
G5xOzU3OXWT+bz+6rzXORpH/zUOlxINJu+4lCnMw/1d0uVY3A9uE66kh4hyM
uWru7iOeEal700qeg80TOSGsHgbBxx3iOnQ5UN2oZ+Hxm+RvvMeTP8KBfvKi
pdkDDGQVCxysfDho/LfTZ5T4ef+bVWePcbD7pusM00EGsx70tA/6cwCnry61
xE/nrjT/FMJBbd6Q588hBlMFuTKXEjmwHQxlRobJeqou736bxEFfn4vMeoaB
/aMvr0Ruc2D1Xj8skPi+24j/yXsciFVrRPUT29QafrXN5WC1mOlYywiDG49L
b8lUcaCXdOJB8ihZ71Gf2OY1HHhalTz8RPzXs2N3cB0HUQGOUhJjDEzUxaf9
beDgmnB+jx/xz+jt3lVdHDwJ89Y0GGdwyWu/iXgvB6a8FRoexEZbj6oY/+Hg
kcdEcBxx7Fh0ZcYQB5oDT536idf6VOtdEKGwlzMt/s4Eg9ZtbTPKxShUXc28
UkUcuXDg+/h0Codl+wUjxE1f5eJ9Z1HQe37zq6XQCM6aO4xaqlBoqXuztIe4
RrO5dIYBhRNLX86SnDIC94wp386vpzDt5IV2HeJhg0UCMSMK15vvjdsQK5t7
aQmbUujWnSsWN9neeyBq0JbCc0HTYTkR0r5fPu3EHgoVL5qO6hFHcNa9/O1A
gbNhygtr4swouq/rIIWwi3L654lHMsTtv/lSiDMtZf0ljly7zM/xBIXLF3qK
pk8dgVqx5fkv/hQCqxQt5xObVMcWVnMomEX8ghVx3b4ntTt5FFzLq+4cIvZs
+9z7LpRCEL1kdyBx1ICyenk4BUmH9PAkYnUK60yiKezIWjQnizhL1NW2OIb8
6eXX/mqyP/k0fmE8haQFOq7fJ/tLqri+NpHCn2M/Zg4S/7e4J/dJEoVlU/5M
nSpK+lun25WRSiFWMfi9GnFW8a4py+9TOGJskqxNbGoRMO9+OgWP4dpna4m/
VMfrL35M5vf6/oUmxF6OhZYpORR61jbVWBGPtjW6z8+jsND7wYe9xNE+Qrwb
hRQuNF6c4zqZN7ggYV4RBYRX3/IizqZMs+JLKPwjcZhzgnirmOdbuTIKhSZF
yUGTedHh7bEVFDqcq6R5k3kK6WPS74kjcyrOTOYlVcpHVVHIlDz/IXwyb0nf
ColaCgXzvVUvEM9/LGse9pnCB9XA/FjinHUGrlPrKZjqlyZdnswrcWAHf6MQ
Ksv9eGUyz4JzabyFQpvwc6sEYu+aG+ns7xREj19TuEo87lhcNvyDQmWTgfak
/2lva/LvodBamxE52X7BUTGm7zeF1Gb1dfHETwaXzPbrp+CbeFc3jtiM3r6s
d4jCYiuBy0Xir2K+Jl4jFFYZiPdPjtfnwj9OnWMU7tWeq4ognlDIDjgsTCOh
PW7kLHFs8qcLLVNpfF5ufTyYWENr+K6zOI2NwdX6bOLcx0ol9ZI0nOauNT01
mbfesH6vNA19+dRbPpN5JQcGPs2moVq6xvIw8dHtIVK75GkcnCVh6kg8kjVL
+PJcGuLXc/Rtic8pJQ3UKdPoTMk7Z0Z8q6uwft9CGnnrFjnrEa+0sahM1KRR
8Ppl02Li53lfSr5pkefb5MrmTc5n2OA915U0spbuLBYmdv8dej1Fj8bvqx51
/eR77N8zO6ZjDY2b0gnWk9/rTM0VgV6GNDKsM06VTa6XUs+tJyxorJrmRwcT
Vy8TrMuxJONJUCryJT5w8czyIWsabkFpbo7ELNdbsix7GvVFb9tXEWcKNbQG
H6axwmIs/StZn0aeXnWvPGi8Gzyl/or4beVwhag3DZXmOOY+cccNucfnj9O4
0WXYHEisbLiTG0PTeBZaGyxFfD+l8URNMI1lW/Zq/yX7h8EMH3e5MzQUnPYY
1RLb1p+zTIigYU/NSYgnPhdUMu9mPI3NAmttJWL5Fmvptms0OhKN5RjhEdw2
a5qyKInMh88x98/ELxRGu+7eoXE748+mWOKBJ6vzMrNopGrsaBYiDlEpfdD3
hEaOg/DMerL/SZ+xTdLPp3HkQUlKDvHS3cfO5hXRaL1aJeVOfLDv7u6X72jk
Vv2sKib76Tsd5b+VHTQqirN0nch+bCV9O0K4m4ZXV1K3DvHH31qaer00/rso
IitEXJdp4BjXT6NNNCEvmez/zat2vd4vxMVrG9b2enJe9K8JT+iay8WsGrVH
q/9jEKAgoz9PhYvtZVKscXLeDAuufNihzsUOhYmnZcSjeXdEMjW5yPi0M9yO
WGxD8dEAPS5+qXlE+JDzSgnDm0QsuQg0puV4AgaJatwGfWsuHnLdpYyJ1YTE
Trvv4sLsQXvgxNDk+T7nYYUDF5EPRR5wiHW2rJD/x50LlZh7tB85Tzdvc+9W
5nHx0rCJMewn9crO2tg12VyYzKD7/X4xqG3wOZqey8Wg880URWJjL1EzjQIu
pB875BT1MpA/s2ZMppgL+VOifySJSwriPXo/kPGkLWxI/MlAWdNpY0o3F6+E
A1KSfzDwHO/rE5fh4dqHt80rSb2iaoqDpbN5CIvm3yltYVATEfGeK8uDvLrU
e3tio7kad4cUeNjuKW7KaWYgp2/n1K7Kg7v4yYbnpP4pOfK0vEibh60bK8sW
kvpJ+RM7McCMh5igbDab1Fs7JccDZC14eJ68/vBU4pBNPJus7Tzkp10sj6xm
8COdL/bLioeVQysnrn1k8ORslJ+bHQ+zUpRW55D6zWptksluVx7GxHtq35L6
L/haSY8uh4cz6zakx79i0OEy3bA3gwd6ebdCxmMG0b6XnqY/5uFcTeB3CeLV
bLVVvtk8nP65VM09k9T3l1Yv/p3Lw8SzL5+VMsj9odxF5u9zHoK+S7tQDxkc
0C74PvCWh3YZ7oBmGoMvQ17Ro508mLuc3SiVyKAi4l2TpHowostLt+vwGWyv
veGiFh2MmXlGlDy5H6wY7Vn5YSAYplT0k2h5BtrFflMWHQ4BO1p4zqrqYUS4
+c1XeBcCrf6c/aaRwzi/hKs2rhuKvVcq5/I2DyP53Cu1qORQqBypa1/WK8Dc
f0OPPp3Gh9gjy38VEgT4cLhKlj+dD/Xmv3ZXrgjAF1Z5Zi3JR82me1fk4wT4
sz5XonsmHyLnfHVlLwpQlv4jTVmej62+xl2SUQKcuGjZGqzBR2XW4YO9PAHe
OSvY79jER9J1QyrIU4CQ/w6NK27hoz1JtvE3ub8ZxGfe+W5C8nJiB93cBLj1
0XyANuNjdaDTbhtXAYJMODGPd/JRu6+zXGO/AJpLW97KO/NhHF5y98VOARrK
lp9sO8DHNfEzGSutBIg5xFLKdOGjZ/Tr8Vs7BBhNnHPE3I2PM2E1S8+YC1Aj
vVWM48NH13oFv21bBDj3MDbdzJc8r2rg8HSTAEbmTbvl/Pg4b+c4oWkswP2Q
wNuPTvKx0cMmVNRQgINqry3Y/nwMeIe4nNoggNwzmb5tp/m4u+DvaOs6Ad7s
dU6QDeLjeemZPTZrBeAN3jduYfHhobLEt2iNAP8HLBs50w==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.662626577706636*^9, 3.799212569353179*^9, 
  3.799212862488722*^9},
 CellLabel->
  "Out[185]=",ExpressionUUID->"9bbda839-543a-4494-98da-90326835534d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.6263677836045267`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"BO10", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, 
   3.481568221803894*^9},
 CellLabel->
  "In[186]:=",ExpressionUUID->"d0eeecc0-a2d1-45fd-96cf-dfc5a8a565b2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.6263677836045267`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.007300967534849954`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.4815667132643127`*^9, 3.662626914105783*^9, 3.799212569394408*^9, 
  3.79921286249854*^9},
 CellLabel->
  "Out[186]=",ExpressionUUID->"b7c73d57-a6e5-42ee-93c8-c03a5a429c20"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}},
 CellLabel->
  "In[187]:=",ExpressionUUID->"bb35c655-1d44-477b-ac6b-b958d5fc1ff1"],

Cell[BoxData["0.007300967534849954`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566713311575*^9, 
  3.662626914153386*^9, 3.7992125694021072`*^9, 3.799212862534831*^9},
 CellLabel->
  "Out[187]=",ExpressionUUID->"603afffa-8586-4210-8968-6669be71c086"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "BO10", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "BO10", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}},
 CellLabel->
  "In[188]:=",ExpressionUUID->"4ece9598-59a5-4f96-beb1-ee15b0d78481"],

Cell[BoxData["1.6263677836045267`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566713335513*^9, 3.662626914178856*^9, 
  3.799212569438169*^9, 3.7992128625428247`*^9},
 CellLabel->
  "Out[188]=",ExpressionUUID->"9898831e-cbce-4855-96c9-471fa2892318"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"BO10", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, 3.6626237826767893`*^9, 3.662623817129786*^9, {
   3.6626238562340107`*^9, 3.662623857953149*^9}},
 CellLabel->
  "In[189]:=",ExpressionUUID->"3162c008-6aed-430c-8662-2321d7d5e472"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AANCro4J3Pt2pS7z0
xis/pg0Qjc6NtT+0o2cCBfI8PwCKjRp2bMY/EHf5R5CART/Zc5vXap3QP0zr
PDvRZEw/Nq8lxyvd1T95KFhlTe9RP9DlGwigfNs/NTpkZ1ZsVT9xc8GIdFPg
P6ZEiLcjNFk/NzeInUYS4z+aNuudSupcP+8jWLRZtOU/vENQ30owYD8WPyC0
IRnoP4botpbSEGI/xq5+zl2e6j/FvEZrbNFjP/RLCpAe5ew/xQT2CjOJZT+I
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7i4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/EAV0WMcc9j9uV/4cjQ5yPzxAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pvaReM8h+D8DDBQMH8t0Pz2f44jp
s/g/TBGQ0dGrdT91YmQs8y35P3XQm/waiHY/qyc5tSmY+T/MjS07FXd3PxPe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/aRsO6aOT+j86QzyvFzV6
P1uCYVT7yvo/E+gMhGsSez+GZYDTpPH6PxqLY2xwAnw/IqGYS8wN+z/bxU5j
fuJ8P+8FpDCGG/s/fbrJvyK+fT/CbrAmmh37P0ytyi94rH4/lw2LZZkT+z/W
N2Cu1op/P3ANZJhA//o/RuA9IPM9gD8wc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1C9B
O8UA+j84ObaySH2CP2ITGAIJsPk/XE1uAyH0gj9XgEhmS1n5P12tcNv9YoM/
XGEQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/hPnjb9jv4P08/HUJy
uYQ/g2vxfqfX9z9LxrfnzzCFP1A2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/ouiUeCeD9j/0GbS0co+GP+a+MB5rC/Y/sRRuJf39hj9j5a7vUpr1
P4UO6x/gdYc/S2jNFJce9T82VLKhx+WHPw68uxR8qvQ//pg8rQdfiD/nGdNb
biz0P7a6jusS1og/HKxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/0DHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/wvjIBw==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$348404#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981908`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAA9Jy5H31I7j0AANCro4J3Pt2pS7z0
xis/pg0Qjc6NtT+0o2cCBfI8PwCKjRp2bMY/EHf5R5CART/Zc5vXap3QP0zr
PDvRZEw/Nq8lxyvd1T95KFhlTe9RP9DlGwigfNs/NTpkZ1ZsVT9xc8GIdFPg
P6ZEiLcjNFk/NzeInUYS4z+aNuudSupcP+8jWLRZtOU/vENQ30owYD8WPyC0
IRnoP4botpbSEGI/xq5+zl2e6j/FvEZrbNFjP/RLCpAe5ew/xQT2CjOJZT+I
UOEusAzvPyBJsdFbZmc/faZOK9yl8D/vvJW1liNpPxhZuBySpvE/GS2GwDMG
az/pQDkTpq/yPwQRlpb932w/pPxYcwam8z9kJM+J2ZluP7i4qBYIf/Q/EBoK
0os8cD/2HhXxHFz1P6g5we0zHHE/EAV0WMcc9j9uV/4cjQ5yPzxAfXti3vY/
FC/LsXz8cj+tz2Ut8Yz3P3WeLFV12nM/pvaReM8h+D8DDBQMH8t0Pz2f44jp
s/g/TBGQ0dGrdT91YmQs8y35P3XQm/waiHY/qyc5tSmY+T/MjS07FXd3PxPe
vzJ0/Pk/3eJTiBhWeD/fW9KiKkz6Pxs2AOnMR3k/aRsO6aOT+j86QzyvFzV6
P1uCYVT7yvo/E+gMhGsSez+GZYDTpPH6PxqLY2xwAnw/IqGYS8wN+z/bxU5j
fuJ8P+8FpDCGG/s/fbrJvyK+fT/CbrAmmh37P0ytyi94rH4/lw2LZZkT+z/W
N2Cu1op/P3ANZJhA//o/RuA9IPM9gD8wc+3Pxt36P3/wlXB/roA/gZjHyF+0
+j+o3bXz1hyBPxZUkXLVgvo/6MmYAIeUgT+lEcguxEP6PwUCxpQ7BII/1C9B
O8UA+j84ObaySH2CP2ITGAIJsPk/XE1uAyH0gj9XgEhmS1n5P12tcNv9YoM/
XGEQBl4C+T91DDY9M9uDPxnqB1pCnvg/ardFJm1LhD/hPnjb9jv4P08/HUJy
uYQ/g2vxfqfX9z9LxrfnzzCFP1A2JywJZ/c/JJmcFDKghT/elPQo9fr2PxRr
RMvsGIY/ouiUeCeD9j/0GbS0co+GP+a+MB5rC/Y/sRRuJf39hj9j5a7vUpr1
P4UO6x/gdYc/S2jNFJce9T82VLKhx+WHPw68uxR8qvQ//pg8rQdfiD/nGdNb
biz0P7a6jusS1og/HKxHAsuw8z9LKCuxIkWJP1b8Y+jaPfM/95SKAIu9iT+B
B49P/MHyP4BNNNf3LYo/0DHlJ0NP8j/xlDZvvp+KP3EtSARM3PE/wvjIBw==

                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$348404#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 1.6947270880981908`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {46}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJxTTMoPSmViYGBgBGI9BgRQqzDwv7Lf0B5CO9pbbjlRtm++F5QfaG8w7U/S
Sf0wqHiUvfOlKV2b+eOh8on22u1iN899T4aqS7M3XfrozeH0DKj6LHu7w+sY
dl7PgerLt19SYMt1fXEBVH+h/Yp65SkXbxdBzSm2X9fHKXdGuBRqXpn9prnv
lx/zLoeaW2G/Y81Vw4PNlVDzq+x3g0E11J4a+wOnFrpu+1xr7wS2r94epOuG
aAPU3gaovY1Qe5ug9jbbv+GaUH22tcV+Ldj+Vvs8oWagUa1Qd7TZf5IsYz2x
tw3qnnb7YsVMr6M32+1NwO7qsP+qEdN/6GuH/Taw+zrty0HWCHZB3dllDwCe
S7Qu
   "], CompressedData["
1:eJwBgQF+/iFib1JlAgAAAC4AAAABAAAAAAAAAAAAAAA0ioxNc4m7P2Y0/HmX
eMs/Or5lU3eF1D8U1V6ZujXbP5qJJ9yb4uA/xZaudDYW5D8H/89kIzLnP0yF
V+MXM+o/egcvBg8W7T/v39TDSdjvP776IaesO/E/pV+NnIx48j/4nril2KHz
P+8ZapvKtvQ/aa2a68C29T8gt2mAPaH2P52zt5Hkdfc/YdVJaXs0+D82xyZL
59z4P5eZCXosb/k/VK98dG3r+T/JmJ9A6lH6P3Mp+e//ovo/9BtLKSjf+j/H
G+Cy+Ab7P81tg9giG/s/cASuxHIc+z+EkIj9zQv7P1TF1lgy6vo/T2EOJLO4
+j/DvEY2sir6P3+7qTCaa/k//jhFb56F+D8koFeRMAf4PzBzks68gvc/hFkZ
5WP59j8sgVIqNGz2P3Nlwbcn3PU/dpUqSCNK9T9x2XoH9rb0Pw678INZI/Q/
r9lrh/KP8z9XNsH1Uf3yPxL/Wh/2a/I/u8Ks/Evc8T9Tg8EQ
   "], {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.6626269251419783`*^9, 3.799212569519064*^9, 
  3.799212871180344*^9},
 CellLabel->
  "Out[189]=",ExpressionUUID->"2f809736-e041-4eb4-8784-2da359d0a513"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "BO10", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "BO10", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "BO10", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.66262382061903*^9, 
   3.662623864201857*^9}, 3.799212531150227*^9, 3.799224399347836*^9},
 CellLabel->
  "In[236]:=",ExpressionUUID->"6201ac92-f07c-47ff-8558-6d88b251ed7c"],

Cell[BoxData["194678.9729432676`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662626925257122*^9, 3.7992125695508966`*^9, 3.7992128712481937`*^9, 
   3.7992244031562033`*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"594fb43a-943f-4073-b492-f9a72c2a86c5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax", "[", "BO10", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "BO10", "]"}], ",", 
      RowBox[{"zmax2", "[", "BO10", "]"}], ",", 
      RowBox[{"fmax2", "[", "BO10", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.481567816726468*^9, 
  3.481567818793173*^9}, {3.662623447715229*^9, 3.662623458100728*^9}, {
  3.7992125311509438`*^9, 3.799212531151538*^9}},
 CellLabel->
  "In[191]:=",ExpressionUUID->"4e67aaea-56ba-4a55-95cd-e7b96b1a29b4"],

Cell[BoxData[
 TagBox[GridBox[{
    {"194678.9729432676`", "0.0071958504693359565`", "1.694858202857608`"},
    {"194678.9729432676`", "0.007300967534849954`", "1.6263677836045267`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.481567825373666*^9, 3.662626925288307*^9, 3.799212569589025*^9, 
  3.7992128712563353`*^9},
 CellLabel->
  "Out[191]//TableForm=",ExpressionUUID->"bfb23b2f-f564-4f47-82b0-\
5100d7143e49"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
6x2 magnets 24 mm apart with AOSEM coil per pitch magnets on top mass and UIM \
of quad\
\>", "Subsection",
 CellChangeTimes->{{3.480700103981674*^9, 3.480700176213991*^9}, {
   3.481565949718953*^9, 3.481565983045248*^9}, {3.481566089551104*^9, 
   3.48156609404573*^9}, 3.4815663420577517`*^9, {3.4815664004646187`*^9, 
   3.4815664245209103`*^9}},ExpressionUUID->"27fb99ae-188f-4fd3-a1df-\
84be7dfb2362"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"plot2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    GraphicsBox[{{}, {}, 
      {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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        "]]}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesOrigin->{0, 0},
     PlotRange->{All, All},
     PlotRangeClipping->True,
     PlotRangePadding->{Automatic, Automatic}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", "z"}], "]"}], "-", 
        RowBox[{"fz", "[", 
         RowBox[{"AODL", ",", 
          RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "0.010"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "Black", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480263490827755*^9, 3.4802634980091763`*^9}, {
   3.480263536719996*^9, 3.480263537125444*^9}, {3.480263833591049*^9, 
   3.480263861642727*^9}, {3.48026393264508*^9, 3.48026393627591*^9}, {
   3.480264005377029*^9, 3.4802640754825783`*^9}, {3.4802641643969183`*^9, 
   3.480264165325192*^9}, {3.4806937485908546`*^9, 3.480693765401557*^9}, {
   3.481566119159527*^9, 3.481566119550919*^9}, 3.4815661573148108`*^9, {
   3.481566453354445*^9, 3.481566453404786*^9}, 3.481568229036901*^9},
 CellLabel->
  "In[192]:=",ExpressionUUID->"34044e2a-61a5-4bfa-b5da-0a2bd8a8ebc4"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV1nlUjG8UB/CKIqKQtEhRSEjCL5S+lqKylHZp06oSLTPzzjRpM0VlSRhK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.480263682317749*^9, 3.4802639921266336`*^9, 
  3.480264150342636*^9, 3.480265704722389*^9, 3.480693170005075*^9, 
  3.481566223913733*^9, 3.48156671551313*^9, 3.4815668538117313`*^9, 
  3.481567024102026*^9, 3.6626269381991873`*^9, 3.79921256959971*^9, 
  3.799212871295436*^9},
 CellLabel->
  "Out[192]=",ExpressionUUID->"362d31ce-f69c-45bc-9cae-cbcce0e2d5c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"optdata2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{"useprecomputed", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.030257769468565232`"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"Minimize", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", "z"}], "]"}], "-", 
           RowBox[{"fz", "[", 
            RowBox[{"AODL", ",", 
             RowBox[{"z", "+", "0.030"}]}], "]"}]}], ")"}]}], ",", " ", 
        RowBox[{"0.004", " ", "<", " ", "z", " ", "<", " ", "0.008"}]}], 
       "}"}], ",", " ", "z"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.478970745257534*^9, 3.478970764425056*^9}, {
   3.4789735053303223`*^9, 3.478973506356164*^9}, 3.478974572010633*^9, {
   3.478974602170628*^9, 3.4789746026573887`*^9}, 3.479661922162386*^9, {
   3.480244453457839*^9, 3.480244472141658*^9}, {3.480244801803609*^9, 
   3.4802448024252663`*^9}, {3.480264669104636*^9, 3.480264684559224*^9}, 
   3.480264725697961*^9, {3.480264796714196*^9, 3.4802647976619177`*^9}, {
   3.480264858240645*^9, 3.4802648706070433`*^9}, 3.480265044282831*^9, 
   3.48069378671309*^9, {3.48156613564054*^9, 3.4815661608653307`*^9}, {
   3.481566453424974*^9, 3.481566453476396*^9}, 3.481568237964075*^9},
 CellLabel->
  "In[193]:=",ExpressionUUID->"48c13e77-6162-429e-b30a-a6280ec31a0b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.030257769468565232`"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", "\[Rule]", "0.005750794119386763`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.480266848202059*^9, 3.4806936239876947`*^9, 
  3.481566715791988*^9, 3.481566854139357*^9, 3.481567149415079*^9, 
  3.662627026022953*^9, 3.7992125696385307`*^9, 3.799212871306295*^9},
 CellLabel->
  "Out[193]=",ExpressionUUID->"d2d11b19-2e7d-4f8a-a3bc-a3780e0a02e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"zmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"z", "/.", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.478970786649661*^9, 3.478970802864567*^9}, {
   3.478973510372629*^9, 3.478973511305757*^9}, {3.479661922261039*^9, 
   3.479661946109579*^9}, 3.479665683353984*^9, {3.4802646918142347`*^9, 
   3.480264705945876*^9}, {3.4802647989584846`*^9, 3.480264799487084*^9}, {
   3.4815664535103188`*^9, 3.481566453543878*^9}},
 CellLabel->
  "In[194]:=",ExpressionUUID->"7407c218-030e-4a0a-95c7-515136a82998"],

Cell[BoxData["0.005750794119386763`"], "Output",
 CellChangeTimes->{3.478971485390909*^9, 3.478974578011325*^9, 
  3.4794913229781513`*^9, 3.479665380304839*^9, 3.479665767726658*^9, 
  3.4796658003982143`*^9, 3.479666123211151*^9, 3.480085256476678*^9, 
  3.480244563873888*^9, 3.480244811221223*^9, 3.4802459142441196`*^9, 
  3.480266848415159*^9, 3.480693624043004*^9, 3.481566716026739*^9, 
  3.481566854410817*^9, 3.481567149455831*^9, 3.662627026053196*^9, 
  3.7992125696471977`*^9, 3.7992128713423853`*^9},
 CellLabel->
  "Out[194]=",ExpressionUUID->"ecadf9a1-7f5b-4b3f-9804-6f74fbbf53ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fmax2", "[", "AODL", "]"}], "  ", "=", " ", 
  RowBox[{"-", 
   RowBox[{
    RowBox[{"optdata2", "[", "AODL", "]"}], " ", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4789708091780043`*^9, 3.4789708248973703`*^9}, {
   3.478973512273596*^9, 3.478973513117116*^9}, 3.479661922361973*^9, 
   3.479661959745741*^9, 3.479665788351471*^9, {3.4802646945892344`*^9, 
   3.4802647077937603`*^9}, {3.480264800442628*^9, 3.480264800914262*^9}, {
   3.481566453577557*^9, 3.4815664536106653`*^9}},
 CellLabel->
  "In[195]:=",ExpressionUUID->"23050121-1a11-4e89-b4ab-3962d9f51f56"],

Cell[BoxData["0.030257769468565232`"], "Output",
 CellChangeTimes->{3.478971485491762*^9, 3.4789745780665216`*^9, 
  3.4794913230334873`*^9, 3.479665380390356*^9, 3.479665767793119*^9, 
  3.479665800479246*^9, 3.479666123277532*^9, 3.480085460576848*^9, 
  3.480244563919486*^9, 3.480245914361339*^9, 3.480266848444786*^9, 
  3.4806936240713797`*^9, 3.481566716286377*^9, 3.481566854706884*^9, 
  3.481567149468693*^9, 3.662627026079937*^9, 3.7992125696830797`*^9, 
  3.799212871353738*^9},
 CellLabel->
  "Out[195]=",ExpressionUUID->"13949d76-72a9-40ce-abf9-9e24169980d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fzi", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{"FunctionInterpolation", "[", 
   RowBox[{
    RowBox[{"fz", "[", 
     RowBox[{"AODL", ",", "z"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "0", ",", "0.013"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.661121231903079*^9, 3.661121302673418*^9}, {
   3.66112135471321*^9, 3.661121364047564*^9}, 3.661121573023286*^9, {
   3.661121981470016*^9, 3.661121984145525*^9}, {3.661122016670216*^9, 
   3.6611220263968563`*^9}, {3.661122422824706*^9, 3.661122440665392*^9}, {
   3.6611225257271423`*^9, 3.6611225561384287`*^9}, 3.661122943936385*^9, 
   3.661124072219921*^9, 3.661124107400278*^9, {3.66114125831656*^9, 
   3.6611412583250227`*^9}, {3.661218342420212*^9, 3.6612184052787037`*^9}, {
   3.661218496917082*^9, 3.661218498643498*^9}, {3.661218568716762*^9, 
   3.661218572408393*^9}, 3.6612187337963448`*^9, {3.661218857797194*^9, 
   3.6612188746198997`*^9}, 3.662246038931663*^9, {3.662246606578101*^9, 
   3.6622466290281973`*^9}, {3.662262652702455*^9, 3.662262654374928*^9}, {
   3.662623129586213*^9, 3.662623133233828*^9}, {3.662623224123418*^9, 
   3.662623225603034*^9}, {3.662623917008511*^9, 3.662623918671576*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"c4ef1199-6327-463a-b14b-bc193aa91401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+CU4LWPVolVsaHopWnzhtSR9NcWpY7ZYphrVUfVnNOl1FF3
5ChxRCTkqPbpObp4jrJQ6tHn6DP2HjUzpmtHoyg6rxTb/vjeZx6eyIhSIxAI
tP/8/6qk1TTTfYFOIJgtd2ebn5q876lc7bVG7qu7zJydYWi8Ha2msUyDas9P
Lz97kATdlA9uJdmueM2ofdh6NxVeKprTcKQXBI9lmgcp2bh2+Jso78WvsFom
9Z3xyIedY2S0f5wfKhctR1w12bjjwm6xsA3EAoPD//COhyqqSurxJgS19ID7
e+7woXT+csqDEoZFgWT6aVopWLPNwhHdcPTk2yf7U8rRozwXGzccgY1QX3Fo
gwA9xH922XCi0FEQcGbpEyHMziuGgy9FwwGN1j9nVWJRWdEktIjBA7uYp8db
RNhPZnXaaMYifYO7fXNeDOJeoXBzKg6/hsz0qG9XIdJyiDMuTsBRyvqh0b+q
oWu0a4RHS0Jr8TjftEuCew5db21Mvoez/ZnyhStSJARsmRTtTsazqZ1Gzw1l
IJ0YUGR8TMZlE+X7IakMTNkxP+ZvV3Axks7R3yGHujZJ23TgB/g2xfdbMeTw
2lsyPPyQiXBV3zFjlhzMX6o/GrGvojOYXN58W47BIrKTQUoKfEzVGKQ6OSZn
fNmG/qkAK89hoEYOYyphbtDtGkhl2647cuRwdKY92meXBrKWwrzCWw79We38
WL10DC7dSO3VkcOIFxGXpJaB9gFReudjGSZ6voi4PpOBlfCg2j+DZchs63ty
oCMTbQOBiVnvpfCq6z+R+uN1PMr1W19Lk2L0ZFj9KDcLTywvKxy3JTg3TTdb
oWdjm3jkqGWSBFlLFUlZ9dn4/aKS4PKyGvcmm1ZGTXJA7NBo5/hWY7ZPRCgU
5KCLEdTv1lAFDbVegRMxF1RPneMv9lXB3qG5wT0zFzdi3EOt48UI8U5QN1/N
xditN9WHukUIrUua2AzPA71+vs/ZQgSmNpVuM5GHSccWngGzEt+1uB6M98xH
xmmr8YwRIXzw6dnk1nyQ1/XqS2yE8Oxt+XuIUgCtipyzduwKWIolpM9vFoC1
/K3BizkBSLEuA/OGLIS12l4inxZgdX9jYzKfhaz457NmknIoSAlWm5ssXP1j
iyfWKEfBbpXpNLMQjnFvLfyiykD9uqHm2atC8F9vjPWPlGJLRKvTusDGkZoL
5JSTpWhuK1bpjbIx03HKsOlWCTwPWysOuHIQ3tWt8jEuwZqAS+C1cxBENZ+T
GfKR7W07tkbmoouirzNFKsY7ATWxQ87FGpG7HGhQhH8Bb+a9Xw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$351060#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687752`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwVxXk0GwYAB+CU4LWPVolVsaHopWnzhtSR9NcWpY7ZYphrVUfVnNOl1FF3
5ChxRCTkqPbpObp4jrJQ6tHn6DP2HjUzpmtHoyg6rxTb/vjeZx6eyIhSIxAI
tP/8/6qk1TTTfYFOIJgtd2ebn5q876lc7bVG7qu7zJydYWi8Ha2msUyDas9P
Lz97kATdlA9uJdmueM2ofdh6NxVeKprTcKQXBI9lmgcp2bh2+Jso78WvsFom
9Z3xyIedY2S0f5wfKhctR1w12bjjwm6xsA3EAoPD//COhyqqSurxJgS19ID7
e+7woXT+csqDEoZFgWT6aVopWLPNwhHdcPTk2yf7U8rRozwXGzccgY1QX3Fo
gwA9xH922XCi0FEQcGbpEyHMziuGgy9FwwGN1j9nVWJRWdEktIjBA7uYp8db
RNhPZnXaaMYifYO7fXNeDOJeoXBzKg6/hsz0qG9XIdJyiDMuTsBRyvqh0b+q
oWu0a4RHS0Jr8TjftEuCew5db21Mvoez/ZnyhStSJARsmRTtTsazqZ1Gzw1l
IJ0YUGR8TMZlE+X7IakMTNkxP+ZvV3Axks7R3yGHujZJ23TgB/g2xfdbMeTw
2lsyPPyQiXBV3zFjlhzMX6o/GrGvojOYXN58W47BIrKTQUoKfEzVGKQ6OSZn
fNmG/qkAK89hoEYOYyphbtDtGkhl2647cuRwdKY92meXBrKWwrzCWw79We38
WL10DC7dSO3VkcOIFxGXpJaB9gFReudjGSZ6voi4PpOBlfCg2j+DZchs63ty
oCMTbQOBiVnvpfCq6z+R+uN1PMr1W19Lk2L0ZFj9KDcLTywvKxy3JTg3TTdb
oWdjm3jkqGWSBFlLFUlZ9dn4/aKS4PKyGvcmm1ZGTXJA7NBo5/hWY7ZPRCgU
5KCLEdTv1lAFDbVegRMxF1RPneMv9lXB3qG5wT0zFzdi3EOt48UI8U5QN1/N
xditN9WHukUIrUua2AzPA71+vs/ZQgSmNpVuM5GHSccWngGzEt+1uB6M98xH
xmmr8YwRIXzw6dnk1nyQ1/XqS2yE8Oxt+XuIUgCtipyzduwKWIolpM9vFoC1
/K3BizkBSLEuA/OGLIS12l4inxZgdX9jYzKfhaz457NmknIoSAlWm5ssXP1j
iyfWKEfBbpXpNLMQjnFvLfyiykD9uqHm2atC8F9vjPWPlGJLRKvTusDGkZoL
5JSTpWhuK1bpjbIx03HKsOlWCTwPWysOuHIQ3tWt8jEuwZqAS+C1cxBENZ+T
GfKR7W07tkbmoouirzNFKsY7ATWxQ87FGpG7HGhQhH8Bb+a9Xw==
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$351060#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{0., 0.013}, {0., 0.030933682923687752`}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "0.013`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{0., 0.013}}, {
   5, 3, 0, {25}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
   0.0005416666666666666, 0.0010833333333333333`, 0.001625, 
   0.0021666666666666666`, 0.0027083333333333334`, 0.00325, 
   0.0037916666666666667`, 0.004333333333333333, 0.004875, 
   0.005416666666666667, 0.005958333333333334, 0.0065, 0.0070416666666666666`,
    0.0075833333333333326`, 0.008125, 0.008666666666666666, 
   0.009208333333333332, 0.00975, 0.010291666666666666`, 
   0.010833333333333334`, 0.011375, 0.011916666666666666`, 
   0.012458333333333332`, 0.013}}, {{0.}, {0.004980807111936509}, {
   0.009810238162392298}, {0.014346227217215901`}, {0.018464393153341013`}, {
   0.022064704980054188`}, {0.025075932164168424`}, {0.02745766837337204}, {
   0.02919997712232828}, {0.030320906486767236`}, {0.03086226877234603}, {
   0.030884202131749795`}, {0.03045909369943538}, {0.02966545644149213}, {
   0.028582684007914066`}, {0.027286003909747704`}, {0.02584374798800854}, {
   0.024315097005136864`}, {0.022749291817872132`}, {0.02118570216276538}, {
   0.019654527865652402`}, {0.01817787617956351}, {0.016771007101224984`}, {
   0.015443590647925326`}, {0.0142008802442115}}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.662262660945747*^9, 3.6623277481278048`*^9, 
  3.662331045843033*^9, 3.662337660257972*^9, 3.662623148630116*^9, 
  3.662623246456143*^9, 3.662627027437167*^9, 3.7992125697648478`*^9, 
  3.7992128725071907`*^9},
 CellLabel->
  "Out[196]=",ExpressionUUID->"6a07898e-3759-49b0-ba74-7e7ed36a592c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"coupling2", "[", "AODL", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"-", "2"}], "*", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", "z", "]"}], "-", 
         RowBox[{
          RowBox[{"fzi", "[", "AODL", "]"}], "[", 
          RowBox[{"z", "+", "0.030"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"zmax", "[", "AODL", "]"}], ",", "2"}], "}"}]}], "]"}], 
      "]"}], ",", 
     RowBox[{"z", "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.479660163969679*^9, 3.479660203608347*^9}, {
   3.479660334457396*^9, 3.479660335305067*^9}, {3.4796611591764927`*^9, 
   3.479661208701754*^9}, {3.479661250977075*^9, 3.479661305176928*^9}, {
   3.479661346153286*^9, 3.479661372928776*^9}, {3.479661851029785*^9, 
   3.479661859051705*^9}, 3.4796619463263597`*^9, 3.479662725037703*^9, 
   3.479665672610339*^9, {3.481940806550991*^9, 3.48194080744361*^9}, {
   3.630208325888165*^9, 3.6302083289679956`*^9}, {3.630210610460196*^9, 
   3.630210610874337*^9}, 3.6611229758725023`*^9, {3.6611412583941383`*^9, 
   3.6611412584082737`*^9}, {3.661141309779232*^9, 3.661141309788487*^9}, {
   3.661143055996151*^9, 3.661143061547195*^9}, {3.661143129145129*^9, 
   3.661143150309849*^9}, {3.661231154888709*^9, 3.661231159334008*^9}, 
   3.66123140853971*^9, {3.6612315267918673`*^9, 3.661231532575729*^9}, 
   3.662253434225093*^9, 3.662256174883844*^9, 3.662256454447321*^9, {
   3.6622576485489264`*^9, 3.6622576543643312`*^9}, {3.662259663815483*^9, 
   3.662259674101316*^9}, 3.662259713425989*^9, {3.662260002840063*^9, 
   3.662260003422638*^9}, {3.662623135362105*^9, 3.662623139152598*^9}, {
   3.662623226987445*^9, 3.662623229834898*^9}, {3.6626238917931423`*^9, 
   3.662623924815764*^9}, 3.662846392788566*^9, 3.799212531152573*^9, 
   3.7992244344427013`*^9},
 CellLabel->
  "In[240]:=",ExpressionUUID->"47b08cef-d50b-43a2-939c-7ef319780418"],

Cell[BoxData["2843.625520379842`"], "Output",
 CellChangeTimes->{
  3.66123150538653*^9, 3.661231825570121*^9, 3.6622460074271603`*^9, 
   3.662246641563151*^9, 3.662255639636259*^9, 3.662256210598072*^9, 
   3.662256513985942*^9, {3.6622576493391542`*^9, 3.662257655351861*^9}, {
   3.6622596695441027`*^9, 3.662259674651012*^9}, 3.662259714075639*^9, 
   3.662260004808572*^9, 3.6623277733809*^9, 3.662331069205131*^9, 
   3.66233768452456*^9, 3.662623148874446*^9, 3.662623251072831*^9, 
   3.662627027471949*^9, 3.66284639360896*^9, 3.799212569794455*^9, 
   3.7992128725817823`*^9, 3.799224546890793*^9},
 CellLabel->
  "Out[240]=",ExpressionUUID->"c7e0f34d-306a-40c3-b53b-58bb4b4aa071"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax", "[", "AODL", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"coupling", "[", "AODL", "]"}], ",", 
      RowBox[{"zmax2", "[", "AODL", "]"}], ",", 
      RowBox[{"fmax2", "[", "AODL", "]"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.662623496752969*^9, 
  3.66262350152312*^9}, {3.799212531153256*^9, 3.799212531153904*^9}},
 CellLabel->
  "In[230]:=",ExpressionUUID->"3f0f2b2a-e80e-44a7-9ea0-2218c7848732"],

Cell[BoxData[
 TagBox[GridBox[{
    {"2843.625520379842`", "0.005342368876734437`", "0.01577331278972314`"},
    {"2843.625520379842`", "0.005750794119386763`", "0.030257769468565232`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.4815677247383738`*^9, 3.48156775513408*^9, 
  3.662627027501245*^9, 3.662846404962121*^9, 3.799212569833867*^9, 
  3.799212872590466*^9, 3.799223694543845*^9},
 CellLabel->
  "Out[230]//TableForm=",ExpressionUUID->"4f9f1298-c893-48c9-b2ce-\
93422e88ec5e"]
}, Open  ]]
}, Open  ]],

Cell["\<\
Summary
\
\>", "Section",
 CellChangeTimes->{{3.799216876183823*^9, 
  3.799216878453554*^9}},ExpressionUUID->"2a1553c3-fbc1-49a8-a5b4-\
16e3cd7262a5"],

Cell["Numbers for Table 2 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 
  3.799216716843322*^9}},ExpressionUUID->"542471c3-8166-4b61-b583-\
dbe9e3bb3f72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"BO5", ",", "BO10", ",", "BM5", ",", " ", "BM"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
  3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
  3.481941481456056*^9}, {3.7992219237632113`*^9, 3.7992219303911877`*^9}},
 CellLabel->
  "In[222]:=",ExpressionUUID->"70244e5a-db23-4530-91b2-e1ac2c7ed63c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Join", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "\"\<\>\"", "}"}], "~", "Join", "~", "cases"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Config\>\"", ",", "\"\<fmax [N/A]\>\"", ",", 
           "\"\<zmax [mm]\>\"", ",", "\"\<zmaxq [mm]\>\"", ",", 
           "\"\<delta [mm]\>\"", ",", "\"\<coupling [N/A/mm]\>\""}], "}"}], 
         "}"}], "\[IndentingNewLine]", "~", "Join", "~", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fmax", "[", 
             RowBox[{"cases2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
            RowBox[{"fmax", "[", 
             RowBox[{"cases2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
            RowBox[{"1000", "*", 
             RowBox[{"zmax", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{"1000", "*", 
             RowBox[{"zmaxq", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{"1000", " ", 
             RowBox[{"delta", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"coupling", "[", 
              RowBox[{"cases2", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", "1000"}]}], "}"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "cases2", "]"}]}], "}"}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}], "/.", 
    RowBox[{
     RowBox[{"zmaxq", "[", "_", "]"}], "\[Rule]", "0"}]}], "/.", 
   RowBox[{
    RowBox[{"delta", "[", "_", "]"}], "\[Rule]", "0"}]}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
   3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
   3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
   3.481942240350567*^9, 3.481942242583256*^9}, {3.6626233925731487`*^9, 
   3.662623394158786*^9}, 3.799212531147224*^9, {3.799217054153356*^9, 
   3.799217058198593*^9}, {3.799217090370521*^9, 3.799217110391349*^9}, {
   3.799217193532177*^9, 3.799217248736793*^9}, {3.799217300662807*^9, 
   3.799217347795745*^9}, {3.799217377925261*^9, 3.7992174636554747`*^9}, {
   3.7992174945367937`*^9, 3.799217515461955*^9}, {3.799217596916654*^9, 
   3.799217632144773*^9}, {3.799221933928629*^9, 3.799221945442816*^9}},
 CellLabel->
  "In[223]:=",ExpressionUUID->"6c8b20fb-1f3d-48d4-b5b6-68c0bbfa6224"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "BO5", "BO10", "BM5", "BM"},
    {"\<\"Config\"\>", "0.9628352953498257`", "1.694858202857608`", 
     "0.6371543615438662`", "1.084332204665714`"},
    {"\<\"fmax [N/A]\"\>", "0.9628352953498257`", "1.694858202857608`", 
     "0.6371543615438662`", "1.084332204665714`"},
    {"\<\"zmax [mm]\"\>", "6.180957231200814`", "7.195850469335957`", 
     "5.090030272462407`", "6.361536563952735`"},
    {"\<\"zmaxq [mm]\"\>", "6.14113232879264`", "7.352611334002004`", "0", 
     "0"},
    {"\<\"delta [mm]\"\>", 
     RowBox[{"-", "0.03982490240817416`"}], "0.15676086466604766`", "0", 
     "0"},
    {"\<\"coupling [N/A/mm]\"\>", "43.7045752793726`", "194.6789729432676`", 
     "38.79446860742498`", "73.71245272737802`"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.799217249329832*^9, 3.79921734838474*^9, 3.799217379473974*^9, {
   3.7992174421885967`*^9, 3.799217464862462*^9}, {3.799217496428701*^9, 
   3.799217515838039*^9}, 3.799217633630611*^9, {3.799221948391423*^9, 
   3.799221961501369*^9}},
 CellLabel->
  "Out[223]//TableForm=",ExpressionUUID->"e164e125-6fa5-4160-85d6-\
d7492f82cce5"]
}, Open  ]],

Cell["Numbers for Table 3 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 3.799216716843322*^9}, 
   3.799216938051504*^9},ExpressionUUID->"41a35b4a-1db5-4578-9c3e-\
c053b6900733"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cases3", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"AO", ",", "AODL", ",", "AOES", ",", " ", "BOTT"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.479668457935833*^9, 3.479668481450539*^9}, {
   3.479668587715115*^9, 3.4796685878908243`*^9}, {3.4819414768722143`*^9, 
   3.481941481456056*^9}, {3.7992219237632113`*^9, 3.7992219303911877`*^9}, 
   3.799222013357449*^9, {3.7992224823127317`*^9, 3.799222482598113*^9}, 
   3.7992226400708027`*^9},
 CellLabel->
  "In[228]:=",ExpressionUUID->"d6aa081b-fe2b-411e-92f9-931ec6ac2f96"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"1000", " ", "l"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "a"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coillen"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coilrad1"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"1000", " ", "coilrad2"}], "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"mz", "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"coilsigma", "/.", 
           RowBox[{"vals", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"fmax", "[", 
           RowBox[{"cases3", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"1000", "*", 
           RowBox[{"zmax", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"coupling", "[", 
            RowBox[{"cases3", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], "/", "1000"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "cases3", "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}], "/.", 
     RowBox[{
      RowBox[{"zmaxq", "[", "_", "]"}], "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"delta", "[", "_", "]"}], "\[Rule]", "0"}]}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<l [mm]\>\"", ",", "\"\<a [mm]\>\"", ",", "\"\<coillen [mm]\>\"", 
        ",", "\"\<coilrad1 [mm]\>\"", ",", "\"\<coilturns\>\"", ",", 
        "\"\<mz\>\"", ",", "\"\<coilsigma\>\"", ",", "\"\<fmax [N/A]\>\"", 
        ",", "\"\<zmax [mm]\>\"", ",", "\"\<coupling [N/A/mm]\>\""}], "}"}], 
      ",", "cases3"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.479668483217331*^9, 3.479668563563539*^9}, {
   3.4796686215578623`*^9, 3.479668666780747*^9}, {3.479668701726816*^9, 
   3.479668747295388*^9}, {3.481942141220706*^9, 3.481942165968225*^9}, {
   3.481942240350567*^9, 3.481942242583256*^9}, {3.6626233925731487`*^9, 
   3.662623394158786*^9}, 3.799212531147224*^9, {3.799217054153356*^9, 
   3.799217058198593*^9}, {3.799217090370521*^9, 3.799217110391349*^9}, {
   3.799217193532177*^9, 3.799217248736793*^9}, {3.799217300662807*^9, 
   3.799217347795745*^9}, {3.799217377925261*^9, 3.7992174636554747`*^9}, {
   3.7992174945367937`*^9, 3.799217515461955*^9}, {3.799217596916654*^9, 
   3.799217632144773*^9}, {3.799221933928629*^9, 3.799221945442816*^9}, {
   3.7992220140494337`*^9, 3.799222048007722*^9}, {3.799222091962309*^9, 
   3.799222207358107*^9}, {3.799222279856093*^9, 3.7992224088460073`*^9}, {
   3.79922461871211*^9, 3.7992247896535797`*^9}, 3.799224820308196*^9, {
   3.799224863673407*^9, 
   3.799224883558642*^9}},ExpressionUUID->"c8d1f20a-e908-45fa-82e6-\
ba37973431dc"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["AO",
       HoldForm], 
      TagBox["AODL",
       HoldForm], 
      TagBox["AOES",
       HoldForm], 
      TagBox["BOTT",
       HoldForm]},
     {
      TagBox["\<\"l [mm]\"\>",
       HoldForm], "3.175`", "6.`", "0.5`", "10.`"},
     {
      TagBox["\<\"a [mm]\"\>",
       HoldForm], "0.9525`", "1.`", "1.`", "2.5`"},
     {
      TagBox["\<\"coillen [mm]\"\>",
       HoldForm], "5.257799999999999`", "5.257799999999999`", 
      "5.257799999999999`", "8.001`"},
     {
      TagBox["\<\"coilrad1 [mm]\"\>",
       HoldForm], "7.7216`", "7.7216`", "7.7216`", "8.889999999999999`"},
     {
      TagBox["\<\"coilturns\"\>",
       HoldForm], "12.649199999999999`", "12.649199999999999`", 
      "12.649199999999999`", "16.51`"},
     {
      TagBox["\<\"mz\"\>",
       HoldForm], "878020.9598010788`", "878020.9598010788`", 
      "878020.9598010788`", "878020.9598010788`"},
     {
      TagBox["\<\"coilsigma\"\>",
       HoldForm], "1.5439046765338914`*^7", "1.5439046765338914`*^7", 
      "1.5439046765338914`*^7", "1.312171936513185`*^7"},
     {
      TagBox["\<\"fmax [N/A]\"\>",
       HoldForm], "0.01577331278972314`", "0.01577331278972314`", 
      "0.002807824198073727`", "0.3925374169455943`"},
     {
      TagBox["\<\"zmax [mm]\"\>",
       HoldForm], "5.342368876734437`", "5.342368876734437`", 
      "5.198473408953153`", "7.59707468312686`"},
     {
      TagBox["\<\"coupling [N/A/mm]\"\>",
       HoldForm], "0.9193132929763831`", "1.7984757640815658`", 
      "0.1690060726375998`", "12.441390320159337`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "l [mm]", "a [mm]", "coillen [mm]", "coilrad1 [mm]", "coilturns", "mz", 
       "coilsigma", "fmax [N/A]", "zmax [mm]", 
       "coupling [N/A/mm]"}, {$CellContext`AO, $CellContext`AODL, \
$CellContext`AOES, $CellContext`BOTT}}]]]], "Output",
 CellChangeTimes->{
  3.7992247543780527`*^9, {3.799224796385661*^9, 3.799224820856853*^9}, 
   3.79922486422314*^9},
 CellLabel->
  "Out[245]//TableForm=",ExpressionUUID->"a4ab7996-7911-4518-8f24-\
691896d72572"]
}, Open  ]],

Cell["Numbers for Table 4 of Word document.", "Subsection",
 CellChangeTimes->{{3.799216693820692*^9, 3.799216716843322*^9}, {
  3.799225095119976*^9, 
  3.799225095438384*^9}},ExpressionUUID->"cc517d30-9eb6-4ae9-85bc-\
b20209ced5be"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax", "[", "BO10", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax", "[", "BO10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"coupling", "[", "BO10", "]"}], "/", "1000"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax2", "[", "BO10", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax2", "[", "BO10", "]"}]}], ",", 
        RowBox[{
         RowBox[{"coupling2", "[", "BO10", "]"}], "/", "1000"}]}], "}"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax", "[", "AODL", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax", "[", "AODL", "]"}]}], ",", 
        RowBox[{
         RowBox[{"coupling", "[", "AODL", "]"}], "/", "1000"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"fmax2", "[", "AODL", "]"}], ",", 
        RowBox[{"1000", " ", 
         RowBox[{"zmax2", "[", "AODL", "]"}]}], ",", 
        RowBox[{
         RowBox[{"coupling2", "[", "AODL", "]"}], "/", "1000"}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<fmax [N/A]\>\"", ",", "\"\<zmax [mm]\>\"", ",", 
        "\"\<coupling [N/A/mm]\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<BO10 single\>\"", ",", "\"\<BO10 pair\>\"", ",", 
        "\"\<AODL single\>\"", ",", "\"\<AODL pair\>\""}], "}"}]}], "}"}]}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.481567608225747*^9, 3.481567635059455*^9}, {
  3.4815676689801073`*^9, 3.481567724116664*^9}, {3.662623496752969*^9, 
  3.66262350152312*^9}, {3.799212531153256*^9, 3.799212531153904*^9}, {
  3.7992237926291847`*^9, 3.7992238500042467`*^9}, {3.7992240713157997`*^9, 
  3.799224115165062*^9}, {3.7992241851271*^9, 3.799224237489109*^9}, {
  3.7992243398690653`*^9, 3.799224365191326*^9}, {3.799224962286886*^9, 
  3.7992250603926992`*^9}, {3.7992252070834084`*^9, 3.7992252110646343`*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"d769e62a-9a58-4688-800b-67ebe350b93e"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"BO10 single\"\>",
       HoldForm], 
      TagBox["\<\"BO10 pair\"\>",
       HoldForm], 
      TagBox["\<\"AODL single\"\>",
       HoldForm], 
      TagBox["\<\"AODL pair\"\>",
       HoldForm]},
     {
      TagBox["\<\"fmax [N/A]\"\>",
       HoldForm], "1.694858202857608`", "1.6263677836045267`", 
      "0.01577331278972314`", "0.030257769468565232`"},
     {
      TagBox["\<\"zmax [mm]\"\>",
       HoldForm], "7.195850469335957`", "7.300967534849954`", 
      "5.342368876734437`", "5.750794119386763`"},
     {
      TagBox["\<\"coupling [N/A/mm]\"\>",
       HoldForm], "61.04963188023506`", "194.6789729432676`", 
      "1.7984757640815658`", "2.8436255203798417`"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{"fmax [N/A]", "zmax [mm]", "coupling [N/A/mm]"}, {
      "BO10 single", "BO10 pair", "AODL single", "AODL pair"}}]]]], "Output",
 CellChangeTimes->{
  3.4815677247383738`*^9, 3.48156775513408*^9, 3.662627027501245*^9, 
   3.662846404962121*^9, 3.799212569833867*^9, 3.799212872590466*^9, 
   3.799223694543845*^9, 3.799223850608693*^9, 3.799224115910757*^9, {
   3.799224209361107*^9, 3.79922423809077*^9}, 3.799224367504829*^9, {
   3.799224536473153*^9, 3.799224551760214*^9}, {3.799225028458828*^9, 
   3.799225061750265*^9}, 3.799225211941506*^9},
 CellLabel->
  "Out[249]//TableForm=",ExpressionUUID->"a32d0611-7a1e-4a19-85ee-\
3186f0a476f5"]
},
CellGrouping->Manual,
WindowSize->{1276, 996},
WindowMargins->{{-2013, Automatic}, {-87, Automatic}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (March 13, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"01c72458-c3b1-40a0-b780-1e977edfca24"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 244, 4, 77, "Title",ExpressionUUID->"3dfe1237-ce63-495a-9b65-ebf5ff37ac1c"],
Cell[CellGroupData[{
Cell[836, 30, 86, 0, 68, "Section",ExpressionUUID->"bb0d3673-5957-440e-805b-8cf3d0ee019a"],
Cell[925, 32, 821, 15, 101, "Text",ExpressionUUID->"639e0d4b-79f4-4554-935e-ec18c521377a"]
}, Open  ]],
Cell[1761, 50, 733, 15, 31, "Input",ExpressionUUID->"880f8f56-0e29-4ae5-b330-3294a7b28cc9"],
Cell[CellGroupData[{
Cell[2519, 69, 136, 3, 68, "Section",ExpressionUUID->"ae6c7bba-54b3-4d61-9f0a-2d04a3ee297b",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2680, 76, 89, 0, 35, "Subsection",ExpressionUUID->"c8619771-36ca-45a5-aa35-9b680d81934d"],
Cell[CellGroupData[{
Cell[2794, 80, 368, 9, 37, "Subsubsection",ExpressionUUID->"a0d974f5-90d7-4db0-ad7e-fd24e90e28de"],
Cell[3165, 91, 942, 20, 108, "Input",ExpressionUUID->"cdb3efd8-18de-4355-af3a-39095dd99e02"]
}, Open  ]]
}, Open  ]],
Cell[4134, 115, 112, 1, 31, "Input",ExpressionUUID->"5372f101-ca2f-49e6-9a12-063152ae5f8d"],
Cell[4249, 118, 158, 2, 31, "Input",ExpressionUUID->"c342b927-7087-4eee-8bf4-9e186f897796"],
Cell[CellGroupData[{
Cell[4432, 124, 99, 0, 35, "Subsection",ExpressionUUID->"9780a3d9-9540-4886-9697-f741c422a5fb"],
Cell[4534, 126, 228, 5, 31, "Input",ExpressionUUID->"cf85e739-cd86-4302-aacd-ac44fc545330"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4799, 136, 126, 0, 35, "Subsection",ExpressionUUID->"9adcfee4-a22e-4c6d-bdb2-90b11cf7b5de"],
Cell[CellGroupData[{
Cell[4950, 140, 109, 0, 24, "Subsubsection",ExpressionUUID->"ffc09f59-ca70-4cb8-affb-eabdf7057e11"],
Cell[5062, 142, 630, 17, 31, "Input",ExpressionUUID->"a8c3bb97-4087-4d53-8662-a22df462b79d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5729, 164, 226, 5, 24, "Subsubsection",ExpressionUUID->"506e45ed-ac8b-4ade-b72f-98885d921fd4"],
Cell[5958, 171, 200, 5, 48, "Input",ExpressionUUID->"6e6dff58-ddc2-4d85-a678-de8a16047112"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6195, 181, 155, 2, 24, "Subsubsection",ExpressionUUID->"6638e03a-c5f4-4afd-9d19-0630b8b3b919"],
Cell[6353, 185, 244, 6, 48, "Input",ExpressionUUID->"c7541543-1c68-47d5-98c0-53e6f0bec293"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6646, 197, 120, 0, 35, "Subsection",ExpressionUUID->"678e8115-2bb6-4ba0-aeb9-afed12599c78"],
Cell[CellGroupData[{
Cell[6791, 201, 229, 14, 182, "Input",ExpressionUUID->"d534ff9f-4118-48a0-8862-c08ac405a88b"],
Cell[7023, 217, 1169, 27, 70, "Output",ExpressionUUID->"a546e7a1-354c-4c1d-8dff-5a3a4173ee4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8229, 249, 163, 3, 28, "Input",ExpressionUUID->"2456c139-a623-4985-af3d-765900d42720"],
Cell[8395, 254, 873, 17, 70, "Output",ExpressionUUID->"e0643c83-0574-4326-a41e-fe004fa5f899"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9305, 276, 234, 13, 168, "Input",ExpressionUUID->"fa895aba-bd45-47e1-b999-8f3ea924fac8"],
Cell[9542, 291, 1145, 26, 70, "Output",ExpressionUUID->"6575c2e5-eac8-43ab-a708-9ca05252588b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10724, 322, 192, 4, 28, "Input",ExpressionUUID->"657f57ee-cbd8-4b4b-ad07-337e3f815d14"],
Cell[10919, 328, 814, 14, 70, "Output",ExpressionUUID->"aa833aa4-f5cd-4b6a-8244-7a8bc24bcf84"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11770, 347, 491, 14, 29, "Input",ExpressionUUID->"b11f8f4d-4fab-4c28-89c0-ba9ed0b4562c"],
Cell[12264, 363, 708, 10, 70, "Output",ExpressionUUID->"3fd1c375-a2f8-40fe-8422-1c2abd48981d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[13021, 379, 141, 3, 27, "Subsection",ExpressionUUID->"edcb98b6-a535-42a2-abc3-024a620de9bf",
 Evaluatable->False],
Cell[13165, 384, 966, 25, 294, "Input",ExpressionUUID->"19e1338f-4a6c-44a8-827f-3217503d699e"],
Cell[14134, 411, 288, 9, 112, "Input",ExpressionUUID->"fdca09ed-d11f-4dbe-b709-0ac511c38634"],
Cell[14425, 422, 770, 22, 280, "Input",ExpressionUUID->"84d4f767-3885-464a-9226-6977164a18a0"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15256, 451, 267, 6, 68, "Section",ExpressionUUID->"2ae1367f-56e4-4279-9cb4-f02578c0d682"],
Cell[CellGroupData[{
Cell[15548, 461, 1806, 45, 677, "Input",ExpressionUUID->"1a638f07-39e3-4615-8baa-7d495e3444de"],
Cell[17357, 508, 2973, 55, 115, "Output",ExpressionUUID->"5386e0a7-1ebd-4793-a0c7-7236984b3e99"]
}, Open  ]],
Cell[20345, 566, 271, 6, 31, "Input",ExpressionUUID->"902df673-dd1f-4fb6-888a-fc33cf3e4da3"],
Cell[CellGroupData[{
Cell[20641, 576, 1084, 25, 108, "Input",ExpressionUUID->"445ff0c9-759b-41bc-bd85-1effc873d84c"],
Cell[21728, 603, 357, 9, 31, "Output",ExpressionUUID->"6d1925a7-604a-45c8-800f-4aa685dd4f1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22122, 617, 6620, 117, 174, "Input",ExpressionUUID->"449b716a-aa12-4cf6-bd1e-313b91961256"],
Cell[28745, 736, 5736, 100, 241, "Output",ExpressionUUID->"6504973f-740a-497e-939a-33d9fe3414ce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34518, 841, 579, 11, 31, "Input",ExpressionUUID->"95d58a8b-5990-4a03-a515-fea0840c57ce"],
Cell[35100, 854, 547, 7, 31, "Output",ExpressionUUID->"d408aa6e-a1d7-490e-a50f-f77a6ca70692"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35684, 866, 573, 11, 31, "Input",ExpressionUUID->"58b82fc2-4281-4e19-9c58-3ceab85f654e"],
Cell[36260, 879, 538, 7, 31, "Output",ExpressionUUID->"9cfc5246-ad41-4075-b5ad-739920d17fca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36835, 891, 1268, 22, 31, "Input",ExpressionUUID->"34545ddd-03f8-4d06-b2de-379474b8d110"],
Cell[38106, 915, 14374, 287, 60, "Output",ExpressionUUID->"aa11c5d6-ed7e-4c3f-a1cd-e1e98b418733"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52517, 1207, 1834, 34, 31, "Input",ExpressionUUID->"64ff4a14-8871-4129-af87-06c0713c3594"],
Cell[54354, 1243, 641, 9, 31, "Output",ExpressionUUID->"729fa1cb-4dc7-412b-9d1a-9f8033cc360c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55032, 1257, 247, 5, 31, "Input",ExpressionUUID->"f8cf4648-752b-474a-bc39-f37770b6d3f7"],
Cell[55282, 1264, 588, 9, 31, "Output",ExpressionUUID->"7afe43e2-5771-4469-8039-4ea07690504f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55907, 1278, 459, 10, 31, "Input",ExpressionUUID->"53a96b9e-449f-4ee8-9791-f3779fc8cb23"],
Cell[56369, 1290, 549, 9, 31, "Output",ExpressionUUID->"39a19b81-a568-4701-b287-897ead9cf996"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56955, 1304, 321, 6, 31, "Input",ExpressionUUID->"401ce758-5327-4811-82da-38866b3dedee"],
Cell[57279, 1312, 516, 9, 31, "Output",ExpressionUUID->"8d6f0369-14f4-4ace-b01d-7b2ffebd0420"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57832, 1326, 219, 3, 26, "Text",ExpressionUUID->"36002a4d-5c80-4599-85a4-f80a15a9331b"],
Cell[CellGroupData[{
Cell[58076, 1333, 6511, 119, 167, "Input",ExpressionUUID->"a754fc22-647b-40ae-bb7f-9655f6a4fb9d"],
Cell[64590, 1454, 6036, 104, 228, "Output",ExpressionUUID->"1c19801b-367e-4ef6-af2c-4d69b24807e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70663, 1563, 385, 10, 99, "Input",ExpressionUUID->"beec4926-b1cd-4634-9cc5-b505164c56d2"],
Cell[71051, 1575, 574, 12, 31, "Output",ExpressionUUID->"01a104a6-a657-4083-9772-f6541425b5ad"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[71686, 1594, 219, 4, 68, "Section",ExpressionUUID->"c37bd691-811c-4570-8675-b60bafa8e5bf"],
Cell[CellGroupData[{
Cell[71930, 1602, 1796, 42, 490, "Input",ExpressionUUID->"b4827e9a-2581-400c-b635-ff1b6db624ad"],
Cell[73729, 1646, 3310, 60, 70, "Output",ExpressionUUID->"cb6a9749-82fc-4f74-ab06-d655d575921e"]
}, Open  ]],
Cell[77054, 1709, 362, 8, 28, "Input",ExpressionUUID->"75fa72e5-f61a-4b00-87b8-d570a6556952"],
Cell[CellGroupData[{
Cell[77441, 1721, 295, 6, 28, "Input",ExpressionUUID->"20077e92-d012-4e5b-862a-5fbaddf3cbfd"],
Cell[77739, 1729, 697, 11, 70, "Output",ExpressionUUID->"bf6d7f1b-1252-4b2f-801f-6cde150ce3a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78473, 1745, 459, 10, 29, "Input",ExpressionUUID->"bc336c19-1cb1-43a6-baa9-f8f5c9d85fcc"],
Cell[78935, 1757, 600, 9, 70, "Output",ExpressionUUID->"0e842272-5dc1-420d-bd05-272be06af2a8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79572, 1771, 393, 7, 29, "Input",ExpressionUUID->"27952e17-6cd1-4d1f-ac44-4d2f63fd648a"],
Cell[79968, 1780, 565, 10, 70, "Output",ExpressionUUID->"4c854889-9107-441a-9f71-9121aefb489f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80570, 1795, 330, 7, 29, "Input",ExpressionUUID->"3a518087-6cae-40e0-983d-81d102009411"],
Cell[80903, 1804, 591, 10, 70, "Output",ExpressionUUID->"6d37aa67-702e-4613-93dc-9853b906c8c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81531, 1819, 330, 7, 29, "Input",ExpressionUUID->"11708426-b2bc-4205-9106-debb6efe02c5"],
Cell[81864, 1828, 598, 10, 70, "Output",ExpressionUUID->"ae69c8ec-c2af-460d-9441-5c86e45adc5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82499, 1843, 178, 3, 26, "Text",ExpressionUUID->"18b6656e-f25d-4227-9736-711dee46383f"],
Cell[CellGroupData[{
Cell[82702, 1850, 469, 11, 29, "Input",ExpressionUUID->"7f8d5b99-3877-44ef-993a-cb12d9cd2d89"],
Cell[83174, 1863, 10891, 197, 70, "Output",ExpressionUUID->"7626922c-2496-4172-b8d6-f659257e0b6c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94102, 2065, 491, 10, 29, "Input",ExpressionUUID->"25973c72-5333-4fd9-80f7-7ac37d6298d6"],
Cell[94596, 2077, 7365, 139, 70, "Output",ExpressionUUID->"7abb0e15-e7ba-49d9-b514-18c04ab1480e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101998, 2221, 780, 16, 29, "Input",ExpressionUUID->"f0fefd8d-0148-4c32-af44-6cb5456687f0"],
Cell[102781, 2239, 828, 16, 70, "Output",ExpressionUUID->"157a085a-46d3-48b4-ade7-1bc852e6338f"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[103670, 2262, 402, 9, 25, "Input",ExpressionUUID->"313eb942-123a-45f1-b00f-bd8283f90fa0"],
Cell[104075, 2273, 389, 5, 31, "Output",ExpressionUUID->"dc67efc3-9b3a-4105-963b-c42af8a2b2ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104501, 2283, 395, 9, 31, "Input",ExpressionUUID->"2f158e54-941f-4e8f-ab4b-59c160c12ea7"],
Cell[104899, 2294, 332, 4, 31, "Output",ExpressionUUID->"427d4820-a750-423c-9260-e3e4bc4e6467"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105268, 2303, 284, 4, 68, "Section",ExpressionUUID->"ec1821fe-d639-4dd4-9f6a-4568230a7630"],
Cell[CellGroupData[{
Cell[105577, 2311, 2350, 53, 711, "Input",ExpressionUUID->"56560bf5-235e-4f9a-a92f-cf475feab4d5"],
Cell[107930, 2366, 3124, 58, 133, "Output",ExpressionUUID->"304ae8a5-8e5a-481c-847e-25accad7d06e"]
}, Open  ]],
Cell[111069, 2427, 410, 8, 31, "Input",ExpressionUUID->"7e81a715-9ca1-4856-9954-33ef64603726"],
Cell[CellGroupData[{
Cell[111504, 2439, 1106, 25, 108, "Input",ExpressionUUID->"4f67205c-9f43-4fbf-838f-c912f0c00cca"],
Cell[112613, 2466, 358, 9, 31, "Output",ExpressionUUID->"0c891c29-a662-4c57-ad4e-487ba55304d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113008, 2480, 6831, 121, 167, "Input",ExpressionUUID->"9fb2e2ba-9280-42e7-a100-e0021c15e7da"],
Cell[119842, 2603, 5902, 103, 235, "Output",ExpressionUUID->"ee657b72-238b-4d6a-a980-ca20c754deaa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125781, 2711, 574, 11, 31, "Input",ExpressionUUID->"32643f23-3336-44ca-99ec-f76e90a3f4e3"],
Cell[126358, 2724, 516, 7, 31, "Output",ExpressionUUID->"63f94bab-0141-4637-8a06-3921c4510957"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126911, 2736, 573, 11, 31, "Input",ExpressionUUID->"1b78dee0-4370-4b8b-84b3-39acbd94d674"],
Cell[127487, 2749, 520, 7, 31, "Output",ExpressionUUID->"f437289e-8009-445f-847d-3157db9da92f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128044, 2761, 1314, 22, 31, "Input",ExpressionUUID->"91096579-c078-45df-9be3-2862295967db"],
Cell[129361, 2785, 14195, 279, 60, "Output",ExpressionUUID->"67ca01b3-485d-4dfc-b14f-7aacc732ea1a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143593, 3069, 1888, 35, 31, "Input",ExpressionUUID->"bc47da5d-ca01-4d8c-8301-7c1274c233c7"],
Cell[145484, 3106, 641, 9, 31, "Output",ExpressionUUID->"9fbb59bc-89b2-452c-8040-a9df27012f00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146162, 3120, 1456, 23, 89, "Input",ExpressionUUID->"f177b1a4-497f-4cd3-a2b6-4e2abe2cce05"],
Cell[147621, 3145, 6076, 107, 233, "Output",ExpressionUUID->"c07c4d54-6518-48ed-ab6d-e551f6bb39f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153734, 3257, 325, 6, 31, "Input",ExpressionUUID->"d9a8c6be-6da5-4103-bcc6-df8f9e62e8bc"],
Cell[154062, 3265, 652, 9, 31, "Output",ExpressionUUID->"e2d42dd6-b9ab-4a74-a4be-ac5c9e8e7968"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154751, 3279, 459, 10, 31, "Input",ExpressionUUID->"c841c6ca-eda9-4bed-9488-ff5a80345e79"],
Cell[155213, 3291, 554, 9, 31, "Output",ExpressionUUID->"62eaa40d-b5f0-41ff-9961-4d83aecc2430"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155804, 3305, 415, 7, 31, "Input",ExpressionUUID->"852f2c59-3560-4124-807e-a41c924f82e6"],
Cell[156222, 3314, 523, 9, 31, "Output",ExpressionUUID->"289ca90e-9214-4b3f-be45-d98c5cee5403"]
}, Open  ]],
Cell[CellGroupData[{
Cell[156782, 3328, 352, 7, 31, "Input",ExpressionUUID->"ee93f305-a43a-4d89-be9d-92f02104aeb3"],
Cell[157137, 3337, 540, 9, 31, "Output",ExpressionUUID->"4e769f50-e69c-41bd-a90b-5a5dd23ea91c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157714, 3351, 352, 7, 31, "Input",ExpressionUUID->"f54f6b89-9c65-45e5-b085-01740ff4004d"],
Cell[158069, 3360, 546, 9, 31, "Output",ExpressionUUID->"28386815-fcb1-46ed-9f32-4a8c90c71d82"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158652, 3374, 178, 3, 26, "Text",ExpressionUUID->"548ecba9-2816-4f3d-b1ee-a36844dfb2ab"],
Cell[CellGroupData[{
Cell[158855, 3381, 491, 11, 31, "Input",ExpressionUUID->"854f4323-71fb-46f6-9e95-f9c32d166838"],
Cell[159349, 3394, 10886, 197, 231, "Output",ExpressionUUID->"a79b417b-4ae9-48a0-9378-df332c79371e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170272, 3596, 517, 11, 31, "Input",ExpressionUUID->"a531a3ec-79d9-4e67-a8a0-42db602ff2ca"],
Cell[170792, 3609, 7325, 139, 226, "Output",ExpressionUUID->"53d17c3d-53b9-4d57-a258-b67cbb51f84a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[178178, 3755, 829, 17, 31, "Input",ExpressionUUID->"da98ea8e-ec18-4fb9-bbee-2bc2c2834481"],
Cell[179010, 3774, 850, 16, 31, "Output",ExpressionUUID->"f4372525-8fc8-4149-8868-8efcf9a14d8e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179897, 3795, 450, 10, 31, "Input",ExpressionUUID->"d60bd202-0290-480e-b2e6-e79e6533ec6f"],
Cell[180350, 3807, 413, 5, 31, "Output",ExpressionUUID->"e1794821-e2e5-462f-882c-7b467238ae0c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[180800, 3817, 446, 10, 31, "Input",ExpressionUUID->"4c9c9ec2-9442-4edb-8b9c-33797d9b231d"],
Cell[181249, 3829, 362, 5, 31, "Output",ExpressionUUID->"b098591c-d6ec-4590-b479-d57786fcf1a4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181648, 3839, 345, 5, 68, "Section",ExpressionUUID->"82586c70-4af1-4da1-b79a-96177a9bd8e0"],
Cell[CellGroupData[{
Cell[182018, 3848, 2573, 56, 547, "Input",ExpressionUUID->"dfd7ef58-4e21-45e6-92c1-45dafe32170f"],
Cell[184594, 3906, 3059, 56, 70, "Output",ExpressionUUID->"67c648db-67fd-412e-a1eb-285cf30b1d35"]
}, Open  ]],
Cell[187668, 3965, 490, 9, 27, "Input",ExpressionUUID->"2d189b41-9222-4a58-8e19-ccb2814792be"],
Cell[CellGroupData[{
Cell[188183, 3978, 178, 3, 26, "Text",ExpressionUUID->"90754ed9-7f5e-430b-bf5c-44472a83d5ba"],
Cell[CellGroupData[{
Cell[188386, 3985, 514, 11, 27, "Input",ExpressionUUID->"b4d67e0f-c1af-4f6b-88d6-e95aa3eb5c9f"],
Cell[188903, 3998, 11174, 202, 70, "Output",ExpressionUUID->"2721820f-bf87-46cf-9728-8e451bf2bb88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200114, 4205, 540, 11, 27, "Input",ExpressionUUID->"e7191882-4686-421a-b6f1-453a24ea51af"],
Cell[200657, 4218, 7405, 140, 70, "Output",ExpressionUUID->"de8e7551-18c5-4eff-80af-5fc0878727ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208099, 4363, 657, 13, 27, "Input",ExpressionUUID->"8c873269-2f83-46ca-9455-031edfe1f7e4"],
Cell[208759, 4378, 751, 15, 70, "Output",ExpressionUUID->"9ba2ec87-6e41-4d53-a52a-f69734fbd372"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[209571, 4400, 262, 5, 25, "Input",ExpressionUUID->"ba4ea7a9-e82a-4e5e-9d30-94aeec41edf7"],
Cell[209836, 4407, 306, 4, 31, "Output",ExpressionUUID->"70cbdc9d-3c6a-46f8-943f-62cee9a734f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210179, 4416, 399, 6, 68, "Section",ExpressionUUID->"46df04c7-2007-4642-9b1f-9ec7b09d28cd"],
Cell[CellGroupData[{
Cell[210603, 4426, 2493, 55, 677, "Input",ExpressionUUID->"1409a6fd-6943-472f-9135-d85b2b6bf26a"],
Cell[213099, 4483, 2959, 54, 115, "Output",ExpressionUUID->"98686405-bdf8-4d40-ae2a-2b8e8743857c"]
}, Open  ]],
Cell[216073, 4540, 538, 10, 31, "Input",ExpressionUUID->"487e2fda-2a80-4287-b27d-746da4ecf6fe"],
Cell[CellGroupData[{
Cell[216636, 4554, 1183, 26, 108, "Input",ExpressionUUID->"8f7817b5-563b-4f5f-af31-f465c6488b7c"],
Cell[217822, 4582, 363, 9, 31, "Output",ExpressionUUID->"cd705f4c-34f1-422c-b2e2-ffd84cbafa14"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218222, 4596, 6740, 119, 168, "Input",ExpressionUUID->"e162c8e4-f5a2-40d6-858a-8d9f8094479b"],
Cell[224965, 4717, 5790, 101, 235, "Output",ExpressionUUID->"eac8dd1d-44e8-4e88-97ff-565b65903386"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230792, 4823, 575, 11, 31, "Input",ExpressionUUID->"429d9939-6034-4001-9360-c57125af8fcc"],
Cell[231370, 4836, 522, 7, 31, "Output",ExpressionUUID->"f4eac74b-5b00-45ea-a77a-67e44fd95c1c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231929, 4848, 571, 11, 31, "Input",ExpressionUUID->"5b4d0698-1f1e-4aaa-ad24-9ac9c6332d15"],
Cell[232503, 4861, 521, 7, 31, "Output",ExpressionUUID->"ceade777-9a82-4e20-8936-ede7ca420b75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233061, 4873, 1316, 22, 31, "Input",ExpressionUUID->"7f5887ee-98f1-42d5-b63c-2b9651d20454"],
Cell[234380, 4897, 14324, 281, 60, "Output",ExpressionUUID->"4369f629-eb1c-4744-9010-91b39cc1c9f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248741, 5183, 1884, 35, 31, "Input",ExpressionUUID->"4bf6b1ea-d75e-4ae1-b0e8-b869c889ad9f"],
Cell[250628, 5220, 639, 9, 31, "Output",ExpressionUUID->"469a9b71-257c-4a87-a055-6d5c839ca70f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251304, 5234, 790, 21, 31, "Input",ExpressionUUID->"f61de3d9-71a3-4818-af8b-1595bc09f16a"],
Cell[252097, 5257, 11396, 195, 235, "Output",ExpressionUUID->"743adc85-6d92-4f38-b227-9c4f226a5351"]
}, Open  ]],
Cell[CellGroupData[{
Cell[263530, 5457, 178, 3, 26, "Text",ExpressionUUID->"0049aa13-92b2-432b-b51a-22a4c957b0b5"],
Cell[CellGroupData[{
Cell[263733, 5464, 541, 12, 31, "Input",ExpressionUUID->"d87e340b-f959-45cb-b783-62f31ee81cd3"],
Cell[264277, 5478, 10906, 198, 231, "Output",ExpressionUUID->"f985c3c3-44b9-4602-8dae-f5db98d03a18"]
}, Open  ]],
Cell[CellGroupData[{
Cell[275220, 5681, 561, 11, 31, "Input",ExpressionUUID->"bf29ff74-3fde-4839-941c-f36d95b618c9"],
Cell[275784, 5694, 7399, 140, 226, "Output",ExpressionUUID->"f3b7b127-c6d3-4a9c-baeb-77dc63200808"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283220, 5839, 682, 14, 31, "Input",ExpressionUUID->"bc34bb23-ffa4-4c43-9f52-1efa7479be62"],
Cell[283905, 5855, 746, 15, 31, "Output",ExpressionUUID->"590f40bb-dbc9-4ed7-8038-cf209a141dfa"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[284712, 5877, 562, 10, 68, "Section",ExpressionUUID->"b7ab0cf5-cedb-47b9-b53a-ccf94e68fe80"],
Cell[CellGroupData[{
Cell[285299, 5891, 2617, 56, 677, "Input",ExpressionUUID->"b19586bb-2c7d-4055-af11-8df359e66e66"],
Cell[287919, 5949, 3023, 55, 115, "Output",ExpressionUUID->"caa8ba38-6532-4073-bbf8-1874a816c133"]
}, Open  ]],
Cell[290957, 6007, 594, 11, 31, "Input",ExpressionUUID->"c52d5242-bbcc-40db-a078-c25af1a1a30f"],
Cell[CellGroupData[{
Cell[291576, 6022, 1260, 27, 108, "Input",ExpressionUUID->"9d4f343d-a4ba-47fb-921e-e99e5a4ea1c0"],
Cell[292839, 6051, 475, 10, 31, "Output",ExpressionUUID->"1e3f206c-0c5c-47b9-ac24-4ec01a6f309e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293351, 6066, 6711, 118, 162, "Input",ExpressionUUID->"a06c1d25-0451-4c24-b8a2-00e990c77f60"],
Cell[300065, 6186, 5795, 100, 232, "Output",ExpressionUUID->"b634b4f9-2370-485b-a3d9-7e54bf4fa965"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305897, 6291, 628, 12, 31, "Input",ExpressionUUID->"ef704f4c-43be-4ad3-afed-5069b47c3194"],
Cell[306528, 6305, 586, 8, 31, "Output",ExpressionUUID->"ff937244-c362-4dfc-8d47-a3e9b178c008"]
}, Open  ]],
Cell[CellGroupData[{
Cell[307151, 6318, 627, 12, 31, "Input",ExpressionUUID->"d9119b47-bb99-4d17-b0c5-4e3ac9c41aa2"],
Cell[307781, 6332, 589, 8, 31, "Output",ExpressionUUID->"64b9a2fc-9d8f-4001-8180-a1c6db65feff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308407, 6345, 1320, 22, 31, "Input",ExpressionUUID->"17ec380f-903d-48ad-840f-942a66457bc7"],
Cell[309730, 6369, 14136, 281, 60, "Output",ExpressionUUID->"667c9523-fc6d-4825-b4d5-b50f99a7d67d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323903, 6655, 1893, 35, 31, "Input",ExpressionUUID->"71f8cc29-6a67-4f1f-8629-2e048d5742fa"],
Cell[325799, 6692, 639, 9, 31, "Output",ExpressionUUID->"33d7ba88-3285-4728-a753-27da43f4b72e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326475, 6706, 178, 3, 26, "Text",ExpressionUUID->"671e63b2-895c-417b-b8b0-1aa4e7ad2546"],
Cell[CellGroupData[{
Cell[326678, 6713, 564, 12, 31, "Input",ExpressionUUID->"f3feb58d-577f-4328-83e7-9422619e6a79"],
Cell[327245, 6727, 10956, 199, 232, "Output",ExpressionUUID->"8c48605e-afc9-497f-9703-68c0ae989b87"]
}, Open  ]],
Cell[CellGroupData[{
Cell[338238, 6931, 589, 12, 31, "Input",ExpressionUUID->"52d51435-012e-48ca-8a75-f644918ad052"],
Cell[338830, 6945, 7503, 141, 223, "Output",ExpressionUUID->"c56c0d50-a54c-4ad2-beea-248d07a556cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346370, 7091, 708, 14, 31, "Input",ExpressionUUID->"58668235-e7ab-469b-a144-2d91f6ec5bda"],
Cell[347081, 7107, 821, 16, 31, "Output",ExpressionUUID->"966b3c14-7399-4ff4-bc7e-86b6ece71158"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[347963, 7130, 699, 12, 68, "Section",ExpressionUUID->"ea161608-72ba-489b-84b2-a25ca58a24b6"],
Cell[CellGroupData[{
Cell[348687, 7146, 2615, 56, 677, "Input",ExpressionUUID->"833a7cc4-7698-419b-8138-47a32295faaf"],
Cell[351305, 7204, 3022, 55, 115, "Output",ExpressionUUID->"b44cffa4-79c9-4737-9b61-87bfd4fda41b"]
}, Open  ]],
Cell[354342, 7262, 640, 11, 31, "Input",ExpressionUUID->"be4e8432-0b2c-4c7b-8ead-9006ac266c55"],
Cell[CellGroupData[{
Cell[355007, 7277, 1287, 28, 108, "Input",ExpressionUUID->"ef0bc78a-c785-440d-86b2-44ebe6c8e09d"],
Cell[356297, 7307, 452, 10, 31, "Output",ExpressionUUID->"052ca5fc-976e-469a-b891-0999568533d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356786, 7322, 6850, 121, 168, "Input",ExpressionUUID->"7be5236c-19c8-4a9a-acc4-e94c22ff0d3d"],
Cell[363639, 7445, 5884, 102, 235, "Output",ExpressionUUID->"5760ab03-0f85-4f64-87a5-3baee8a9b031"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369560, 7552, 680, 13, 31, "Input",ExpressionUUID->"61afc4f0-c899-47cb-b3ea-0b99486537da"],
Cell[370243, 7567, 591, 8, 31, "Output",ExpressionUUID->"364cb738-c6ca-4ef0-9608-d3e3ad0953d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370871, 7580, 679, 13, 31, "Input",ExpressionUUID->"f1dc5dde-6f3b-400d-b913-88e2d8e5ff9a"],
Cell[371553, 7595, 589, 8, 31, "Output",ExpressionUUID->"4d6a443a-ddb2-4309-a909-763cd3e2088a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372179, 7608, 1318, 22, 31, "Input",ExpressionUUID->"440efa85-b8a4-4816-83fc-a299e3eb1262"],
Cell[373500, 7632, 14466, 283, 60, "Output",ExpressionUUID->"875c275c-bc96-4396-8f33-2984b4ac5ee3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388003, 7920, 1897, 36, 31, "Input",ExpressionUUID->"90692c4b-af96-47c0-bba3-84fe2d59ded3"],
Cell[389903, 7958, 674, 11, 31, "Output",ExpressionUUID->"6ecf317e-067d-40f6-be8f-3ad9b74435a8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390614, 7974, 178, 3, 26, "Text",ExpressionUUID->"ed069afb-65a9-4706-a035-58555d00a52a"],
Cell[CellGroupData[{
Cell[390817, 7981, 585, 12, 31, "Input",ExpressionUUID->"de04cda8-cce7-4f5f-8e4c-19e1df4a03ea"],
Cell[391405, 7995, 10974, 198, 231, "Output",ExpressionUUID->"eb76286c-2a2c-4ac0-92b2-80089a1b2861"]
}, Open  ]],
Cell[CellGroupData[{
Cell[402416, 8198, 615, 13, 31, "Input",ExpressionUUID->"c546244e-c6e7-4dcf-8f92-58c09faf7ac7"],
Cell[403034, 8213, 7406, 141, 226, "Output",ExpressionUUID->"36c10732-f114-4041-a2b1-f3f46539d2dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[410477, 8359, 736, 15, 31, "Input",ExpressionUUID->"82eafcc7-3e81-42cc-8856-b31f68018464"],
Cell[411216, 8376, 825, 17, 31, "Output",ExpressionUUID->"ff3e0a65-d4bb-4c7d-ad20-4c42d512a702"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[412102, 8400, 288, 6, 68, "Section",ExpressionUUID->"2813d2a2-de64-4046-a4e2-dd4ff7805916"],
Cell[CellGroupData[{
Cell[412415, 8410, 1870, 47, 677, "Input",ExpressionUUID->"377650f6-9d15-4e9d-b438-1fb4d43219f2"],
Cell[414288, 8459, 2940, 56, 115, "Output",ExpressionUUID->"10386a98-940d-4c3d-af8f-e110b3a5e7f0"]
}, Open  ]],
Cell[417243, 8518, 325, 8, 31, "Input",ExpressionUUID->"d7341d39-4812-48b4-ab2d-5d6ef0b56354"],
Cell[CellGroupData[{
Cell[417593, 8530, 1042, 25, 108, "Input",ExpressionUUID->"e34482ee-c873-4a58-8d7e-00471656aa43"],
Cell[418638, 8557, 361, 10, 31, "Output",ExpressionUUID->"3015b92f-6859-4781-8577-5a087fa64be3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419036, 8572, 6623, 119, 175, "Input",ExpressionUUID->"94469ae9-0aa1-4d7b-bde4-deec403b3e7a"],
Cell[425662, 8693, 5771, 102, 241, "Output",ExpressionUUID->"1982ac6b-55e5-44a0-be8a-07be84e5024f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431470, 8800, 535, 12, 31, "Input",ExpressionUUID->"cc740a61-a5f2-4a3e-95e3-83f535b4fb22"],
Cell[432008, 8814, 529, 8, 31, "Output",ExpressionUUID->"2efc3972-7e5a-43ca-8aef-9e8988aed0ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432574, 8827, 531, 12, 31, "Input",ExpressionUUID->"9a31230c-7433-4b9d-99bf-6abf92d55d95"],
Cell[433108, 8841, 526, 8, 31, "Output",ExpressionUUID->"e7b89250-bc75-4a42-afdc-404b4af80bc2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433671, 8854, 1320, 23, 31, "Input",ExpressionUUID->"ed33ce46-c711-4ecf-9625-01290b2a55e5"],
Cell[434994, 8879, 14465, 289, 60, "Output",ExpressionUUID->"0b071736-6c26-4725-aa48-eff36d06fcd4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449496, 9173, 1891, 36, 31, "Input",ExpressionUUID->"f6234f0a-64d6-4d54-b176-b040b7db139d"],
Cell[451390, 9211, 643, 10, 31, "Output",ExpressionUUID->"7899290b-2597-400e-a514-657a84cf9d95"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452070, 9226, 1439, 24, 89, "Input",ExpressionUUID->"837fae9f-d025-4dd0-a738-adfe2d58ee62"],
Cell[453512, 9252, 6497, 113, 239, "Output",ExpressionUUID->"050222f3-8f92-453a-9942-65e81a4c8d8e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[460058, 9371, 310, 5, 68, "Section",ExpressionUUID->"50028e12-664d-4797-b26a-9e356f598b23"],
Cell[460371, 9378, 2097, 49, 677, "Input",ExpressionUUID->"f15ccc8c-1273-46df-894d-99940b8f8b0a"],
Cell[462471, 9429, 447, 10, 31, "Input",ExpressionUUID->"65d4aeeb-a263-4296-9eb2-cfe938d46820"],
Cell[CellGroupData[{
Cell[462943, 9443, 990, 25, 108, "Input",ExpressionUUID->"9e29d255-97ef-4440-b21e-f182851efff1"],
Cell[463936, 9470, 358, 10, 31, "Output",ExpressionUUID->"5d50e20d-46ac-49b2-b8f2-279acf2ceb4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464331, 9485, 6566, 117, 173, "Input",ExpressionUUID->"86da488b-07c5-42ac-abad-116c78ad154d"],
Cell[470900, 9604, 5671, 100, 241, "Output",ExpressionUUID->"430f0cbf-a2cc-4140-98a3-14215d803a91"]
}, Open  ]],
Cell[CellGroupData[{
Cell[476608, 9709, 441, 10, 31, "Input",ExpressionUUID->"7fb93265-7e27-4cad-8673-f16f2172d585"],
Cell[477052, 9721, 480, 7, 31, "Output",ExpressionUUID->"b076b6fa-9009-40b1-86ff-eb9324cbb807"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477569, 9733, 435, 10, 31, "Input",ExpressionUUID->"4f528aab-fdf6-421c-af92-23b463b6b6bd"],
Cell[478007, 9745, 472, 7, 31, "Output",ExpressionUUID->"1fb76a46-0755-4c01-b6e0-5b04c9fd2838"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478516, 9757, 1322, 23, 31, "Input",ExpressionUUID->"3b437d79-499c-427c-93bd-703723471f2e"],
Cell[479841, 9782, 14345, 289, 60, "Output",ExpressionUUID->"ef1e1ede-6800-4e1a-9a8a-71f8ecc43416"]
}, Open  ]],
Cell[CellGroupData[{
Cell[494223, 10076, 1897, 36, 31, "Input",ExpressionUUID->"757f8d27-49aa-4b6a-bf4d-99a07057acb5"],
Cell[496123, 10114, 669, 11, 56, "Output",ExpressionUUID->"eee69ecc-f092-4802-8ee2-4af0e3c4de0f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[496829, 10130, 1174, 27, 31, "Input",ExpressionUUID->"4d8ac11c-2d99-4a2c-9304-7c7688c4bfc1"],
Cell[498006, 10159, 542, 8, 31, "Output",ExpressionUUID->"e19ad825-b69e-494f-98e7-7fde24afe947"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498585, 10172, 1172, 26, 31, "Input",ExpressionUUID->"bace1cb2-a4e2-4b19-8fa7-dd30a5449edf"],
Cell[499760, 10200, 531, 9, 31, "Output",ExpressionUUID->"e599eda5-e74c-47c2-a819-ffe781a1260c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500328, 10214, 162, 3, 24, "Subsubsection",ExpressionUUID->"17a3342e-9e8b-4795-a16a-47c460a7b7cb"],
Cell[CellGroupData[{
Cell[500515, 10221, 1953, 39, 165, "Input",ExpressionUUID->"bfa8b184-c367-4662-ac83-aa02c4a7b9f3"],
Cell[502471, 10262, 773, 15, 31, "Output",ExpressionUUID->"611b3ed1-16d2-40b3-bec1-42b6253522a2"]
}, Open  ]],
Cell[503259, 10280, 1347, 22, 146, "Input",ExpressionUUID->"385289ce-be9a-46d2-8000-5cd05c46f4d7"],
Cell[504609, 10304, 1506, 24, 127, "Input",ExpressionUUID->"85cc34c7-864e-4269-8e0f-16cbc322e570"],
Cell[506118, 10330, 602, 17, 31, "Input",ExpressionUUID->"137e75f8-6f4d-40fa-ad7e-bad45f9f505f"],
Cell[506723, 10349, 1516, 26, 165, "Input",ExpressionUUID->"08ac2375-fbe3-484d-8d93-994ce7d26d31"],
Cell[508242, 10377, 1569, 25, 165, "Input",ExpressionUUID->"fb52f218-0295-4138-aee9-078f0f6dbdfd"],
Cell[509814, 10404, 652, 17, 31, "Input",ExpressionUUID->"89f9ff9b-b7d8-44c6-a739-d7366d4e4c08"],
Cell[CellGroupData[{
Cell[510491, 10425, 1063, 21, 31, "Input",ExpressionUUID->"d71f22e6-3597-4777-981b-faefce5cd1af"],
Cell[511557, 10448, 2924, 63, 246, "Output",ExpressionUUID->"d529a869-07d0-4237-80da-69fd5964d65b"]
}, Open  ]],
Cell[514496, 10514, 1275, 29, 31, "Input",ExpressionUUID->"0e5bf6c5-df10-4466-adb0-1a4bb5380fbc"],
Cell[CellGroupData[{
Cell[515796, 10547, 319, 6, 31, "Input",ExpressionUUID->"aab122d0-9757-415d-acd6-ff7fa2ba159a"],
Cell[516118, 10555, 2634, 56, 234, "Output",ExpressionUUID->"d28d59cb-400d-4b2c-a6f0-a100311723a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[518789, 10616, 632, 15, 31, "Input",ExpressionUUID->"f79e74b4-094f-44cd-87ce-9907a0a87f23"],
Cell[519424, 10633, 808, 14, 32, "Output",ExpressionUUID->"e16912de-3840-4a6a-8871-1ea4d7f89b5d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[520269, 10652, 812, 18, 31, "Input",ExpressionUUID->"c769e96c-c61c-40a0-9e0c-b4f689616d07"],
Cell[521084, 10672, 8022, 147, 240, "Output",ExpressionUUID->"6bfbc409-c98b-4f68-a7b9-e9e5bccc1552"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[529155, 10825, 795, 20, 31, "Input",ExpressionUUID->"becee2b2-4d84-4484-9d32-defedfca584e"],
Cell[529953, 10847, 529, 8, 31, "Output",ExpressionUUID->"9e970f14-24d9-445f-b2b5-1926d5f51793"]
}, Open  ]],
Cell[CellGroupData[{
Cell[530519, 10860, 485, 10, 31, "Input",ExpressionUUID->"2b309981-7b7d-440a-b82c-8c01b1981b68"],
Cell[531007, 10872, 519, 8, 31, "Output",ExpressionUUID->"dbde4cfe-446c-4aed-aa60-97b4daa54dd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[531563, 10885, 564, 11, 31, "Input",ExpressionUUID->"7c49e19e-4363-4f73-8b6e-1a43e496b3ee"],
Cell[532130, 10898, 512, 8, 31, "Output",ExpressionUUID->"e3db57d7-d7d2-4a91-8c7d-e0c68706362b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532679, 10911, 220, 5, 26, "Text",ExpressionUUID->"33369bd6-4667-4e2d-9f02-e69a722930b7"],
Cell[CellGroupData[{
Cell[532924, 10920, 783, 14, 31, "Input",ExpressionUUID->"c7efb6f5-403c-4fe9-808d-5c2ffef498ea"],
Cell[533710, 10936, 749, 12, 31, "Output",ExpressionUUID->"52cb7017-bdc9-4774-8afd-53f1fe2f7613"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[534508, 10954, 2255, 45, 127, "Input",ExpressionUUID->"cf9944be-38ea-4989-849a-5e06ab1b9d29"],
Cell[536766, 11001, 13494, 231, 413, "Output",ExpressionUUID->"c9320f06-1d91-4968-ae91-117659f2bacf"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[550309, 11238, 305, 5, 68, "Section",ExpressionUUID->"3e8ab641-d0ac-4724-a259-68c331873309"],
Cell[550617, 11245, 2173, 50, 677, "Input",ExpressionUUID->"fd944fd5-79d6-47c7-8f61-db697a9b9078"],
Cell[552793, 11297, 491, 10, 31, "Input",ExpressionUUID->"8ab6d7d1-aec3-4982-9aeb-d4f7c5ad9135"],
Cell[CellGroupData[{
Cell[553309, 11311, 1166, 27, 108, "Input",ExpressionUUID->"f55e7bfe-ea93-4c0f-8155-1bd9f471e265"],
Cell[554478, 11340, 361, 10, 31, "Output",ExpressionUUID->"38c74d42-8094-4c19-aba1-206c72b9a2c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554876, 11355, 6437, 116, 173, "Input",ExpressionUUID->"7e4b96fe-abcd-4197-ae39-f1075f7afa58"],
Cell[561316, 11473, 5647, 100, 241, "Output",ExpressionUUID->"c368cabe-9a8a-4632-aebb-41b866ca1f78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[567000, 11578, 485, 11, 31, "Input",ExpressionUUID->"126f4d47-0600-43f1-aa14-0dd4c6aaac9c"],
Cell[567488, 11591, 547, 8, 31, "Output",ExpressionUUID->"85af67fd-a4ee-45e5-9106-9608638343c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[568072, 11604, 481, 11, 31, "Input",ExpressionUUID->"4917d071-f59b-4f1e-a96c-a6c9042c6636"],
Cell[568556, 11617, 526, 8, 31, "Output",ExpressionUUID->"331334d4-a000-4b6f-9202-91b934bf4de5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[569119, 11630, 1320, 23, 31, "Input",ExpressionUUID->"2c444fb3-82df-43cc-9185-44884396c783"],
Cell[570442, 11655, 14382, 288, 60, "Output",ExpressionUUID->"c8377607-9031-40b4-b282-58765617e6d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584861, 11948, 1892, 36, 31, "Input",ExpressionUUID->"2a59b881-d376-43d8-b396-175d1e1c9938"],
Cell[586756, 11986, 644, 10, 31, "Output",ExpressionUUID->"58ac029c-e6f1-4836-aa11-e17f66cebbdd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[587437, 12001, 162, 3, 24, "Subsubsection",ExpressionUUID->"8741529c-9780-4efa-acce-b0a7f8555815"],
Cell[CellGroupData[{
Cell[587624, 12008, 1827, 37, 165, "Input",ExpressionUUID->"40407238-0b55-4802-84a1-94f993312b98"],
Cell[589454, 12047, 840, 16, 31, "Output",ExpressionUUID->"b09dd3e3-ffa3-4722-94d4-f01ce3e7fa13"]
}, Open  ]],
Cell[590309, 12066, 259, 6, 31, "Input",ExpressionUUID->"c4821a4d-17ad-4a62-868d-79afc8bf9aef"],
Cell[590571, 12074, 794, 15, 146, "Input",ExpressionUUID->"fab4ed2e-8b7b-4354-a878-ca8d74d41502"],
Cell[591368, 12091, 1347, 26, 146, "Input",ExpressionUUID->"efcfd2d9-3339-4b5f-a21c-c05beabe29d0"],
Cell[592718, 12119, 574, 16, 31, "Input",ExpressionUUID->"9dc654f5-12e7-4376-b988-c7b6004ee35f"],
Cell[593295, 12137, 997, 17, 146, "Input",ExpressionUUID->"bfd1fe49-5c2f-42b5-a27b-fbf16023de9c"],
Cell[594295, 12156, 1061, 18, 146, "Input",ExpressionUUID->"a2cbe80f-09bc-4b53-8bff-04c2ae7c47c3"],
Cell[595359, 12176, 623, 16, 31, "Input",ExpressionUUID->"bfb484d5-820f-4006-ab1e-d64c012102c0"],
Cell[CellGroupData[{
Cell[596007, 12196, 299, 7, 31, "Input",ExpressionUUID->"05db1675-ae50-40f9-b872-a707329c2930"],
Cell[596309, 12205, 2537, 58, 245, "Output",ExpressionUUID->"be2778ef-42a6-44cd-a5b1-d414c8090f9a"]
}, Open  ]],
Cell[598861, 12266, 1001, 25, 31, "Input",ExpressionUUID->"7a1d2727-4002-416b-a42f-e21aef650e48"],
Cell[599865, 12293, 1106, 27, 31, "Input",ExpressionUUID->"f483904d-facb-4226-90a0-92506a67fe1f"],
Cell[CellGroupData[{
Cell[600996, 12324, 238, 5, 31, "Input",ExpressionUUID->"d7ded7f2-fd4e-48bc-afff-313ea28ab95e"],
Cell[601237, 12331, 2702, 58, 233, "Output",ExpressionUUID->"a0a00e2e-643e-46ca-b4c1-5d406fcd8080"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603976, 12394, 514, 13, 31, "Input",ExpressionUUID->"3b0690d8-576a-4f50-805c-848c9bf88016"],
Cell[604493, 12409, 833, 14, 32, "Output",ExpressionUUID->"b4e9aad2-1add-430e-bd8c-3bce75f14ced"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605363, 12428, 680, 16, 31, "Input",ExpressionUUID->"48eeed37-8a15-4b27-b484-77994f6f7a0d"],
Cell[606046, 12446, 8084, 150, 235, "Output",ExpressionUUID->"79ced1b0-2e2f-447d-9f1a-82a88b8845ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614167, 12601, 740, 19, 31, "Input",ExpressionUUID->"5e378bec-8eea-41d9-b2cc-c81546e65412"],
Cell[614910, 12622, 506, 8, 31, "Output",ExpressionUUID->"d03b2dfe-ec5c-4d0c-bb69-24a32a27c1bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[615453, 12635, 436, 10, 31, "Input",ExpressionUUID->"4d1ac0e4-ef35-46bc-bc7e-5fb5ef8e3016"],
Cell[615892, 12647, 499, 8, 31, "Output",ExpressionUUID->"6c400a1f-43d7-48f2-8b10-d777c09737ce"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[616440, 12661, 515, 11, 31, "Input",ExpressionUUID->"3aa2d35d-0c01-4b12-8fd5-db47c23e14a8"],
Cell[616958, 12674, 502, 8, 31, "Output",ExpressionUUID->"cea1019c-bdc8-4242-9606-c66daf7bf390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617497, 12687, 220, 5, 26, "Text",ExpressionUUID->"c5a22707-c3e3-4ef3-83ee-4d3cf36dcb3b"],
Cell[CellGroupData[{
Cell[617742, 12696, 732, 14, 31, "Input",ExpressionUUID->"94effaa2-9976-41e0-982f-16b2ea4c52ce"],
Cell[618477, 12712, 726, 11, 31, "Output",ExpressionUUID->"316e3fca-4a3d-4ef6-9f2c-f1f790dcab7b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[619252, 12729, 2195, 44, 127, "Input",ExpressionUUID->"751718a7-0c82-478d-9e79-edcec149d036"],
Cell[621450, 12775, 13332, 229, 413, "Output",ExpressionUUID->"c2187c37-901b-4059-ab23-23417881c731"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[634831, 13010, 379, 6, 68, "Section",ExpressionUUID->"4efd5b93-148c-456b-9645-92b2cb33f148"],
Cell[635213, 13018, 2130, 50, 677, "Input",ExpressionUUID->"454dd928-09a4-486a-aecd-7774f1d75e6c"],
Cell[637346, 13070, 495, 10, 31, "Input",ExpressionUUID->"e6910de8-019b-40a7-add6-27cfea9f6e47"],
Cell[CellGroupData[{
Cell[637866, 13084, 1140, 27, 108, "Input",ExpressionUUID->"0c306e42-9206-451e-b276-7f25d1a13d5d"],
Cell[639009, 13113, 383, 10, 31, "Output",ExpressionUUID->"3deec005-1079-4b48-bc38-7539da438e1b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[639429, 13128, 6851, 121, 179, "Input",ExpressionUUID->"00e8cb3d-befa-4bba-b9d8-2d8e7eaf6b21"],
Cell[646283, 13251, 5831, 102, 246, "Output",ExpressionUUID->"21a258b2-597d-4ca2-affd-560a12db1df7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[652151, 13358, 490, 11, 31, "Input",ExpressionUUID->"657a4614-756e-46da-90b8-1da0ad443cd5"],
Cell[652644, 13371, 593, 9, 31, "Output",ExpressionUUID->"3adcc00d-29d6-42c0-bded-98afaa646ee7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[653274, 13385, 485, 11, 31, "Input",ExpressionUUID->"4f5e3a6e-21e1-49d9-aa63-433c66fd4a38"],
Cell[653762, 13398, 587, 9, 31, "Output",ExpressionUUID->"c77627dc-b825-4408-8fcb-5af3c0bb9976"]
}, Open  ]],
Cell[CellGroupData[{
Cell[654386, 13412, 1226, 22, 31, "Input",ExpressionUUID->"2d21b415-427f-49d4-9f11-30820cfce8dd"],
Cell[655615, 13436, 14967, 291, 60, "Output",ExpressionUUID->"0c743654-6f80-48aa-bd07-31ae263cbba9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[670619, 13732, 1801, 35, 31, "Input",ExpressionUUID->"6a1ad74d-aa0f-455c-b75d-91c2cdcb9618"],
Cell[672423, 13769, 624, 10, 31, "Output",ExpressionUUID->"a0af7a63-8b04-405d-bf07-8fb71d61c68b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[673084, 13784, 1226, 28, 31, "Input",ExpressionUUID->"d98c8203-05d9-46c7-9f72-a2b2a847834d"],
Cell[674313, 13814, 657, 10, 31, "Output",ExpressionUUID->"c4a982dc-854e-4b4c-848b-09d6c68dd9bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[675007, 13829, 1222, 27, 31, "Input",ExpressionUUID->"c42e2814-1f08-4f70-81a8-0ff89bc9e521"],
Cell[676232, 13858, 647, 10, 31, "Output",ExpressionUUID->"69c91a00-74d9-4148-83ea-eb33cf1b7abb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676916, 13873, 1593, 26, 89, "Input",ExpressionUUID->"9b4a253e-aa44-4989-976d-0d18868730fa"],
Cell[678512, 13901, 6781, 117, 239, "Output",ExpressionUUID->"57f74154-c8c9-49d7-91fa-2ae85a211661"]
}, Open  ]]
}, Open  ]],
Cell[685320, 14022, 180, 3, 68, "Section",ExpressionUUID->"c3b09d43-f3b6-4a18-b0db-d33ac90e0b1c"],
Cell[CellGroupData[{
Cell[685525, 14029, 325, 6, 27, "Subsection",ExpressionUUID->"3c2133ea-c6b3-4e20-9c0b-5677ddc7ddd8"],
Cell[CellGroupData[{
Cell[685875, 14039, 816, 20, 31, "Input",ExpressionUUID->"3295a945-7d3c-451f-83e8-c148033f7623"],
Cell[686694, 14061, 7226, 139, 226, "Output",ExpressionUUID->"15dc98bd-3fed-4e57-bd88-b7a896c29bd8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693957, 14205, 1480, 34, 108, "Input",ExpressionUUID->"669c2f71-30fd-4ee2-a1be-27ec0e3f0c0e"],
Cell[695440, 14241, 451, 11, 31, "Output",ExpressionUUID->"1b634ab1-1c7b-4ef1-9bc5-4e4ca3bce323"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695928, 14257, 537, 12, 31, "Input",ExpressionUUID->"31db6a62-ff27-4e38-bd76-ac28d9c01d8b"],
Cell[696468, 14271, 547, 8, 31, "Output",ExpressionUUID->"4c8a1c28-3e85-40ca-bce3-f11545b0833d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[697052, 14284, 535, 12, 31, "Input",ExpressionUUID->"fe6f9ed8-6623-4eef-97b8-c489a8a5923b"],
Cell[697590, 14298, 524, 8, 31, "Output",ExpressionUUID->"84e76f2f-a94c-43ad-be41-44c2391a042a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[698151, 14311, 1272, 23, 31, "Input",ExpressionUUID->"97af3af2-c4ae-4e04-a6f7-b5103efeb3a5"],
Cell[699426, 14336, 14384, 288, 60, "Output",ExpressionUUID->"a29779ca-4c62-485e-9aef-02991baf11cd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[713847, 14629, 2052, 40, 31, "Input",ExpressionUUID->"0639adc6-6737-4ad7-851a-9a0285bb4887"],
Cell[715902, 14671, 673, 11, 31, "Output",ExpressionUUID->"e8053031-8815-4037-9c8a-3f1b31502039"]
}, Open  ]],
Cell[CellGroupData[{
Cell[716612, 14687, 853, 20, 31, "Input",ExpressionUUID->"62f882dc-4d25-432d-8550-6cb963756cf7"],
Cell[717468, 14709, 885, 21, 58, "Output",ExpressionUUID->"341d574d-beed-417c-be19-072822b5b9ae"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[718402, 14736, 404, 8, 35, "Subsection",ExpressionUUID->"82549c51-83fb-4a0c-ace5-8082f6200c29"],
Cell[CellGroupData[{
Cell[718831, 14748, 6958, 125, 165, "Input",ExpressionUUID->"9ba64c0b-d7f4-4cf4-aebd-e3d6ae2a9ab6"],
Cell[725792, 14875, 5966, 103, 230, "Output",ExpressionUUID->"9bbda839-543a-4494-98da-90326835534d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731795, 14983, 1611, 36, 108, "Input",ExpressionUUID->"d0eeecc0-a2d1-45fd-96cf-dfc5a8a565b2"],
Cell[733409, 15021, 432, 11, 31, "Output",ExpressionUUID->"b7c73d57-a6e5-42ee-93c8-c03a5a429c20"]
}, Open  ]],
Cell[CellGroupData[{
Cell[733878, 15037, 589, 12, 31, "Input",ExpressionUUID->"bb35c655-1d44-477b-ac6b-b958d5fc1ff1"],
Cell[734470, 15051, 548, 8, 31, "Output",ExpressionUUID->"603afffa-8586-4210-8968-6669be71c086"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735055, 15064, 585, 12, 31, "Input",ExpressionUUID->"4ece9598-59a5-4f96-beb1-ee15b0d78481"],
Cell[735643, 15078, 524, 8, 31, "Output",ExpressionUUID->"9898831e-cbce-4855-96c9-471fa2892318"]
}, Open  ]],
Cell[CellGroupData[{
Cell[736204, 15091, 1374, 24, 31, "Input",ExpressionUUID->"3162c008-6aed-430c-8662-2321d7d5e472"],
Cell[737581, 15117, 14345, 289, 60, "Output",ExpressionUUID->"2f809736-e041-4eb4-8784-2da359d0a513"]
}, Open  ]],
Cell[CellGroupData[{
Cell[751963, 15411, 2059, 40, 31, "Input",ExpressionUUID->"6201ac92-f07c-47ff-8558-6d88b251ed7c"],
Cell[754025, 15453, 675, 11, 31, "Output",ExpressionUUID->"594fb43a-943f-4073-b492-f9a72c2a86c5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754737, 15469, 815, 19, 31, "Input",ExpressionUUID->"4e67aaea-56ba-4a55-95cd-e7b96b1a29b4"],
Cell[755555, 15490, 810, 20, 58, "Output",ExpressionUUID->"bfb23b2f-f564-4f47-82b0-5100d7143e49"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[756414, 15516, 417, 8, 35, "Subsection",ExpressionUUID->"27fb99ae-188f-4fd3-a1df-84be7dfb2362"],
Cell[CellGroupData[{
Cell[756856, 15528, 6921, 124, 164, "Input",ExpressionUUID->"34044e2a-61a5-4bfa-b5da-0a2bd8a8ebc4"],
Cell[763780, 15654, 5956, 103, 223, "Output",ExpressionUUID->"362d31ce-f69c-45bc-9cae-cbcce0e2d5c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[769773, 15762, 1659, 36, 108, "Input",ExpressionUUID->"48c13e77-6162-429e-b30a-a6280ec31a0b"],
Cell[771435, 15800, 479, 11, 31, "Output",ExpressionUUID->"d2d11b19-2e7d-4f8a-a3bc-a3780e0a02e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[771951, 15816, 641, 13, 31, "Input",ExpressionUUID->"7407c218-030e-4a0a-95c7-515136a82998"],
Cell[772595, 15831, 597, 9, 31, "Output",ExpressionUUID->"ecadf9a1-7f5b-4b3f-9804-6f74fbbf53ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[773229, 15845, 637, 13, 31, "Input",ExpressionUUID->"23050121-1a11-4e89-b4ab-3962d9f51f56"],
Cell[773869, 15860, 573, 9, 31, "Output",ExpressionUUID->"13949d76-72a9-40ce-abf9-9e24169980d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[774479, 15874, 1322, 23, 31, "Input",ExpressionUUID->"c4ef1199-6327-463a-b14b-bc193aa91401"],
Cell[775804, 15899, 14473, 284, 60, "Output",ExpressionUUID->"6a07898e-3759-49b0-ba74-7e7ed36a592c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[790314, 16188, 2090, 41, 31, "Input",ExpressionUUID->"47b08cef-d50b-43a2-939c-7ef319780418"],
Cell[792407, 16231, 692, 11, 31, "Output",ExpressionUUID->"c7e0f34d-306a-40c3-b53b-58bb4b4aa071"]
}, Open  ]],
Cell[CellGroupData[{
Cell[793136, 16247, 763, 18, 31, "Input",ExpressionUUID->"3f0f2b2a-e80e-44a7-9ea0-2218c7848732"],
Cell[793902, 16267, 833, 20, 58, "Output",ExpressionUUID->"4f9f1298-c893-48c9-b2ce-93422e88ec5e"]
}, Open  ]]
}, Open  ]],
Cell[794762, 16291, 161, 6, 91, "Section",ExpressionUUID->"2a1553c3-fbc1-49a8-a5b4-16e3cd7262a5"],
Cell[794926, 16299, 185, 3, 27, "Subsection",ExpressionUUID->"542471c3-8166-4b61-b583-dbe9e3bb3f72"],
Cell[795114, 16304, 468, 10, 31, "Input",ExpressionUUID->"70244e5a-db23-4530-91b2-e1ac2c7ed63c"],
Cell[CellGroupData[{
Cell[795607, 16318, 2985, 67, 203, "Input",ExpressionUUID->"6c8b20fb-1f3d-48d4-b5b6-68c0bbfa6224"],
Cell[798595, 16387, 1498, 34, 142, "Output",ExpressionUUID->"e164e125-6fa5-4160-85d6-d7492f82cce5"]
}, Open  ]],
Cell[800108, 16424, 208, 3, 35, "Subsection",ExpressionUUID->"41a35b4a-1db5-4578-9c3e-c053b6900733"],
Cell[800319, 16429, 574, 12, 31, "Input",ExpressionUUID->"d6aa081b-fe2b-411e-92f9-931ec6ac2f96"],
Cell[CellGroupData[{
Cell[800918, 16445, 4259, 96, 355, "Input",ExpressionUUID->"c8d1f20a-e908-45fa-82e6-ba37973431dc"],
Cell[805180, 16543, 2707, 77, 214, "Output",ExpressionUUID->"a4ab7996-7911-4518-8f24-691896d72572"]
}, Open  ]],
Cell[807902, 16623, 234, 4, 35, "Subsection",ExpressionUUID->"cc517d30-9eb6-4ae9-85bc-b20209ced5be"],
Cell[808139, 16629, 2350, 58, 121, "Input",ExpressionUUID->"d769e62a-9a58-4688-800b-67ebe350b93e"],
Cell[810492, 16689, 2037, 53, 92, "Output",ExpressionUUID->"a32d0611-7a1e-4a19-85ee-3186f0a476f5"]
}
]
*)

